# Hindi lexemes settings_dialog.py
lexemes = {
    "tab_openai_api_config": "OpenAI API",

    "module_openai_api_label": "OpenAI API",
    "module_openai_api_url_label": "API URL",
    "module_openai_api_url_input_placeholder_text": "API URL",
    "module_openai_api_url_input_accessible_description":
        "OpenAI API का URL API के अंतिम बिंदु का पता है, जो सेवा और संस्करण के आधार पर भिन्न हो सकता है।\n"
        "AI सहायक इसका उपयोग वार्तालाप चैट या पाठ पूर्णता के लिए करता है।\n"
        "वर्तमान URL प्राप्त करने के लिए OpenAI API के आधिकारिक दस्तावेज़ का संदर्भ लें।",
    "module_openai_api_key_label": "API कुंजी",
    "module_openai_api_key_input_placeholder_text": "API कुंजी",
    "module_openai_api_key_input_accessible_description":
        "OpenAI API कुंजी API के अंतिम बिंदु पर अनुरोधों को प्रमाणित करने के लिए उपयोग किया जाने वाला एक गुप्त टोकन है।",
    "module_openai_api_supported_models_label": "समर्थित मॉडल",
    "module_openai_api_model_names_combo_placeholder_text": "एक मॉडल चुनें",
    "module_openai_api_model_names_combo_accessible_description":
        "चैट वार्तालापों के लिए समर्थित मॉडलों में से चुनें।",

    "module_openai_api_base_system_prompt_label": "सिस्टम प्रॉम्प्ट",
    "module_openai_api_base_system_prompt_edit_placeholder_text": "प्रत्येक अनुरोध से पहले आधार सिस्टम प्रॉम्प्ट",
    "module_openai_api_base_system_prompt_edit_accessible_description":
        "प्रत्येक अनुरोध से पहले आने वाला आधार सिस्टम प्रॉम्प्ट।\n"
        "आमतौर पर, यह निर्देशों या भूमिका विशेषताओं वाला सादा पाठ होता है।",

    "module_openai_api_base_response_temperature_label": "तापमान: {temperature}",
    "module_openai_api_base_response_temperature_input_accessible_description":
        "मॉडल की प्रतिक्रियाओं की यादृच्छिकता को समायोजित करता है। उच्च मूल्य अधिक विविधतापूर्ण\n"
        "आउटपुट उत्पन्न करते हैं, जबकि निम्न मूल्य अधिक पूर्वानुमान योग्य प्रतिक्रियाएं देते हैं।",

    "module_openai_api_base_response_max_tokens_label": "अधिकतम प्रतिक्रिया टोकन",
    "module_openai_api_base_response_max_tokens_input_accessible_description":
        "प्रतिक्रिया में प्राप्त होने वाले टोकनों की अधिकतम संख्या निर्धारित करता है, जैसे शब्द और विराम चिह्न,\n"
        "आउटपुट की लंबाई को नियंत्रित करता है।",

    "module_openai_api_config_prompt_history_size_label": "प्रॉम्प्ट इतिहास का आकार",
    "module_openai_api_config_prompt_history_size_input_accessible_description":
        "प्रणाली द्वारा संदर्भ के लिए बनाए रखी गई प्रॉम्प्ट इतिहास की प्रविष्टियों की संख्या को नियंत्रित करता है।\n"
        "शून्य मूल्य असीमित प्रविष्टियों की अनुमति देता है।"
}
