# Japanese lexemes color_picker_dialog.py
lexemes = {
    "color_picker_title": "色を選択",

    "color_picker_color_black": "黒",
    "color_picker_color_silver": "銀色",
    "color_picker_color_gray": "灰色",
    "color_picker_color_white": "白",
    "color_picker_color_maroon": "栗色",
    "color_picker_color_red": "赤",
    "color_picker_color_purple": "紫",
    "color_picker_color_fuchsia": "紫紅色",
    "color_picker_color_green": "緑",
    "color_picker_color_lime": "ライム",
    "color_picker_color_olive": "オリーブ",
    "color_picker_color_yellow": "黄色",
    "color_picker_color_navy": "ネイビー",
    "color_picker_color_blue": "青",
    "color_picker_color_teal": "ティール",
    "color_picker_color_aqua": "アクア",
    "color_picker_color_aliceblue": "アリスブルー",
    "color_picker_color_antiquewhite": "アンティークホワイト",
    "color_picker_color_aquamarine": "アクアマリン",
    "color_picker_color_azure": "空色",
    "color_picker_color_beige": "ベージュ",
    "color_picker_color_bisque": "ビスク",
    "color_picker_color_blanchedalmond": "ブランチドアーモンド",
    "color_picker_color_blueviolet": "ブルーバイオレット",
    "color_picker_color_brown": "茶色",
    "color_picker_color_burlywood": "バーリーウッド",
    "color_picker_color_cadetblue": "キャデットブルー",
    "color_picker_color_chartreuse": "シャルトリューズ",
    "color_picker_color_chocolate": "チョコレート",
    "color_picker_color_coral": "コーラル",
    "color_picker_color_cornflowerblue": "コーンフラワーブルー",
    "color_picker_color_cornsilk": "コーンシルク",
    "color_picker_color_crimson": "クリムゾン",
    "color_picker_color_cyan": "シアン",
    "color_picker_color_darkblue": "ダークブルー",
    "color_picker_color_darkcyan": "ダークシアン",
    "color_picker_color_darkgoldenrod": "ダークゴールデンロッド",
    "color_picker_color_darkgray": "ダークグレー",
    "color_picker_color_darkgreen": "ダークグリーン",
    "color_picker_color_darkkhaki": "ダークカーキ",
    "color_picker_color_darkmagenta": "ダークマゼンタ",
    "color_picker_color_darkolivegreen": "ダークオリーブグリーン",
    "color_picker_color_darkorange": "ダークオレンジ",
    "color_picker_color_darkorchid": "ダークオーキッド",
    "color_picker_color_darkred": "ダークレッド",
    "color_picker_color_darksalmon": "ダークサーモン",
    "color_picker_color_darkseagreen": "ダークシーグリーン",
    "color_picker_color_darkslateblue": "ダークスレートブルー",
    "color_picker_color_darkslategray": "ダークスレートグレー",
    "color_picker_color_darkturquoise": "ダークターコイズ",
    "color_picker_color_darkviolet": "ダークバイオレット",
    "color_picker_color_deeppink": "ディープピンク",
    "color_picker_color_deepskyblue": "ディープスカイブルー",
    "color_picker_color_dimgray": "ディムグレー",
    "color_picker_color_dodgerblue": "ドジャーブルー",
    "color_picker_color_firebrick": "ファイアーブリック",
    "color_picker_color_floralwhite": "フローラルホワイト",
    "color_picker_color_forestgreen": "フォレストグリーン",
    "color_picker_color_gainsboro": "ゲインズボロ",
    "color_picker_color_ghostwhite": "ゴーストホワイト",
    "color_picker_color_gold": "ゴールド",
    "color_picker_color_goldenrod": "ゴールデンロッド",
    "color_picker_color_greenyellow": "グリーンイエロー",
    "color_picker_color_honeydew": "ハニーデュー",
    "color_picker_color_hotpink": "ホットピンク",
    "color_picker_color_indianred": "インディアンレッド",
    "color_picker_color_indigo": "インディゴ",
    "color_picker_color_ivory": "アイボリー",
    "color_picker_color_khaki": "カーキ",
    "color_picker_color_lavender": "ラベンダー",
    "color_picker_color_lavenderblush": "ラベンダーブラッシュ",
    "color_picker_color_lawngreen": "ローングリーン",
    "color_picker_color_lemonchiffon": "レモンシフォン",
    "color_picker_color_lightblue": "ライトブルー",
    "color_picker_color_lightcoral": "ライトコーラル",
    "color_picker_color_lightcyan": "ライトシアン",
    "color_picker_color_lightgoldenrodyellow": "ライトゴールデンロッドイエロー",
    "color_picker_color_lightgray": "ライトグレー",
    "color_picker_color_lightgreen": "ライトグリーン",
    "color_picker_color_lightpink": "ライトピンク",
    "color_picker_color_lightsalmon": "ライトサーモン",
    "color_picker_color_lightseagreen": "ライトシーグリーン",
    "color_picker_color_lightskyblue": "ライトスカイブルー",
    "color_picker_color_lightslategray": "ライトスレートグレー",
    "color_picker_color_lightsteelblue": "ライトスチールブルー",
    "color_picker_color_lightyellow": "ライトイエロー",
    "color_picker_color_limegreen": "ライムグリーン",
    "color_picker_color_linen": "リネン",
    "color_picker_color_magenta": "マゼンタ",
    "color_picker_color_mediumaquamarine": "ミディアムアクアマリン",
    "color_picker_color_mediumblue": "ミディアムブルー",
    "color_picker_color_mediumorchid": "ミディアムオーキッド",
    "color_picker_color_mediumpurple": "ミディアムパープル",
    "color_picker_color_mediumseagreen": "ミディアムシーグリーン",
    "color_picker_color_mediumslateblue": "ミディアムスレートブルー",
    "color_picker_color_mediumspringgreen": "ミディアムスプリンググリーン",
    "color_picker_color_mediumturquoise": "ミディアムターコイズ",
    "color_picker_color_mediumvioletred": "ミディアムバイオレットレッド",
    "color_picker_color_midnightblue": "ミッドナイトブルー",
    "color_picker_color_mintcream": "ミントクリーム",
    "color_picker_color_mistyrose": "ミスティーローズ",
    "color_picker_color_moccasin": "モカシン",
    "color_picker_color_navajowhite": "ナバホホワイト",
    "color_picker_color_oldlace": "オールドレース",
    "color_picker_color_olivedrab": "オリーブドラブ",
    "color_picker_color_orange": "オレンジ",
    "color_picker_color_orangered": "オレンジレッド",
    "color_picker_color_orchid": "オーキッド",
    "color_picker_color_palegoldenrod": "ペールゴールデンロッド",
    "color_picker_color_palegreen": "ペールグリーン",
    "color_picker_color_paleturquoise": "ペールターコイズ",
    "color_picker_color_palevioletred": "ペールバイオレットレッド",
    "color_picker_color_papayawhip": "パパイヤ",
    "color_picker_color_peachpuff": "ピーチパフ",
    "color_picker_color_peru": "ペルー",
    "color_picker_color_pink": "ピンク",
    "color_picker_color_plum": "プラム",
    "color_picker_color_powderblue": "パウダーブルー",
    "color_picker_color_rebeccapurple": "レベッカパープル",
    "color_picker_color_rosybrown": "ロージーブラウン",
    "color_picker_color_royalblue": "ロイヤルブルー",
    "color_picker_color_saddlebrown": "サドルブラウン",
    "color_picker_color_salmon": "サーモン",
    "color_picker_color_sandybrown": "サンディブラウン",
    "color_picker_color_seagreen": "シーグリーン",
    "color_picker_color_seashell": "シーシェル",
    "color_picker_color_sienna": "シエナ",
    "color_picker_color_skyblue": "スカイブルー",
    "color_picker_color_slateblue": "スレートブルー",
    "color_picker_color_slategray": "スレートグレイ",
    "color_picker_color_snow": "スノー",
    "color_picker_color_springgreen": "スプリンググリーン",
    "color_picker_color_steelblue": "スチールブルー",
    "color_picker_color_tan": "タン",
    "color_picker_color_thistle": "シスル",
    "color_picker_color_tomato": "トマト",
    "color_picker_color_turquoise": "ターコイズ",
    "color_picker_color_violet": "バイオレット",
    "color_picker_color_wheat": "ウィート",
    "color_picker_color_whitesmoke": "ホワイトスモーク",
    "color_picker_color_yellowgreen": "イエローグリーン",
}
