# Greek lexemes common.py
lexemes = {
    # Common
    "module_ondevice_llm_name": "LLM στη συσκευή",

    "module_ondevice_llm_model_exception": "Σφάλμα μη εύρεσης μοντέλου: {error_msg}",
    "module_ondevice_llm_task_exception": "Αδυναμία αρχικοποίησης του δημιουργού μοντέλου: {error_msg}",
}
