# Greek lexemes settings_dialog.py
lexemes = {
    # Διάλογος ρυθμίσεων
    "window_title": "Ρυθμίσεις",

    "button_close": "Κλείσιμο",

    "tab_general": "Γενικά",
    "tab_editor_config": "Επεξεργαστής",
    "tab_viewer_config": "Προβολέας",
    "tab_ai_config": "Ρυθμίσεις AI",

    "general_app_config_label": "Ρυθμίσεις Εφαρμογής",
    "general_app_language_label": "Γλώσσα",
    "general_app_language_combo_placeholder_text": "Επιλέξτε γλώσσα",
    "general_app_language_combo_accessible_description": "Γλώσσα διεπαφής της εφαρμογής",
    "general_app_theme_label": "Θέμα",
    "general_app_theme_combo_placeholder_text": "Επιλέξτε θέμα",
    "general_app_theme_combo_accessible_description": "Θέμα διεπαφής της εφαρμογής",
    "general_app_main_menu_label": "Κύριο Μενού",
    "general_app_main_menu_checkbox": "Εμφάνιση Κύριου Μενού",
    "general_app_main_menu_checkbox_accessible_description": "Εμφάνιση του κύριου αναδυόμενου μενού της εφαρμογής",
    "general_app_font_size_label": "Μέγεθος Γραμματοσειράς: {size}pt",
    "general_app_font_size_slider_accessible_description":
        "Ρύθμιση του παγκόσμιου μεγέθους γραμματοσειράς της εφαρμογής",

    "general_statusbar_label": "Γραμμή Κατάστασης",
    "general_statusbar_show_global_cursor_position_checkbox": "Εμφάνιση Παγκόσμιας Θέσης Δρομέα",
    "general_statusbar_show_global_cursor_position_checkbox_accessible_description":
        "Εμφάνιση της παγκόσμιας θέσης του δρομέα στη γραμμή κατάστασης",

    "editor_config_label": "Ρυθμίσεις Επεξεργαστή",
    "editor_config_show_line_numbers_checkbox": "Εμφάνιση Αριθμών Γραμμών",
    "editor_config_show_line_numbers_checkbox_accessible_description": "Εμφάνιση αριθμών γραμμών στον επεξεργαστή",

    "viewer_config_label": "Ρυθμίσεις Προβολέα",
    "viewer_config_process_emojis_checkbox": "Μετατροπή Εικονιδίων Κειμένου σε Γραφικά",
    "viewer_config_process_emojis_checkbox_accessible_description":
        "Μετατροπή εικονιδίων κειμένου σε γραφικές αναπαραστάσεις",
    "viewer_config_highlight_todos_checkbox": "Επισήμανση Σημειώσεων TODO",
    "viewer_config_highlight_todos_checkbox_accessible_description": "Επισήμανση ετικετών TODO μέσα στο κείμενο",
    "viewer_config_open_link_confirmation_checkbox": "Απαίτηση Επιβεβαίωσης για Άνοιγμα Συνδέσμων",
    "viewer_config_open_link_confirmation_checkbox_accessible_description":
        "Ζήτηση επιβεβαίωσης πριν το άνοιγμα συνδέσμων",
    "viewer_config_save_resources_checkbox": "Αυτόματη αποθήκευση εξωτερικών εικόνων στον δίσκο",
    "viewer_config_save_resources_checkbox_accessible_description":
        "Αυτόματη αποθήκευση αντιγράφων εξωτερικών εικόνων στον δίσκο για πρόσβαση χωρίς σύνδεση.",

    "ai_config_inference_module_label": "Μονάδα Συμπερασμού",
    "ai_config_inference_module_names_combo_label": "Ενεργή Μονάδα Συμπερασμού",
    "ai_config_inference_module_names_combo_placeholder_text": "Επιλέξτε Μονάδα",
    "ai_config_inference_module_names_combo_accessible_description":
        "Επιλέξτε από τις διαθέσιμες μονάδες συμπερασμού AI για να λειτουργήσετε με τον AI Assistant.\n"
        "Οι επιλογές περιλαμβάνουν μεγάλα γλωσσικά μοντέλα (LLM) με επεξεργασία σε πραγματικό χρόνο,\n"
        "ή λειτουργικότητα βασισμένη σε API.",

    "ai_config_base_label": "Βασικές Παράμετροι",
    "ai_config_multi_turn_dialogue_checkbox": "Πολλαπλός διάλογος με μνήμη συνομιλιών",
    "ai_config_multi_turn_dialogue_checkbox_accessible_description":
        "Ενεργοποιήστε έναν πολλαπλό διάλογο που διατηρεί την προηγούμενη προτροπή για μνήμη συνομιλιών.\n"
        "Όταν είναι απενεργοποιημένο, μόνο το νέο μήνυμα και η προτροπή συστήματος επηρεάζουν την απάντηση.",
    "ai_config_convert_to_md_checkbox": "Μετατροπή του αποτελέσματος σε Markdown",
    "ai_config_convert_to_md_checkbox_accessible_description":
        "Μετατρέψτε το μήνυμα εξόδου σε μορφή Markdown.",
}
