# Italian lexemes common.py
lexemes = {
    "module_llama_cpp_name": "Modulo llama.cpp",

    "module_llama_cpp_model_exception": "Errore modello non trovato: {error_msg}",
    "module_llama_cpp_task_exception": "Impossibile inizializzare il generatore di modelli: {error_msg}",
}
