# French lexemes color_picker_dialog.py
lexemes = {
    "color_picker_title": "Sélectionner une couleur",

    "color_picker_color_black": "Noir",
    "color_picker_color_silver": "Argenté",
    "color_picker_color_gray": "Gris",
    "color_picker_color_white": "Blanc",
    "color_picker_color_maroon": "Marron",
    "color_picker_color_red": "Rouge",
    "color_picker_color_purple": "Violet",
    "color_picker_color_fuchsia": "Fuchsia",
    "color_picker_color_green": "Vert",
    "color_picker_color_lime": "Citron vert",
    "color_picker_color_olive": "Olive",
    "color_picker_color_yellow": "Jaune",
    "color_picker_color_navy": "Bleu marine",
    "color_picker_color_blue": "Bleu",
    "color_picker_color_teal": "Sarcelle",
    "color_picker_color_aqua": "Aqua",
    "color_picker_color_aliceblue": "Bleu Alice",
    "color_picker_color_antiquewhite": "Blanc antique",
    "color_picker_color_aquamarine": "Aigue-marine",
    "color_picker_color_azure": "Azur",
    "color_picker_color_beige": "Beige",
    "color_picker_color_bisque": "Bisque",
    "color_picker_color_blanchedalmond": "Amande blanchie",
    "color_picker_color_blueviolet": "Violet bleu",
    "color_picker_color_brown": "Brun",
    "color_picker_color_burlywood": "Bois robuste",
    "color_picker_color_cadetblue": "Bleu cadet",
    "color_picker_color_chartreuse": "Chartreuse",
    "color_picker_color_chocolate": "Chocolat",
    "color_picker_color_coral": "Corail",
    "color_picker_color_cornflowerblue": "Bleu bleuet",
    "color_picker_color_cornsilk": "Soie de maïs",
    "color_picker_color_crimson": "Cramoisi",
    "color_picker_color_cyan": "Cyan",
    "color_picker_color_darkblue": "Bleu foncé",
    "color_picker_color_darkcyan": "Cyan foncé",
    "color_picker_color_darkgoldenrod": "Verge d'or foncée",
    "color_picker_color_darkgray": "Gris foncé",
    "color_picker_color_darkgreen": "Vert foncé",
    "color_picker_color_darkkhaki": "Kaki foncé",
    "color_picker_color_darkmagenta": "Magenta foncé",
    "color_picker_color_darkolivegreen": "Vert olive foncé",
    "color_picker_color_darkorange": "Orange foncé",
    "color_picker_color_darkorchid": "Orchidée foncée",
    "color_picker_color_darkred": "Rouge foncé",
    "color_picker_color_darksalmon": "Saumon foncé",
    "color_picker_color_darkseagreen": "Vert mer foncé",
    "color_picker_color_darkslateblue": "Bleu ardoise foncé",
    "color_picker_color_darkslategray": "Gris ardoise foncé",
    "color_picker_color_darkturquoise": "Turquoise foncé",
    "color_picker_color_darkviolet": "Violet foncé",
    "color_picker_color_deeppink": "Rose profond",
    "color_picker_color_deepskyblue": "Bleu ciel profond",
    "color_picker_color_dimgray": "Gris terne",
    "color_picker_color_dodgerblue": "Bleu dodger",
    "color_picker_color_firebrick": "Brique de feu",
    "color_picker_color_floralwhite": "Blanc floral",
    "color_picker_color_forestgreen": "Vert forêt",
    "color_picker_color_gainsboro": "Gainsboro",
    "color_picker_color_ghostwhite": "Blanc fantôme",
    "color_picker_color_gold": "Or",
    "color_picker_color_goldenrod": "Verge d'or",
    "color_picker_color_greenyellow": "Vert jaune",
    "color_picker_color_honeydew": "Rosée de miel",
    "color_picker_color_hotpink": "Rose chaud",
    "color_picker_color_indianred": "Rouge indien",
    "color_picker_color_indigo": "Indigo",
    "color_picker_color_ivory": "Ivoire",
    "color_picker_color_khaki": "Kaki",
    "color_picker_color_lavender": "Lavande",
    "color_picker_color_lavenderblush": "Rouge lavande",
    "color_picker_color_lawngreen": "Vert gazon",
    "color_picker_color_lemonchiffon": "Mousseline de citron",
    "color_picker_color_lightblue": "Bleu clair",
    "color_picker_color_lightcoral": "Corail clair",
    "color_picker_color_lightcyan": "Cyan clair",
    "color_picker_color_lightgoldenrodyellow": "Jaune verge d'or clair",
    "color_picker_color_lightgray": "Gris clair",
    "color_picker_color_lightgreen": "Vert clair",
    "color_picker_color_lightpink": "Rose clair",
    "color_picker_color_lightsalmon": "Saumon clair",
    "color_picker_color_lightseagreen": "Vert mer clair",
    "color_picker_color_lightskyblue": "Bleu ciel clair",
    "color_picker_color_lightslategray": "Gris ardoise clair",
    "color_picker_color_lightsteelblue": "Bleu acier clair",
    "color_picker_color_lightyellow": "Jaune clair",
    "color_picker_color_limegreen": "Vert citron",
    "color_picker_color_linen": "Lin",
    "color_picker_color_magenta": "Magenta",
    "color_picker_color_mediumaquamarine": "Aigue-marine moyenne",
    "color_picker_color_mediumblue": "Bleu moyen",
    "color_picker_color_mediumorchid": "Orchidée moyenne",
    "color_picker_color_mediumpurple": "Violet moyen",
    "color_picker_color_mediumseagreen": "Vert mer moyen",
    "color_picker_color_mediumslateblue": "Bleu ardoise moyen",
    "color_picker_color_mediumspringgreen": "Vert printemps moyen",
    "color_picker_color_mediumturquoise": "Turquoise moyen",
    "color_picker_color_mediumvioletred": "Rouge violet moyen",
    "color_picker_color_midnightblue": "Bleu minuit",
    "color_picker_color_mintcream": "Crème de menthe",
    "color_picker_color_mistyrose": "Rose brumeux",
    "color_picker_color_moccasin": "Mocassin",
    "color_picker_color_navajowhite": "Blanc Navajo",
    "color_picker_color_oldlace": "Vieille dentelle",
    "color_picker_color_olivedrab": "Olive terne",
    "color_picker_color_orange": "Orange",
    "color_picker_color_orangered": "Rouge orange",
    "color_picker_color_orchid": "Orchidée",
    "color_picker_color_palegoldenrod": "Verge d'or pâle",
    "color_picker_color_palegreen": "Vert pâle",
    "color_picker_color_paleturquoise": "Turquoise pâle",
    "color_picker_color_palevioletred": "Rouge violet pâle",
    "color_picker_color_papayawhip": "Fouetté à la papaye",
    "color_picker_color_peachpuff": "Pêche",
    "color_picker_color_peru": "Pérou",
    "color_picker_color_pink": "Rose",
    "color_picker_color_plum": "Prune",
    "color_picker_color_powderblue": "Bleu poudre",
    "color_picker_color_rebeccapurple": "Pourpre Rebecca",
    "color_picker_color_rosybrown": "Brun rosé",
    "color_picker_color_royalblue": "Bleu royal",
    "color_picker_color_saddlebrown": "Brun selle",
    "color_picker_color_salmon": "Saumon",
    "color_picker_color_sandybrown": "Brun sable",
    "color_picker_color_seagreen": "Vert mer",
    "color_picker_color_seashell": "Coquillage",
    "color_picker_color_sienna": "Terre de Sienne",
    "color_picker_color_skyblue": "Bleu ciel",
    "color_picker_color_slateblue": "Bleu ardoise",
    "color_picker_color_slategray": "Gris ardoise",
    "color_picker_color_snow": "Neige",
    "color_picker_color_springgreen": "Vert printemps",
    "color_picker_color_steelblue": "Bleu acier",
    "color_picker_color_tan": "Tan",
    "color_picker_color_thistle": "Chardon",
    "color_picker_color_tomato": "Tomate",
    "color_picker_color_turquoise": "Turquoise",
    "color_picker_color_violet": "Violet",
    "color_picker_color_wheat": "Blé",
    "color_picker_color_whitesmoke": "Fumée blanche",
    "color_picker_color_yellowgreen": "Vert jaune",
}
