# Turkish lexemes common.py
lexemes = {
    "module_llama_cpp_name": "Modül llama.cpp",

    "module_llama_cpp_model_exception": "Model bulunamadı hatası: {error_msg}",
    "module_llama_cpp_task_exception": "Model jeneratörü başlatılamıyor: {error_msg}",
}
