# Hindi lexemes settings_dialog.py
lexemes = {
    "window_title": "सेटिंग्स",

    "button_close": "बंद करें",

    "tab_general": "सामान्य",
    "tab_editor_config": "संपादक",
    "tab_viewer_config": "दर्शक",
    "tab_ai_config": "एआई कॉन्फ़िग",

    "general_app_config_label": "एप्लिकेशन कॉन्फ़िग",
    "general_app_language_label": "भाषा",
    "general_app_language_combo_placeholder_text": "एक भाषा चुनें",
    "general_app_language_combo_accessible_description": "एप्लिकेशन की इंटरफ़ेस भाषा",
    "general_app_theme_label": "थीम",
    "general_app_theme_combo_placeholder_text": "एक थीम चुनें",
    "general_app_theme_combo_accessible_description": "एप्लिकेशन की इंटरफ़ेस थीम",
    "general_app_main_menu_label": "मुख्य मेनू",
    "general_app_main_menu_checkbox": "मुख्य मेनू दिखाएं",
    "general_app_main_menu_checkbox_accessible_description": "ऐप का मुख्य ड्रॉपडाउन मेनू दिखाएं",
    "general_app_font_size_label": "फ़ॉन्ट आकार: {size} पीटी",
    "general_app_font_size_slider_accessible_description": "ऐप का वैश्विक फ़ॉन्ट आकार समायोजित करें",

    "general_statusbar_label": "स्थिति पट्टी",
    "general_statusbar_show_global_cursor_position_checkbox": "ग्लोबल कर्सर स्थिति दिखाएं",
    "general_statusbar_show_global_cursor_position_checkbox_accessible_description":
        "स्थिति पट्टी में ग्लोबल कर्सर स्थिति दिखाएं",

    "editor_config_label": "संपादक कॉन्फ़िगरेशन",
    "editor_config_show_line_numbers_checkbox": "लाइन संख्याएँ दिखाएं",
    "editor_config_show_line_numbers_checkbox_accessible_description": "संपादक में लाइन संख्याएँ दिखाएं",

    "viewer_config_label": "दर्शक कॉन्फ़िगरेशन",
    "viewer_config_process_emojis_checkbox": "पाठ इमोजी को ग्राफिक में परिवर्तित करें",
    "viewer_config_process_emojis_checkbox_accessible_description": "पाठ इमोजी को चित्रित प्रतिनिधि में परिवर्तित करें",
    "viewer_config_highlight_todos_checkbox": "TODO को हाइलाइट करें",
    "viewer_config_highlight_todos_checkbox_accessible_description": "पाठ में TODO टैग को महत्वपूर्ण बनाएं",
    "viewer_config_open_link_confirmation_checkbox": "लिंक खोलने के लिए पुष्टि की आवश्यकता",
    "viewer_config_open_link_confirmation_checkbox_accessible_description":
        "लिंक खोलने से पहले पुष्टि की आवश्यकता है",
    "viewer_config_save_resources_checkbox": "बाहरी छवियों को डिस्क में स्वचालित रूप से सहेजें",
    "viewer_config_save_resources_checkbox_accessible_description":
        "ऑफ़लाइन पहुंच के लिए बाहरी छवियों की स्वचालित प्रतिलिपियाँ डिस्क में सहेजें।",

    "ai_config_inference_module_label": "अनुमान मॉड्यूल",
    "ai_config_inference_module_names_combo_label": "सक्रिय अनुमान मॉड्यूल",
    "ai_config_inference_module_names_combo_placeholder_text": "मॉड्यूल चुनें",
    "ai_config_inference_module_names_combo_accessible_description":
        "AI सहायक के साथ संचालन के लिए उपलब्ध AI अनुमान मॉड्यूलों में से चुनें।\n"
        "विकल्पों में वास्तविक समय प्रसंस्करण के साथ बड़े भाषा मॉडल (LLM) या API-आधारित कार्यक्षमताएं शामिल हैं।",

    "ai_config_base_label": "मूल पैरामीटर",
    "ai_config_multi_turn_dialogue_checkbox": "संवादी स्मृति के साथ मल्टी-टर्न संवाद",
    "ai_config_multi_turn_dialogue_checkbox_accessible_description":
        "संवादी स्मृति के लिए अंतिम संकेत को बनाए रखने वाला मल्टी-टर्न संवाद सक्षम करें।\n"
        "बंद होने पर, केवल नया संदेश और सिस्टम प्रॉम्प्ट प्रतिक्रिया को प्रभावित करते हैं।",
    "ai_config_convert_to_md_checkbox": "परिणाम को Markdown में बदलें",
    "ai_config_convert_to_md_checkbox_accessible_description":
        "आउटपुट संदेश को Markdown प्रारूप में बदलें।",
}
