# Italian lexemes color_picker_dialog.py
lexemes = {
    "color_picker_title": "Seleziona un colore",

    "color_picker_color_black": "Nero",
    "color_picker_color_silver": "Argento",
    "color_picker_color_gray": "Grigio",
    "color_picker_color_white": "Bianco",
    "color_picker_color_maroon": "Marrone",
    "color_picker_color_red": "Rosso",
    "color_picker_color_purple": "Porpora",
    "color_picker_color_fuchsia": "Fucsia",
    "color_picker_color_green": "Verde",
    "color_picker_color_lime": "Lime",
    "color_picker_color_olive": "Oliva",
    "color_picker_color_yellow": "Giallo",
    "color_picker_color_navy": "Blu marino",
    "color_picker_color_blue": "Blu",
    "color_picker_color_teal": "Verde acqua",
    "color_picker_color_aqua": "Acqua",
    "color_picker_color_aliceblue": "Blu Alice",
    "color_picker_color_antiquewhite": "Bianco antico",
    "color_picker_color_aquamarine": "Acquamarina",
    "color_picker_color_azure": "Azzurro",
    "color_picker_color_beige": "Beige",
    "color_picker_color_bisque": "Biscotto",
    "color_picker_color_blanchedalmond": "Mandorla sbiancata",
    "color_picker_color_blueviolet": "Blu violaceo",
    "color_picker_color_brown": "Marrone",
    "color_picker_color_burlywood": "Legno massiccio",
    "color_picker_color_cadetblue": "Blu cadetto",
    "color_picker_color_chartreuse": "Chartreuse",
    "color_picker_color_chocolate": "Cioccolato",
    "color_picker_color_coral": "Corallo",
    "color_picker_color_cornflowerblue": "Blu fiordaliso",
    "color_picker_color_cornsilk": "Seta di mais",
    "color_picker_color_crimson": "Cremisi",
    "color_picker_color_cyan": "Ciano",
    "color_picker_color_darkblue": "Blu scuro",
    "color_picker_color_darkcyan": "Ciano scuro",
    "color_picker_color_darkgoldenrod": "Oro scuro",
    "color_picker_color_darkgray": "Grigio scuro",
    "color_picker_color_darkgreen": "Verde scuro",
    "color_picker_color_darkkhaki": "Khaki scuro",
    "color_picker_color_darkmagenta": "Magenta scuro",
    "color_picker_color_darkolivegreen": "Verde oliva scuro",
    "color_picker_color_darkorange": "Arancione scuro",
    "color_picker_color_darkorchid": "Orchidea scura",
    "color_picker_color_darkred": "Rosso scuro",
    "color_picker_color_darksalmon": "Salmone scuro",
    "color_picker_color_darkseagreen": "Verde mare scuro",
    "color_picker_color_darkslateblue": "Blu ardesia scuro",
    "color_picker_color_darkslategray": "Grigio ardesia scuro",
    "color_picker_color_darkturquoise": "Turchese scuro",
    "color_picker_color_darkviolet": "Viola scuro",
    "color_picker_color_deeppink": "Rosa profondo",
    "color_picker_color_deepskyblue": "Blu cielo profondo",
    "color_picker_color_dimgray": "Grigio tenue",
    "color_picker_color_dodgerblue": "Blu dodger",
    "color_picker_color_firebrick": "Mattone",
    "color_picker_color_floralwhite": "Bianco floreale",
    "color_picker_color_forestgreen": "Verde foresta",
    "color_picker_color_gainsboro": "Gainsboro",
    "color_picker_color_ghostwhite": "Bianco fantasma",
    "color_picker_color_gold": "Oro",
    "color_picker_color_goldenrod": "Oro vecchio",
    "color_picker_color_greenyellow": "Verde giallo",
    "color_picker_color_honeydew": "Melata",
    "color_picker_color_hotpink": "Rosa acceso",
    "color_picker_color_indianred": "Rosso indiano",
    "color_picker_color_indigo": "Indaco",
    "color_picker_color_ivory": "Avorio",
    "color_picker_color_khaki": "Khaki",
    "color_picker_color_lavender": "Lavanda",
    "color_picker_color_lavenderblush": "Lavanda chiara",
    "color_picker_color_lawngreen": "Verde prato",
    "color_picker_color_lemonchiffon": "Chiffon limone",
    "color_picker_color_lightblue": "Blu chiaro",
    "color_picker_color_lightcoral": "Corallo chiaro",
    "color_picker_color_lightcyan": "Ciano chiaro",
    "color_picker_color_lightgoldenrodyellow": "Giallo oro chiaro",
    "color_picker_color_lightgray": "Grigio chiaro",
    "color_picker_color_lightgreen": "Verde chiaro",
    "color_picker_color_lightpink": "Rosa chiaro",
    "color_picker_color_lightsalmon": "Salmone chiaro",
    "color_picker_color_lightseagreen": "Verde mare chiaro",
    "color_picker_color_lightskyblue": "Blu cielo chiaro",
    "color_picker_color_lightslategray": "Grigio ardesia chiaro",
    "color_picker_color_lightsteelblue": "Blu acciaio chiaro",
    "color_picker_color_lightyellow": "Giallo chiaro",
    "color_picker_color_limegreen": "Verde lime",
    "color_picker_color_linen": "Lino",
    "color_picker_color_magenta": "Magenta",
    "color_picker_color_mediumaquamarine": "Acquamarina medio",
    "color_picker_color_mediumblue": "Blu medio",
    "color_picker_color_mediumorchid": "Orchidea media",
    "color_picker_color_mediumpurple": "Porpora medio",
    "color_picker_color_mediumseagreen": "Verde mare medio",
    "color_picker_color_mediumslateblue": "Blu ardesia medio",
    "color_picker_color_mediumspringgreen": "Verde primavera medio",
    "color_picker_color_mediumturquoise": "Turchese medio",
    "color_picker_color_mediumvioletred": "Rosso violetto medio",
    "color_picker_color_midnightblue": "Blu mezzanotte",
    "color_picker_color_mintcream": "Crema di menta",
    "color_picker_color_mistyrose": "Rosa nebbia",
    "color_picker_color_moccasin": "Mocassino",
    "color_picker_color_navajowhite": "Bianco Navajo",
    "color_picker_color_oldlace": "Pizzo antico",
    "color_picker_color_olivedrab": "Oliva opaco",
    "color_picker_color_orange": "Arancione",
    "color_picker_color_orangered": "Rosso arancio",
    "color_picker_color_orchid": "Orchidea",
    "color_picker_color_palegoldenrod": "Oro pallido",
    "color_picker_color_palegreen": "Verde pallido",
    "color_picker_color_paleturquoise": "Turchese pallido",
    "color_picker_color_palevioletred": "Rosso violetto pallido",
    "color_picker_color_papayawhip": "Papaya",
    "color_picker_color_peachpuff": "Pesca",
    "color_picker_color_peru": "Perù",
    "color_picker_color_pink": "Rosa",
    "color_picker_color_plum": "Prugna",
    "color_picker_color_powderblue": "Blu polvere",
    "color_picker_color_rebeccapurple": "Porpora Rebecca",
    "color_picker_color_rosybrown": "Marrone rosato",
    "color_picker_color_royalblue": "Blu reale",
    "color_picker_color_saddlebrown": "Marrone sella",
    "color_picker_color_salmon": "Salmone",
    "color_picker_color_sandybrown": "Marrone sabbia",
    "color_picker_color_seagreen": "Verde mare",
    "color_picker_color_seashell": "Conchiglia",
    "color_picker_color_sienna": "Terra di Siena",
    "color_picker_color_skyblue": "Blu cielo",
    "color_picker_color_slateblue": "Blu ardesia",
    "color_picker_color_slategray": "Grigio ardesia",
    "color_picker_color_snow": "Neve",
    "color_picker_color_springgreen": "Verde primavera",
    "color_picker_color_steelblue": "Blu acciaio",
    "color_picker_color_tan": "Cuoio",
    "color_picker_color_thistle": "Cardo",
    "color_picker_color_tomato": "Pomodoro",
    "color_picker_color_turquoise": "Turchese",
    "color_picker_color_violet": "Viola",
    "color_picker_color_wheat": "Grano",
    "color_picker_color_whitesmoke": "Fumo bianco",
    "color_picker_color_yellowgreen": "Verde giallastro",
}
