# Dutch lexemes main_menu.py
lexemes = {
    "group_file_label": "Bestand",
    "group_edit_label": "Bewerken",
    "group_tools_label": "Gereedschappen",
    "group_help_label": "Hulp",

    "actions_file_label_new_document": "Nieuw document",
    "actions_file_accessible_name_new_document": "Nieuw document",
    "actions_file_label_open": "Openen",
    "actions_file_accessible_name_open": "Document openen",
    "actions_file_label_save": "Opslaan",
    "actions_file_accessible_name_save": "Document opslaan",
    "actions_file_label_save_as": "Opslaan als",
    "actions_file_accessible_name_save_as": "Opslaan als documentkopie",
    "actions_file_label_settings": "Instellingen",
    "actions_file_accessible_name_settings": "App instellingen",
    "actions_file_label_reset_settings": "Instellingen resetten",
    "actions_file_accessible_name_reset_settings": "Instellingen resetten",
    "actions_file_label_exit": "Afsluiten",
    "actions_file_accessible_name_exit": "De app verlaten",

    "actions_edit_edit_mode": "Bewerken",
    "actions_edit_accessible_name_edit_mode": "Bestand bewerken",
    "actions_edit_source_mode": "Bron",
    "actions_edit_accessible_name_source_mode": "Broncode",
    "actions_edit_bold": "Vet",
    "actions_edit_accessible_name_bold": "Tekst in vetformaat",
    "actions_edit_italic": "Cursief",
    "actions_edit_accessible_name_italic": "Tekst in cursief formaat",
    "actions_edit_underline": "Onderstrepen",
    "actions_edit_accessible_name_underline": "Tekst onderstrepen",
    "actions_edit_strikethrough": "Doorhalen",
    "actions_edit_accessible_name_strikethrough": "Tekst doorhalen",
    "actions_edit_blockquote": "Citaat",
    "actions_edit_accessible_name_blockquote": "Tekst in citaatformaat",

    "actions_tools_ai_assistant": "AI Assistent",
    "actions_tools_accessible_name_ai_assistant": "AI Assistent starten",
    "actions_tools_color_picker": "Kleurkiezer",
    "actions_tools_accessible_name_color_picker": "Kies een tekstkleur",

    "actions_help_label_md_syntax": "Markdown-syntax",
    "actions_help_accessible_name_md_syntax": "Markdown-syntax",
    "actions_help_label_check_for_updates": "Controleer op updates",
    "actions_help_accessible_name_check_for_updates": "Controleer op updates",
    "actions_help_label_bug_report": "Bugrapport",
    "actions_help_accessible_name_bug_report": "Bugrapport indienen",
    "actions_help_label_about": "Over",
    "actions_help_accessible_name_about": "Over",
}
