# Dutch lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "Nieuw document",
    "actions_accessible_name_new_document": "Nieuw document",
    "actions_label_open": "Openen",
    "actions_accessible_name_open": "Document openen",
    "actions_label_save": "Opslaan",
    "actions_accessible_name_save": "Document opslaan",
    "actions_label_save_as": "Opslaan als",
    "actions_accessible_name_save_as": "Documentkopie opslaan",
    "actions_label_sync": "Synchroniseren",
    "actions_accessible_name_sync": "Document synchroniseren met externe opslag",
    "actions_label_edit": "Bewerken",
    "actions_accessible_name_edit": "Bestand bewerken",
    "actions_label_source": "Bron",
    "actions_accessible_name_source": "Broncode",
    "actions_label_encrypt": "Versleutelen",
    "actions_accessible_name_encrypt": "Bestand versleutelen",
    "actions_label_decrypt": "Decrypteren",
    "actions_accessible_name_decrypt": "Bestand decrypteren",
    "actions_label_bold": "Vet",
    "actions_accessible_name_bold": "Tekst vetgedrukt maken",
    "actions_label_italic": "Cursief",
    "actions_accessible_name_italic": "Tekst cursiveren",
    "actions_label_underline": "Onderstrepen",
    "actions_accessible_name_underline": "Tekst onderstrepen",
    "actions_label_strikethrough": "Doorhalen",
    "actions_accessible_name_strikethrough": "Tekst doorhalen",
    "actions_label_blockquote": "Citaat",
    "actions_accessible_name_blockquote": "Tekst als citaat opmaken",
    "actions_label_color_picker": "Kleurenkiezer",
    "actions_accessible_name_color_picker": "Tekstkleur kiezen",
    "actions_label_ai_assistant": "AI Assistent",
    "actions_accessible_name_ai_assistant": "AI Assistent starten",
    "actions_label_about": "Over",
    "actions_accessible_name_about": "Over de app",
    "actions_label_exit": "Afsluiten",
    "actions_accessible_name_exit": "De app afsluiten",
    "actions_label_settings": "Instellingen",
    "actions_accessible_name_settings": "App instellingen",

    "search_input_label": "Zoeken",
    "search_input_placeholder_text": "Zoek tekst in het document",
    "search_input_accessible_description": "Zoekveld",
    "search_buttons_label_clear": "Zoekopdracht wissen",
    "search_buttons_accessible_name_clear": "Zoekveld leegmaken",
    "search_buttons_label_prev": "Vorige zoeken",
    "search_buttons_accessible_name_prev": "Vorig zoekresultaat",
    "search_buttons_label_next": "Volgende zoeken",
    "search_buttons_accessible_name_next": "Volgend zoekresultaat",
    "search_case_sensitive_accessible_name": "Hoofdlettergevoelig",
    "search_case_sensitive_tooltip": "Zoeken met hoofdlettergevoeligheid",
}
