# French lexemes ai_assistant.py
lexemes = {
    # Assistant IA
    "dialog_title": "Requête à l'IA",
    "dialog_prompt_input_placeholder_text": "Requête",
    "dialog_prompt_input_accessible_description": "Entrer une requête pour donner un contexte à l'assistant IA",
    "dialog_response_output_placeholder_text": "Données de réponse",
    "dialog_response_output_accessible_description": "Les données de réponse apparaîtront dans ce champ",
    "dialog_response_output_notice_empty_text": "Fournissez une saisie de texte pour obtenir une réponse d'environ...",

    "dialog_usage_module_label": "MODULE",
    "dialog_usage_model_label": "MODÈLE",
    "dialog_usage_tokens_label": "JETONS",
    "dialog_usage_tokens_prompt": "invite : {tokens}",
    "dialog_usage_tokens_answer": "réponse : {tokens}",
    "dialog_usage_tokens_total": "total : {tokens}",

    "dialog_button_send_request": "Envoyer la requête",
    "dialog_button_stop_request": "Arrêter",
    "dialog_button_save_history": "Enregistrer l'historique du dialogue",

    "dialog_message_copy_tooltip": "Copier le texte",
    "dialog_message_copied_tooltip": "Copié",

    "dialog_error_loading_model": "Erreur lors du chargement du modèle personnalisé",
}
