# Georgian lexemes settings_dialog.py
lexemes = {
    # პარამეტრების დიალოგი
    "window_title": "პარამეტრები",

    "button_close": "დახურვა",

    "tab_general": "ძირითადი",
    "tab_editor_config": "რედაქტორი",
    "tab_viewer_config": "დამკვრელი",
    "tab_ai_config": "AI კონფიგურაცია",

    "general_app_config_label": "აპლიკაციის კონფიგურაცია",
    "general_app_language_label": "ენა",
    "general_app_language_combo_placeholder_text": "აირჩიეთ ენა",
    "general_app_language_combo_accessible_description": "აპლიკაციის ინტერფეისის ენა",
    "general_app_theme_label": "თემა",
    "general_app_theme_combo_placeholder_text": "აირჩიეთ თემა",
    "general_app_theme_combo_accessible_description": "აპლიკაციის ინტერფეისის თემა",
    "general_app_main_menu_label": "მთავარი მენიუ",
    "general_app_main_menu_checkbox": "მთავარი მენიუს ჩვენება",
    "general_app_main_menu_checkbox_accessible_description": "აჩვენეთ აპლიკაციის მთავარი ჩამოშლილი მენიუ",
    "general_app_font_size_label": "შრიფტის ზომა: {size}pt",
    "general_app_font_size_slider_accessible_description": "შრიფტის გლობალური ზომის რეგულირება",

    "general_statusbar_label": "სტატუსის ზოლი",
    "general_statusbar_show_global_cursor_position_checkbox": "მსოფლიო კურსორის პოზიციის ჩვენება",
    "general_statusbar_show_global_cursor_position_checkbox_accessible_description":
        "აჩვენეთ კურსორის მსოფლიო პოზიცია სტატუსის ზოლში",

    "editor_config_label": "რედაქტორის კონფიგურაცია",
    "editor_config_show_line_numbers_checkbox": "ხაზების ნომრების ჩვენება",
    "editor_config_show_line_numbers_checkbox_accessible_description": "ხაზების ნომრების ჩვენება რედაქტორში",

    "viewer_config_label": "დამკვრელის კონფიგურაცია",
    "viewer_config_process_emojis_checkbox": "ტექსტური ემოჯის გრაფიკულად გარდაქმნა",
    "viewer_config_process_emojis_checkbox_accessible_description": "ტექსტური ემოჯების გრაფიკული წარმოჩენა",
    "viewer_config_highlight_todos_checkbox": "TODO-ების გამოყოფა",
    "viewer_config_highlight_todos_checkbox_accessible_description": "TODO ტეგების გამოყოფა ტექსტში",
    "viewer_config_open_link_confirmation_checkbox": "ბმულების გახსნის დასტური",
    "viewer_config_open_link_confirmation_checkbox_accessible_description":
        "ბმულების გახსნისას დასტურის მოთხოვნა",
    "viewer_config_save_resources_checkbox": "გარე სურათების ავტომატური შენახვა დისკზე",
    "viewer_config_save_resources_checkbox_accessible_description":
        "გარე სურათების ასლების ავტომატურად შენახვა დისკზე ოფლაინ წვდომისთვის.",

    "ai_config_inference_module_label": "ინფერენციის მოდული",
    "ai_config_inference_module_names_combo_label": "აქტიური ინფერენციის მოდული",
    "ai_config_inference_module_names_combo_placeholder_text": "აირჩიეთ მოდული",
    "ai_config_inference_module_names_combo_accessible_description":
        "აირჩიეთ AI ასისტენტთან მუშაობადი არსებული AI ინფერენციის მოდულებიდან.\n"
        "ოფციები მოიცავს ლოკალური დიდი ენის მოდელებს (LLM) რეალური დროის დამუშავებით,\n"
        "ან API-ზე დაყრდნობითი ფუნქციონალობით.",

    "ai_config_base_label": "ძირითადი პარამეტრები",
    "ai_config_multi_turn_dialogue_checkbox": "მრავალშრიანი დიალოგი საუბრის მეხსიერებით",
    "ai_config_multi_turn_dialogue_checkbox_accessible_description":
        "ჩართეთ მრავალშრიანი დიალოგი, რომელიც ინახავს წინა მოთხოვნას საუბრის მეხსიერებისთვის.\n"
        "გამორთვის შემთხვევაში, მხოლოდ ახალი შეტყობინება და სისტემის პრომპტი ახდენენ გავლენას პასუხზე.",
    "ai_config_convert_to_md_checkbox": "შედეგის Markdown-ში კონვერტაცია",
    "ai_config_convert_to_md_checkbox_accessible_description":
        "გადაიყვანეთ გამოსახული შეტყობინება Markdown ფორმატში.",
}
