# Finnish lexemes common.py
lexemes = {
    # Common
    "module_ondevice_llm_name": "Laitteessa LLM",

    "module_ondevice_llm_model_exception": "Mallia ei löydy virhe: {error_msg}",
    "module_ondevice_llm_task_exception": "Malligeneraattoria ei voi alustaa: {error_msg}",
}
