# Portuguese lexemes main_menu.py
lexemes = {
    "group_file_label": "Arquivo",
    "group_edit_label": "Editar",
    "group_tools_label": "Ferramentas",
    "group_help_label": "Ajuda",

    "actions_file_label_new_document": "Novo documento",
    "actions_file_accessible_name_new_document": "Novo documento",
    "actions_file_label_open": "Abrir",
    "actions_file_accessible_name_open": "Abrir documento",
    "actions_file_label_save": "Salvar",
    "actions_file_accessible_name_save": "Salvar documento",
    "actions_file_label_save_as": "Salvar como",
    "actions_file_accessible_name_save_as": "Salvar como cópia do documento",
    "actions_file_label_settings": "Configurações",
    "actions_file_accessible_name_settings": "Configurações do aplicativo",
    "actions_file_label_reset_settings": "Redefinir configurações",
    "actions_file_accessible_name_reset_settings": "Redefinir configurações",
    "actions_file_label_exit": "Sair do aplicativo",
    "actions_file_accessible_name_exit": "Sair do aplicativo",

    "actions_edit_edit_mode": "Editar",
    "actions_edit_accessible_name_edit_mode": "Editar arquivo",
    "actions_edit_source_mode": "Fonte",
    "actions_edit_accessible_name_source_mode": "Código-fonte",
    "actions_edit_bold": "Negrito",
    "actions_edit_accessible_name_bold": "Formato de texto em negrito",
    "actions_edit_italic": "Itálico",
    "actions_edit_accessible_name_italic": "Formato de texto em itálico",
    "actions_edit_underline": "Sublinhado",
    "actions_edit_accessible_name_underline": "Formato de texto sublinhado",
    "actions_edit_strikethrough": "Riscado",
    "actions_edit_accessible_name_strikethrough": "Formato de texto riscado",
    "actions_edit_blockquote": "Citação",
    "actions_edit_accessible_name_blockquote": "Formato de texto de citação",

    "actions_tools_ai_assistant": "Assistente de IA",
    "actions_tools_accessible_name_ai_assistant": "Lançar Assistente de IA",
    "actions_tools_color_picker": "Seletor de Cor",
    "actions_tools_accessible_name_color_picker": "Escolher uma cor para o texto",

    "actions_help_label_md_syntax": "Sintaxe Markdown",
    "actions_help_accessible_name_md_syntax": "Sintaxe Markdown",
    "actions_help_label_check_for_updates": "Verificar atualizações",
    "actions_help_accessible_name_check_for_updates": "Verificar atualizações",
    "actions_help_label_bug_report": "Relatar bug",
    "actions_help_accessible_name_bug_report": "Enviar relatório de bug",
    "actions_help_label_about": "Sobre",
    "actions_help_accessible_name_about": "Sobre",
}
