# Japanese lexemes ai_assistant.py
lexemes = {
    # AI アシスタント
    "dialog_title": "AI へのリクエスト",
    "dialog_prompt_input_placeholder_text": "リクエスト",
    "dialog_prompt_input_accessible_description": "AIアシスタントにコンテキストを提供するためのリクエスト入力",
    "dialog_response_output_placeholder_text": "応答データ",
    "dialog_response_output_accessible_description": "応答データはこのフィールドに表示されます",
    "dialog_response_output_notice_empty_text": "テキスト入力を提供して、約...",

    "dialog_usage_module_label": "モジュール",
    "dialog_usage_model_label": "モデル",
    "dialog_usage_tokens_label": "トークン",
    "dialog_usage_tokens_prompt": "プロンプト: {tokens}",
    "dialog_usage_tokens_answer": "回答: {tokens}",
    "dialog_usage_tokens_total": "合計: {tokens}",

    "dialog_button_send_request": "リクエストを送信",
    "dialog_button_stop_request": "停止",
    "dialog_button_save_history": "対話履歴を保存する",

    "dialog_message_copy_tooltip": "テキストをコピー",
    "dialog_message_copied_tooltip": "コピーしました",

    "dialog_error_loading_model": "カスタムモデルのロードエラー",
}
