# Japanese lexemes common.py
lexemes = {
    "module_llama_cpp_name": "モジュール llama.cpp",

    "module_llama_cpp_model_exception": "モデルが見つからないエラー: {error_msg}",
    "module_llama_cpp_task_exception": "モデルジェネレータを初期化できません: {error_msg}",
}
