# Greek lexemes ai_assistant.py
lexemes = {
    # Διάλογος βοηθού AI
    "dialog_title": "Αίτηση προς το AI",
    "dialog_prompt_input_placeholder_text": "Αίτηση",
    "dialog_prompt_input_accessible_description": "Εισαγωγή αιτήματος για να δώσετε πλαίσιο στον βοηθό AI",
    "dialog_response_output_placeholder_text": "Δεδομένα απόκρισης",
    "dialog_response_output_accessible_description": "Τα δεδομένα απόκρισης θα εμφανιστούν σε αυτό το πεδίο",
    "dialog_response_output_notice_empty_text": "Παρέχετε εισαγωγή κειμένου για να λάβετε μια απάντηση περίπου...",

    "dialog_usage_module_label": "ΜΟΔΟΥΛΟ",
    "dialog_usage_model_label": "ΜΟΝΤΕΛΟ",
    "dialog_usage_tokens_label": "ΔΙΑΚΡΙΤΙΚΑ",
    "dialog_usage_tokens_prompt": "prompt: {tokens}",
    "dialog_usage_tokens_answer": "answer: {tokens}",
    "dialog_usage_tokens_total": "total: {tokens}",

    "dialog_button_send_request": "Αποστολή Αιτήματος",
    "dialog_button_stop_request": "Διακοπή",
    "dialog_button_save_history": "Αποθήκευση ιστορικού διαλόγου",

    "dialog_message_copy_tooltip": "Αντιγραφή κειμένου",
    "dialog_message_copied_tooltip": "Αντιγράφηκε",

    "dialog_error_loading_model": "Σφάλμα φόρτωσης προσαρμοσμένου μοντέλου",
}
