# Korean lexemes settings_dialog.py
lexemes = {
    # 설정
    "window_title": "설정",

    "button_close": "닫기",

    "tab_general": "일반",
    "tab_editor_config": "편집기",
    "tab_viewer_config": "뷰어",
    "tab_ai_config": "AI 설정",

    "general_app_config_label": "앱 설정",
    "general_app_language_label": "언어",
    "general_app_language_combo_placeholder_text": "언어 선택",
    "general_app_language_combo_accessible_description": "앱의 인터페이스 언어",
    "general_app_theme_label": "테마",
    "general_app_theme_combo_placeholder_text": "테마 선택",
    "general_app_theme_combo_accessible_description": "앱의 인터페이스 테마",
    "general_app_main_menu_label": "메인 메뉴",
    "general_app_main_menu_checkbox": "메인 메뉴 보기",
    "general_app_main_menu_checkbox_accessible_description": "앱의 주요 드롭다운 메뉴 표시",
    "general_app_font_size_label": "글꼴 크기: {size}pt",
    "general_app_font_size_slider_accessible_description": "앱의 전역 글꼴 크기 조정",

    "general_statusbar_label": "상태 바",
    "general_statusbar_show_global_cursor_position_checkbox": "전역 커서 위치 보기",
    "general_statusbar_show_global_cursor_position_checkbox_accessible_description":
        "상태 바에서 전역 커서 위치 표시",

    "editor_config_label": "편집기 설정",
    "editor_config_show_line_numbers_checkbox": "줄 번호 표시",
    "editor_config_show_line_numbers_checkbox_accessible_description": "편집기에서 줄 번호 표시",

    "viewer_config_label": "뷰어 설정",
    "viewer_config_process_emojis_checkbox": "텍스트 이모지를 그래픽으로 변환",
    "viewer_config_process_emojis_checkbox_accessible_description": "텍스트 이모지를 그래픽 표현으로 변환",
    "viewer_config_highlight_todos_checkbox": "할 일 하이라이트",
    "viewer_config_highlight_todos_checkbox_accessible_description": "텍스트 내 할 일 태그 강조",
    "viewer_config_open_link_confirmation_checkbox": "링크 열기 전 확인 요구",
    "viewer_config_open_link_confirmation_checkbox_accessible_description":
        "링크를 열기 전에 확인 요청",
    "viewer_config_save_resources_checkbox": "외부 이미지를 디스크에 자동 저장",
    "viewer_config_save_resources_checkbox_accessible_description":
        "오프라인 액세스를 위해 외부 이미지의 복사본을 디스크에 자동으로 저장합니다.",

    "ai_config_inference_module_label": "추론 모듈",
    "ai_config_inference_module_names_combo_label": "활성 추론 모듈",
    "ai_config_inference_module_names_combo_placeholder_text": "모듈 선택",
    "ai_config_inference_module_names_combo_accessible_description":
        "AI 어시스턴트와 함께 작동할 수 있는 사용 가능한 AI 추론 모듈을 선택하세요.\n"
        "옵션에는 실시간 처리가 가능한 대형 언어 모델(LLM) 또는 API 기반 기능이 포함됩니다.",

    "ai_config_base_label": "기본 매개변수",
    "ai_config_multi_turn_dialogue_checkbox": "대화 메모리를 가진 다중 턴 대화",
    "ai_config_multi_turn_dialogue_checkbox_accessible_description":
        "대화 메모리를 유지하는 다중 턴 대화를 활성화합니다.\n"
        "비활성화되면 새 메시지와 시스템 프롬프트만 응답에 영향을 미칩니다.",
    "ai_config_convert_to_md_checkbox": "결과를 Markdown으로 변환",
    "ai_config_convert_to_md_checkbox_accessible_description":
        "출력 메시지를 Markdown 형식으로 변환합니다.",
}
