# Georgian lexemes color_picker_dialog.py
lexemes = {
    "color_picker_title": "ფერის არჩევა",

    "color_picker_color_black": "შავი",
    "color_picker_color_silver": "ვერცხლისფერი",
    "color_picker_color_gray": "ნაცრისფერი",
    "color_picker_color_white": "თეთრი",
    "color_picker_color_red": "წითელი",
    "color_picker_color_purple": "იისფერი",
    "color_picker_color_fuchsia": "ფუქსია",
    "color_picker_color_green": "მწვანე",
    "color_picker_color_lime": "ლაიმი",
    "color_picker_color_olive": "ზეთისფერი",
    "color_picker_color_yellow": "ყვითელი",
    "color_picker_color_navy": "ზღვისფერი",
    "color_picker_color_blue": "ლურჯი",
    "color_picker_color_teal": "ტეალი",
    "color_picker_color_aqua": "აკვა",
    "color_picker_color_aliceblue": "ალისის ლურჯი",
    "color_picker_color_antiquewhite": "ანტიკური თეთრი",
    "color_picker_color_aquamarine": "აკვამარინი",
    "color_picker_color_azure": "ცისფერი",
    "color_picker_color_beige": "ბეჟი",
    "color_picker_color_bisque": "ბისკვიტისფერი",
    "color_picker_color_blanchedalmond": "მუქი ნიგოზისფერი",
    "color_picker_color_blueviolet": "ლურჯი იისფერი",
    "color_picker_color_brown": "ყავისფერი",
    "color_picker_color_burlywood": "ბალახისფერი",
    "color_picker_color_cadetblue": "კადეტის ლურჯი",
    "color_picker_color_chartreuse": "ჩარტრიუზი",
    "color_picker_color_chocolate": "შოკოლადისფერი",
    "color_picker_color_coral": "კორალისფერი",
    "color_picker_color_cornflowerblue": "საზამთრო ლურჯი",
    "color_picker_color_cornsilk": "კალათისფერი",
    "color_picker_color_crimson": "წითელი",
    "color_picker_color_cyan": "ციანი",
    "color_picker_color_darkblue": "მუქი ლურჯი",
    "color_picker_color_darkcyan": "მუქი ციანი",
    "color_picker_color_darkgoldenrod": "მუქი ოქროსფერი",
    "color_picker_color_darkgray": "მუქი ნაცრისფერი",
    "color_picker_color_darkgreen": "მუქი მწვანე",
    "color_picker_color_darkkhaki": "მუქი ხაკი",
    "color_picker_color_darkmagenta": "მუქი მაგენტა",
    "color_picker_color_darkolivegreen": "მუქი ზეთისფერი",
    "color_picker_color_darkorange": "მუქი ორანჟი",
    "color_picker_color_darkorchid": "მუქი ორქიდეა",
    "color_picker_color_darkred": "მუქი წითელი",
    "color_picker_color_darksalmon": "მუქი ლოსოსფერი",
    "color_picker_color_darkseagreen": "მუქი ზღვის მწვანე",
    "color_picker_color_darkslateblue": "მუქი დაფნის ლურჯი",
    "color_picker_color_darkslategray": "მუქი დაფნის ნაცრისფერი",
    "color_picker_color_darkturquoise": "მუქი ტურქული ლურჯი",
    "color_picker_color_darkviolet": "მუქი იისფერი",
    "color_picker_color_deeppink": "ღრმა ვარდისფერი",
    "color_picker_color_deepskyblue": "ღრმა ცის ლურჯი",
    "color_picker_color_dimgray": "ბნელი ნაცრისფერი",
    "color_picker_color_dodgerblue": "დოჯერის ლურჯი",
    "color_picker_color_firebrick": "ცეცხლოვანი ყავისფერი",
    "color_picker_color_floralwhite": "ფლორალური თეთრი",
    "color_picker_color_forestgreen": "ტყის მწვანე",
    "color_picker_color_gainsboro": "გეინსბოროს ფერი",
    "color_picker_color_ghostwhite": "მკაცრი თეთრი",
    "color_picker_color_gold": "ოქროსფერი",
    "color_picker_color_goldenrod": "ოქროს ქვეითი",
    "color_picker_color_greenyellow": "მწვანე-ყვითელი",
    "color_picker_color_honeydew": "თაფლის წვეთი",
    "color_picker_color_hotpink": "ცხელი ვარდისფერი",
    "color_picker_color_indianred": "ინდური წითელი",
    "color_picker_color_indigo": "ინდიგო",
    "color_picker_color_ivory": "ზურმუხტისფერი",
    "color_picker_color_khaki": "ხაკი",
    "color_picker_color_lavender": "ლავანდა",
    "color_picker_color_lavenderblush": "ლავანდას ფერი",
    "color_picker_color_lawngreen": "მწვანე ბალახი",
    "color_picker_color_lemonchiffon": "ლიმონის ჩიფონი",
    "color_picker_color_lightblue": "ღია ლურჯი",
    "color_picker_color_lightcoral": "ღია კორალისფერი",
    "color_picker_color_lightcyan": "ღია ციანი",
    "color_picker_color_lightgoldenrodyellow": "ღია ოქროს ფერი",
    "color_picker_color_lightgray": "ღია ნაცრისფერი",
    "color_picker_color_lightgreen": "ღია მწვანე",
    "color_picker_color_lightpink": "ღია ვარდისფერი",
    "color_picker_color_lightsalmon": "ღია ლოსოსფერი",
    "color_picker_color_lightseagreen": "ღია ზღვის მწვანე",
    "color_picker_color_lightskyblue": "ღია ცის ლურჯი",
    "color_picker_color_lightslategray": "ღია დაფნის ნაცრისფერი",
    "color_picker_color_lightsteelblue": "ღია ფოლადის ლურჯი",
    "color_picker_color_lightyellow": "ღია ყვითელი",
    "color_picker_color_limegreen": "ლაიმის მწვანე",
    "color_picker_color_linen": "ბეწვისფერი",
    "color_picker_color_magenta": "მაგენტა",
    "color_picker_color_maroon": "მუქი წითელი",
    "color_picker_color_mediumaquamarine": "საშუალო აკვამარინი",
    "color_picker_color_mediumblue": "საშუალო ლურჯი",
    "color_picker_color_mediumorchid": "საშუალო ორქიდეა",
    "color_picker_color_mediumpurple": "საშუალო იისფერი",
    "color_picker_color_mediumseagreen": "საშუალო ზღვის მწვანე",
    "color_picker_color_mediumslateblue": "საშუალო დაფნის ლურჯი",
    "color_picker_color_mediumspringgreen": "საშუალო გაზაფხულის მწვანე",
    "color_picker_color_mediumturquoise": "საშუალო ტურქული ლურჯი",
    "color_picker_color_mediumvioletred": "საშუალო ვარდისფერი",
    "color_picker_color_midnightblue": "შუაღამის ლურჯი",
    "color_picker_color_mintcream": "მინტის კრემი",
    "color_picker_color_mistyrose": "ნაზი ვარდისფერი",
    "color_picker_color_moccasin": "მოკასინისფერი",
    "color_picker_color_navajowhite": "ნავახოს თეთრი",
    "color_picker_color_oldlace": "ძველი ბეწვი",
    "color_picker_color_olivedrab": "ზეთისფერი",
    "color_picker_color_orange": "ორანჟი",
    "color_picker_color_orangered": "მუქი ორანჟი",
    "color_picker_color_orchid": "ორქიდეა",
    "color_picker_color_palegoldenrod": "ღია ოქროსფერი",
    "color_picker_color_palegreen": "ღია მწვანე",
    "color_picker_color_paleturquoise": "ღია ტურქული ლურჯი",
    "color_picker_color_palevioletred": "ღია ვარდისფერი",
    "color_picker_color_papayawhip": "პაპაიის კრემი",
    "color_picker_color_peachpuff": "ატამის კრემი",
    "color_picker_color_peru": "პერუს ფერი",
    "color_picker_color_pink": "ვარდისფერი",
    "color_picker_color_plum": "ქლიავი",
    "color_picker_color_powderblue": "ფხვნილის ლურჯი",
    "color_picker_color_rebeccapurple": "რებეკას იისფერი",
    "color_picker_color_rosybrown": "როზის ყავისფერი",
    "color_picker_color_royalblue": "მეფის ლურჯი",
    "color_picker_color_saddlebrown": "საყელოს ყავისფერი",
    "color_picker_color_salmon": "ლოსოსფერი",
    "color_picker_color_sandybrown": "ქვიშის ყავისფერი",
    "color_picker_color_seagreen": "ზღვის მწვანე",
    "color_picker_color_seashell": "ზღვის ბალახი",
    "color_picker_color_sienna": "სიენის ფერი",
    "color_picker_color_skyblue": "ცის ლურჯი",
    "color_picker_color_slateblue": "დაფნის ლურჯი",
    "color_picker_color_slategray": "დაფნის ნაცრისფერი",
    "color_picker_color_snow": "თოვლისფერი",
    "color_picker_color_springgreen": "გაზაფხულის მწვანე",
    "color_picker_color_steelblue": "ფოლადის ლურჯი",
    "color_picker_color_tan": "შამფურინისფერი",
    "color_picker_color_thistle": "ბალის ფერი",
    "color_picker_color_tomato": "პომიდორისფერი",
    "color_picker_color_turquoise": "ტურქული ლურჯი",
    "color_picker_color_violet": "იისფერი",
    "color_picker_color_wheat": "ხორბლისფერი",
    "color_picker_color_whitesmoke": "თეთრი კვამლი",
    "color_picker_color_yellowgreen": "ყვითელი-მწვანე",
}
