# Latin lexemes settings_dialog.py
lexemes = {
    # Configurationes
    "window_title": "Configurationes",

    "button_close": "Claudere",

    "tab_general": "Generale",
    "tab_editor_config": "Editor",
    "tab_viewer_config": "Visor",
    "tab_ai_config": "Configuratio AI",

    "general_app_config_label": "Configuratio App",
    "general_app_language_label": "Lingua",
    "general_app_language_combo_placeholder_text": "Elige linguam",
    "general_app_language_combo_accessible_description": "Lingua interfaciei app",
    "general_app_theme_label": "Thema",
    "general_app_theme_combo_placeholder_text": "Elige thema",
    "general_app_theme_combo_accessible_description": "Thema interfaciei app",
    "general_app_main_menu_label": "Praecipuum Menu",
    "general_app_main_menu_checkbox": "Praecipuum Menu Ostende",
    "general_app_main_menu_checkbox_accessible_description": "Praecipuum dropdown menu applicationis ostendere",
    "general_app_font_size_label": "Magnitudo Fontis: {size}pt",
    "general_app_font_size_slider_accessible_description": "Regula magnitudinem fontis globalis applicationis",

    "general_statusbar_label": "Status Barra",
    "general_statusbar_show_global_cursor_position_checkbox": "Ostende Globalem Cursoris Positionem",
    "general_statusbar_show_global_cursor_position_checkbox_accessible_description":
        "Ostende globalem cursoris positionem in status barra",

    "editor_config_label": "Editoris Configuratio",
    "editor_config_show_line_numbers_checkbox": "Ostende Numeros Linearum",
    "editor_config_show_line_numbers_checkbox_accessible_description": "Ostende numeros linearum in editor",

    "viewer_config_label": "Visoris Configuratio",
    "viewer_config_process_emojis_checkbox": "Converte Textum Emojis ad Graphica",
    "viewer_config_process_emojis_checkbox_accessible_description":
        "Converte emojis textuales in representationes graphicas",
    "viewer_config_highlight_todos_checkbox": "Illustra TODOs",
    "viewer_config_highlight_todos_checkbox_accessible_description": "In textu TODOs signa illustra",
    "viewer_config_open_link_confirmation_checkbox": "Postulat Confirmationem ad Aperiendum Nexus",
    "viewer_config_open_link_confirmation_checkbox_accessible_description":
        "Quaere confirmationem ante apertionem nexus",
    "viewer_config_save_resources_checkbox": "Serva imagines externas in disco automatice",
    "viewer_config_save_resources_checkbox_accessible_description":
        "Automatice servat exemplaria imaginum externarum in disco ad usum sine nexu.",

    "ai_config_inference_module_label": "Modulus Inferentiae",
    "ai_config_inference_module_names_combo_label": "Modulus Inferentiae Activus",
    "ai_config_inference_module_names_combo_placeholder_text": "Modulum Elige",
    "ai_config_inference_module_names_combo_accessible_description":
        "Elige ex modulis inferentiae AI praesto ut opera cum Auxiliario AI gerantur.\n"
        "Optiones includunt magnos linguarum modelos (LLM) cum processione temporis realis aut functiones\n"
        "quae sunt basis API.",

    "ai_config_base_label": "Parametri Fundamentales",
    "ai_config_multi_turn_dialogue_checkbox": "Dialogus Multiplex cum Memoria Sermonis",
    "ai_config_multi_turn_dialogue_checkbox_accessible_description":
        "Permitte dialogum multiplex qui ultimam praeceptionem ad memoriam sermonis retinet.\n"
        "Si deactivatum, tantum novum nuntium et praeceptum systematis responsionem afficiunt.",
    "ai_config_convert_to_md_checkbox": "Resultatum in Markdown Convertere",
    "ai_config_convert_to_md_checkbox_accessible_description":
        "Convertere nuntium exitu in formam Markdown.",
}
