# Turkish lexemes main_menu.py
lexemes = {
    "group_file_label": "Dosya",
    "group_edit_label": "Düzenle",
    "group_tools_label": "Araçlar",
    "group_help_label": "Yardım",

    "actions_file_label_new_document": "Yeni belge",
    "actions_file_accessible_name_new_document": "Yeni belge",
    "actions_file_label_open": "Aç",
    "actions_file_accessible_name_open": "Belgeyi aç",
    "actions_file_label_save": "Kaydet",
    "actions_file_accessible_name_save": "Belgeyi kaydet",
    "actions_file_label_save_as": "Farklı Kaydet",
    "actions_file_accessible_name_save_as": "Belgeyi kopya olarak kaydet",
    "actions_file_label_settings": "Ayarlar",
    "actions_file_accessible_name_settings": "Uygulama ayarları",
    "actions_file_label_reset_settings": "Ayarları sıfırla",
    "actions_file_accessible_name_reset_settings": "Ayarları sıfırla",
    "actions_file_label_exit": "Çıkış",
    "actions_file_accessible_name_exit": "Uygulamadan çık",

    "actions_edit_edit_mode": "Düzenle",
    "actions_edit_accessible_name_edit_mode": "Dosyayı düzenle",
    "actions_edit_source_mode": "Kaynak",
    "actions_edit_accessible_name_source_mode": "Kaynak kodu",
    "actions_edit_bold": "Kalın",
    "actions_edit_accessible_name_bold": "Kalın metin biçimi",
    "actions_edit_italic": "İtalik",
    "actions_edit_accessible_name_italic": "İtalik metin biçimi",
    "actions_edit_underline": "Altı çizili",
    "actions_edit_accessible_name_underline": "Altı çizili metin biçimi",
    "actions_edit_strikethrough": "Üstü çizili",
    "actions_edit_accessible_name_strikethrough": "Üstü çizili metin biçimi",
    "actions_edit_blockquote": "Alıntı",
    "actions_edit_accessible_name_blockquote": "Alıntı metin biçimi",

    "actions_tools_ai_assistant": "AI Asistanı",
    "actions_tools_accessible_name_ai_assistant": "AI Asistanını Başlat",
    "actions_tools_color_picker": "Renk Seçici",
    "actions_tools_accessible_name_color_picker": "Metin rengi seç",

    "actions_help_label_md_syntax": "Markdown Sözdizimi",
    "actions_help_accessible_name_md_syntax": "Markdown Sözdizimi",
    "actions_help_label_check_for_updates": "Güncellemeleri Denetle",
    "actions_help_accessible_name_check_for_updates": "Güncellemeleri denetle",
    "actions_help_label_bug_report": "Hata Raporu",
    "actions_help_accessible_name_bug_report": "Hata raporu gönder",
    "actions_help_label_about": "Hakkında",
    "actions_help_accessible_name_about": "Hakkında",
}
