# Spanish lexemes color_picker_dialog.py
lexemes = {
    "color_picker_title": "Seleccionar un color",

    "color_picker_color_black": "Negro",
    "color_picker_color_silver": "Plateado",
    "color_picker_color_gray": "Gris",
    "color_picker_color_white": "Blanco",
    "color_picker_color_maroon": "Marrón",
    "color_picker_color_red": "Rojo",
    "color_picker_color_purple": "Púrpura",
    "color_picker_color_fuchsia": "Fucsia",
    "color_picker_color_green": "Verde",
    "color_picker_color_lime": "Lima",
    "color_picker_color_olive": "Oliva",
    "color_picker_color_yellow": "Amarillo",
    "color_picker_color_navy": "Azul marino",
    "color_picker_color_blue": "Azul",
    "color_picker_color_teal": "Verde azulado",
    "color_picker_color_aqua": "Aguamarina",
    "color_picker_color_aliceblue": "Azul Alicia",
    "color_picker_color_antiquewhite": "Blanco antiguo",
    "color_picker_color_aquamarine": "Aguamarina",
    "color_picker_color_azure": "Azur",
    "color_picker_color_beige": "Beige",
    "color_picker_color_bisque": "Bisque",
    "color_picker_color_blanchedalmond": "Almendra blanqueada",
    "color_picker_color_blueviolet": "Violeta azulado",
    "color_picker_color_brown": "Marrón",
    "color_picker_color_burlywood": "Madera",
    "color_picker_color_cadetblue": "Azul cadete",
    "color_picker_color_chartreuse": "Chartreuse",
    "color_picker_color_chocolate": "Chocolate",
    "color_picker_color_coral": "Coral",
    "color_picker_color_cornflowerblue": "Azul aciano",
    "color_picker_color_cornsilk": "Seda de maíz",
    "color_picker_color_crimson": "Carmesí",
    "color_picker_color_cyan": "Cian",
    "color_picker_color_darkblue": "Azul oscuro",
    "color_picker_color_darkcyan": "Cian oscuro",
    "color_picker_color_darkgoldenrod": "Vara de oro oscuro",
    "color_picker_color_darkgray": "Gris oscuro",
    "color_picker_color_darkgreen": "Verde oscuro",
    "color_picker_color_darkkhaki": "Caqui oscuro",
    "color_picker_color_darkmagenta": "Magenta oscuro",
    "color_picker_color_darkolivegreen": "Verde oliva oscuro",
    "color_picker_color_darkorange": "Naranja oscuro",
    "color_picker_color_darkorchid": "Orquídea oscura",
    "color_picker_color_darkred": "Rojo oscuro",
    "color_picker_color_darksalmon": "Salmón oscuro",
    "color_picker_color_darkseagreen": "Verde mar oscuro",
    "color_picker_color_darkslateblue": "Azul pizarra oscuro",
    "color_picker_color_darkslategray": "Gris pizarra oscuro",
    "color_picker_color_darkturquoise": "Turquesa oscuro",
    "color_picker_color_darkviolet": "Violeta oscuro",
    "color_picker_color_deeppink": "Rosa profundo",
    "color_picker_color_deepskyblue": "Azul cielo profundo",
    "color_picker_color_dimgray": "Gris tenue",
    "color_picker_color_dodgerblue": "Azul dodger",
    "color_picker_color_firebrick": "Ladrillo refractario",
    "color_picker_color_floralwhite": "Blanco floral",
    "color_picker_color_forestgreen": "Verde bosque",
    "color_picker_color_gainsboro": "Gainsboro",
    "color_picker_color_ghostwhite": "Blanco fantasma",
    "color_picker_color_gold": "Oro",
    "color_picker_color_goldenrod": "Vara de oro",
    "color_picker_color_greenyellow": "Verde amarillo",
    "color_picker_color_honeydew": "Melón",
    "color_picker_color_hotpink": "Rosa intenso",
    "color_picker_color_indianred": "Rojo indio",
    "color_picker_color_indigo": "Índigo",
    "color_picker_color_ivory": "Marfil",
    "color_picker_color_khaki": "Caqui",
    "color_picker_color_lavender": "Lavanda",
    "color_picker_color_lavenderblush": "Rubor lavanda",
    "color_picker_color_lawngreen": "Verde césped",
    "color_picker_color_lemonchiffon": "Chifón limón",
    "color_picker_color_lightblue": "Azul claro",
    "color_picker_color_lightcoral": "Coral claro",
    "color_picker_color_lightcyan": "Cian claro",
    "color_picker_color_lightgoldenrodyellow": "Amarillo vara de oro claro",
    "color_picker_color_lightgray": "Gris claro",
    "color_picker_color_lightgreen": "Verde claro",
    "color_picker_color_lightpink": "Rosa claro",
    "color_picker_color_lightsalmon": "Salmón claro",
    "color_picker_color_lightseagreen": "Verde mar claro",
    "color_picker_color_lightskyblue": "Azul cielo claro",
    "color_picker_color_lightslategray": "Gris pizarra claro",
    "color_picker_color_lightsteelblue": "Azul acero claro",
    "color_picker_color_lightyellow": "Amarillo claro",
    "color_picker_color_limegreen": "Verde lima",
    "color_picker_color_linen": "Lino",
    "color_picker_color_magenta": "Magenta",
    "color_picker_color_mediumaquamarine": "Aguamarina medio",
    "color_picker_color_mediumblue": "Azul medio",
    "color_picker_color_mediumorchid": "Orquídea media",
    "color_picker_color_mediumpurple": "Púrpura medio",
    "color_picker_color_mediumseagreen": "Verde mar medio",
    "color_picker_color_mediumslateblue": "Azul pizarra medio",
    "color_picker_color_mediumspringgreen": "Verde primavera medio",
    "color_picker_color_mediumturquoise": "Turquesa medio",
    "color_picker_color_mediumvioletred": "Rojo violeta medio",
    "color_picker_color_midnightblue": "Azul medianoche",
    "color_picker_color_mintcream": "Crema de menta",
    "color_picker_color_mistyrose": "Rosa brumoso",
    "color_picker_color_moccasin": "Mocasín",
    "color_picker_color_navajowhite": "Blanco Navajo",
    "color_picker_color_oldlace": "Encaje antiguo",
    "color_picker_color_olivedrab": "Oliva desvaído",
    "color_picker_color_orange": "Naranja",
    "color_picker_color_orangered": "Rojo naranja",
    "color_picker_color_orchid": "Orquídea",
    "color_picker_color_palegoldenrod": "Vara de oro pálido",
    "color_picker_color_palegreen": "Verde pálido",
    "color_picker_color_paleturquoise": "Turquesa pálido",
    "color_picker_color_palevioletred": "Rojo violeta pálido",
    "color_picker_color_papayawhip": "Papaya batida",
    "color_picker_color_peachpuff": "Bofetada de durazno",
    "color_picker_color_peru": "Perú",
    "color_picker_color_pink": "Rosa",
    "color_picker_color_plum": "Ciruela",
    "color_picker_color_powderblue": "Azul talco",
    "color_picker_color_rebeccapurple": "Púrpura Rebecca",
    "color_picker_color_rosybrown": "Marrón rosado",
    "color_picker_color_royalblue": "Azul real",
    "color_picker_color_saddlebrown": "Marrón silla",
    "color_picker_color_salmon": "Salmón",
    "color_picker_color_sandybrown": "Marrón arenoso",
    "color_picker_color_seagreen": "Verde mar",
    "color_picker_color_seashell": "Concha",
    "color_picker_color_sienna": "Siena",
    "color_picker_color_skyblue": "Azul cielo",
    "color_picker_color_slateblue": "Azul pizarra",
    "color_picker_color_slategray": "Gris pizarra",
    "color_picker_color_snow": "Nieve",
    "color_picker_color_springgreen": "Verde primavera",
    "color_picker_color_steelblue": "Azul acero",
    "color_picker_color_tan": "Bronceado",
    "color_picker_color_thistle": "Cardo",
    "color_picker_color_tomato": "Tomate",
    "color_picker_color_turquoise": "Turquesa",
    "color_picker_color_violet": "Violeta",
    "color_picker_color_wheat": "Trigo",
    "color_picker_color_whitesmoke": "Humo blanco",
    "color_picker_color_yellowgreen": "Verde amarillo",
}
