# German lexemes ai_assistant.py
lexemes = {
    # KI-Assistent
    "dialog_title": "Anfrage an KI",
    "dialog_prompt_input_placeholder_text": "Anfrage",
    "dialog_prompt_input_accessible_description": "Anfrage eingeben, um dem KI-Assistenten Kontext zu geben",
    "dialog_response_output_placeholder_text": "Antwortdaten",
    "dialog_response_output_accessible_description": "Antwortdaten erscheinen in diesem Feld",
    "dialog_response_output_notice_empty_text": "Geben Sie einen Text ein, um eine Antwort von etwa...",

    "dialog_usage_module_label": "MODUL",
    "dialog_usage_model_label": "MODELL",
    "dialog_usage_tokens_label": "TOKENS",
    "dialog_usage_tokens_prompt": "prompt: {tokens}",
    "dialog_usage_tokens_answer": "Antwort: {tokens}",
    "dialog_usage_tokens_total": "gesamt: {tokens}",

    "dialog_button_send_request": "Anfrage senden",
    "dialog_button_stop_request": "Stop",
    "dialog_button_save_history": "Dialogverlauf speichern",

    "dialog_message_copy_tooltip": "Text kopieren",
    "dialog_message_copied_tooltip": "Kopiert",

    "dialog_error_loading_model": "Fehler beim Laden des benutzerdefinierten Modells",
}
