# Korean lexemes common.py
lexemes = {
    # Common
    "module_ondevice_llm_name": "기기 내 LLM",

    "module_ondevice_llm_model_exception": "모델을 찾을 수 없음 오류: {error_msg}",
    "module_ondevice_llm_task_exception": "모델 생성기를 초기화할 수 없습니다: {error_msg}",
}
