# Finnish lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "Uusi asiakirja",
    "actions_accessible_name_new_document": "Uusi asiakirja",
    "actions_label_open": "Avaa",
    "actions_accessible_name_open": "Avaa asiakirja",
    "actions_label_save": "Tallenna",
    "actions_accessible_name_save": "Tallenna asiakirja",
    "actions_label_save_as": "Tallenna nimellä",
    "actions_accessible_name_save_as": "Tallenna asiakirjan kopio",
    "actions_label_sync": "Synkronoi",
    "actions_accessible_name_sync": "Synkronoi asiakirja ulkoiseen tallennustilaan",
    "actions_label_edit": "Muokkaa",
    "actions_accessible_name_edit": "Muokkaa tiedostoa",
    "actions_label_source": "Lähdekoodi",
    "actions_accessible_name_source": "Lähdekoodi",
    "actions_label_encrypt": "Salaa",
    "actions_accessible_name_encrypt": "Salaa tiedosto",
    "actions_label_decrypt": "Pura salaus",
    "actions_accessible_name_decrypt": "Pura tiedoston salaus",
    "actions_label_bold": "Lihavointi",
    "actions_accessible_name_bold": "Lihavoi teksti",
    "actions_label_italic": "Kursivointi",
    "actions_accessible_name_italic": "Kursivoi teksti",
    "actions_label_underline": "Alleviivaus",
    "actions_accessible_name_underline": "Alleviivaa teksti",
    "actions_label_strikethrough": "Yliviivaus",
    "actions_accessible_name_strikethrough": "Yliviivaa teksti",
    "actions_label_blockquote": "Lainaus",
    "actions_accessible_name_blockquote": "Lainaa teksti",
    "actions_label_color_picker": "Värinvalitsin",
    "actions_accessible_name_color_picker": "Valitse tekstiväri",
    "actions_label_ai_assistant": "Tekoälyavustaja",
    "actions_accessible_name_ai_assistant": "Käynnistä tekoälyavustaja",
    "actions_label_about": "Tietoja",
    "actions_accessible_name_about": "Tietoja sovelluksesta",
    "actions_label_exit": "Poistu",
    "actions_accessible_name_exit": "Poistu sovelluksesta",
    "actions_label_settings": "Asetukset",
    "actions_accessible_name_settings": "Sovelluksen asetukset",

    "search_input_label": "Haku",
    "search_input_placeholder_text": "Hae tekstiä dokumentista",
    "search_input_accessible_description": "Hakukenttä",
    "search_buttons_label_clear": "Tyhjennä haku",
    "search_buttons_accessible_name_clear": "Tyhjennä hakukenttä",
    "search_buttons_label_prev": "Edellinen haku",
    "search_buttons_accessible_name_prev": "Edellinen hakutulos",
    "search_buttons_label_next": "Seuraava haku",
    "search_buttons_accessible_name_next": "Seuraava hakutulos",
    "search_case_sensitive_accessible_name": "Kirjainkoko merkitsee",
    "search_case_sensitive_tooltip": "Haku kirjainkoolla",
}
