# Finnish lexemes main_menu.py
lexemes = {
    "group_file_label": "Tiedosto",
    "group_edit_label": "Muokkaa",
    "group_tools_label": "Työkalut",
    "group_help_label": "Apua",

    "actions_file_label_new_document": "Uusi asiakirja",
    "actions_file_accessible_name_new_document": "Uusi asiakirja",
    "actions_file_label_open": "Avaa",
    "actions_file_accessible_name_open": "Avaa asiakirja",
    "actions_file_label_save": "Tallenna",
    "actions_file_accessible_name_save": "Tallenna asiakirja",
    "actions_file_label_save_as": "Tallenna nimellä",
    "actions_file_accessible_name_save_as": "Tallenna asiakirjan kopio",
    "actions_file_label_settings": "Asetukset",
    "actions_file_accessible_name_settings": "Sovelluksen asetukset",
    "actions_file_label_reset_settings": "Nollaa asetukset",
    "actions_file_accessible_name_reset_settings": "Nollaa asetukset",
    "actions_file_label_exit": "Poistu",
    "actions_file_accessible_name_exit": "Poistu sovelluksesta",

    "actions_edit_edit_mode": "Muokkaa",
    "actions_edit_accessible_name_edit_mode": "Muokkaa tiedostoa",
    "actions_edit_source_mode": "Lähdekoodi",
    "actions_edit_accessible_name_source_mode": "Lähdekoodi",
    "actions_edit_bold": "Lihavoitu",
    "actions_edit_accessible_name_bold": "Lihavoi teksti",
    "actions_edit_italic": "Kursivoitu",
    "actions_edit_accessible_name_italic": "Kursivoi teksti",
    "actions_edit_underline": "Alleviivaus",
    "actions_edit_accessible_name_underline": "Alleviivaa teksti",
    "actions_edit_strikethrough": "Yliviivaus",
    "actions_edit_accessible_name_strikethrough": "Yliviivaa teksti",
    "actions_edit_blockquote": "Lainaus",
    "actions_edit_accessible_name_blockquote": "Lainaa teksti",

    "actions_tools_ai_assistant": "Tekoälyavustaja",
    "actions_tools_accessible_name_ai_assistant": "Käynnistä tekoälyavustaja",
    "actions_tools_color_picker": "Värinvalitsin",
    "actions_tools_accessible_name_color_picker": "Valitse tekstiväri",

    "actions_help_label_md_syntax": "Markdown-syntaksi",
    "actions_help_accessible_name_md_syntax": "Markdown-syntaksi",
    "actions_help_label_check_for_updates": "Tarkista päivitykset",
    "actions_help_accessible_name_check_for_updates": "Tarkista päivitykset",
    "actions_help_label_bug_report":  "Vikailmoitus",
    "actions_help_accessible_name_bug_report": "Lähetä vikailmoitus",
    "actions_help_label_about": "Tietoja",
    "actions_help_accessible_name_about": "Tietoja",
}
