# Swedish lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "Nytt dokument",
    "actions_accessible_name_new_document": "Nytt dokument",
    "actions_label_open": "Öppna",
    "actions_accessible_name_open": "Öppna dokument",
    "actions_label_save": "Spara",
    "actions_accessible_name_save": "Spara dokument",
    "actions_label_save_as": "Spara som",
    "actions_accessible_name_save_as": "Spara som dokumentkopia",
    "actions_label_sync": "Synkronisera",
    "actions_accessible_name_sync": "Synkronisera dokument med extern lagring",
    "actions_label_edit": "Redigera",
    "actions_accessible_name_edit": "Redigera fil",
    "actions_label_source": "Källkod",
    "actions_accessible_name_source": "Källkod",
    "actions_label_encrypt": "Kryptera",
    "actions_accessible_name_encrypt": "Kryptera fil",
    "actions_label_decrypt": "Dekryptera",
    "actions_accessible_name_decrypt": "Dekryptera fil",
    "actions_label_bold": "Fet",
    "actions_accessible_name_bold": "Fet textformat",
    "actions_label_italic": "Kursiv",
    "actions_accessible_name_italic": "Kursiv textformat",
    "actions_label_underline": "Understrykning",
    "actions_accessible_name_underline": "Understrykningsformat",
    "actions_label_strikethrough": "Genomstrykning",
    "actions_accessible_name_strikethrough": "Genomstrykningsformat",
    "actions_label_blockquote": "Blockcitat",
    "actions_accessible_name_blockquote": "Blockcitatformat",
    "actions_label_color_picker": "Färgväljare",
    "actions_accessible_name_color_picker": "Välj textfärg",
    "actions_label_ai_assistant": "AI-assistent",
    "actions_accessible_name_ai_assistant": "Starta AI-assistent",
    "actions_label_about": "Om",
    "actions_accessible_name_about": "Om appen",
    "actions_label_exit": "Avsluta",
    "actions_accessible_name_exit": "Avsluta appen",
    "actions_label_settings": "Inställningar",
    "actions_accessible_name_settings": "Appinställningar",

    "search_input_label": "Sök",
    "search_input_placeholder_text": "Sök text i dokumentet",
    "search_input_accessible_description": "Sökfält",
    "search_buttons_label_clear": "Rensa sökning",
    "search_buttons_accessible_name_clear": "Rensa sökfält",
    "search_buttons_label_prev": "Föregående sökning",
    "search_buttons_accessible_name_prev": "Föregående sökresultat",
    "search_buttons_label_next": "Nästa sökning",
    "search_buttons_accessible_name_next": "Nästa sökresultat",
    "search_case_sensitive_accessible_name": "Skiftlägeskänslig",
    "search_case_sensitive_tooltip": "Skiftlägeskänslig sökning"
}
