# Latin lexemes settings_dialog.py
lexemes = {
    "tab_openai_api_config": "API OpenAI",

    "module_openai_api_label": "API OpenAI",
    "module_openai_api_url_label": "URL API",
    "module_openai_api_url_input_placeholder_text": "URL API",
    "module_openai_api_url_input_accessible_description":
        "URL OpenAI API est locus terminatio API, qui variare potest secundum officium et versionem.\n"
        "Auxiliarius AI hoc utitur pro functione colloquii aut textus complementis.\n"
        "Ad conspectum hodiernum URL, documenta officialia OpenAI API consulenda sunt.",
    "module_openai_api_key_label": "Clavis API",
    "module_openai_api_key_input_placeholder_text": "Clavis API",
    "module_openai_api_key_input_accessible_description":
        "Clavis API OpenAI est secretum symbolum ad validationem petitionum apud terminationem API.",
    "module_openai_api_supported_models_label": "Modellos sustentata",
    "module_openai_api_model_names_combo_placeholder_text": "Elige Modello",
    "module_openai_api_model_names_combo_accessible_description":
        "Elige inter modellos sustentata pro colloquiis chattationis.",

    "module_openai_api_base_system_prompt_label": "Promptus Systematis",
    "module_openai_api_base_system_prompt_edit_placeholder_text":
        "Promptus systematis basis quae praecedit omnem postulationem",
    "module_openai_api_base_system_prompt_edit_accessible_description":
        "Promptus systematis basis quae praecedit omnem postulationem.\n"
        "Plurimum est textus simplex cum praeceptis vel characteribus muneri.",

    "module_openai_api_base_response_temperature_label": "Temperatura: {temperature}",
    "module_openai_api_base_response_temperature_input_accessible_description":
        "Varietatem responsionum modeli regulat. Valores altiores producunt exitus magis variatos, "
        "dum valores inferiores responsiones magis praedicibiles faciunt.",

    "module_openai_api_base_response_max_tokens_label": "Maximum Responsionum Tokenorum",
    "module_openai_api_base_response_max_tokens_input_accessible_description":
        "Maximum numerum tokenorum quos in responsione accipere potes, verba et interpunctionem includens, "
        "longitudinem exitus moderans.",

    "module_openai_api_config_prompt_history_size_label": "Magnitudo Historiae Promptorum",
    "module_openai_api_config_prompt_history_size_input_accessible_description":
        "Numerum introituum in historia promptorum quae systema retinet ad referentiam moderatur.\n"
        "Valor nullos introitus indefinitos permittit."
}
