# Japanese lexemes statusbar.py
lexemes = {
    "statusbar_litter_bin_label": "ごみ箱",
    "statusbar_litter_bin_accessible_name": "ごみ箱の内容を表示",

    "statusbar_save_progress_label": b'\xf0\x9f\x92\xbe',
    "statusbar_encryption_symbol_encrypted_label": b'\xf0\x9f\x94\x92',
    "statusbar_encryption_symbol_unencrypted_label": b'\xf0\x9f\x94\x93',

    "statusbar_mode_label_mode_view": "ビューモード",
    "statusbar_mode_label_mode_edit": "編集モード",
    "statusbar_mode_label_mode_source": "ソースモード",

    "statusbar_source_label_source_markdown": "Markdown",
    "statusbar_source_label_source_html": "HTML",

    "statusbar_encryption_label": "{encryption} {icon}",
    "statusbar_encryption_label_encryption_plain": "プレーン",
    "statusbar_encryption_label_encryption_encrypted": "暗号化",

    "statusbar_cursor_label": "行: {line} → 列: {column}",
    "statusbar_cursor_label_selected": "行: {line} → 列: {column} → 選択: {selected}",
    "statusbar_cursor_label_with_global": "行: {line} → 列: {column} → 位置: {position}",
    "statusbar_cursor_label_selected_with_global": "行: {line} → 列: {column} → 位置: {position} → 選択: {selected}",
}
