# English lexemes color_picker_dialog.py
lexemes = {
    "color_picker_title": "Select a Color",

    "color_picker_color_black": "Black",
    "color_picker_color_silver": "Silver",
    "color_picker_color_gray": "Gray",
    "color_picker_color_white": "White",
    "color_picker_color_maroon": "Maroon",
    "color_picker_color_red": "Red",
    "color_picker_color_purple": "Purple",
    "color_picker_color_fuchsia": "Fuchsia",
    "color_picker_color_green": "Green",
    "color_picker_color_lime": "Lime",
    "color_picker_color_olive": "Olive",
    "color_picker_color_yellow": "Yellow",
    "color_picker_color_navy": "Navy",
    "color_picker_color_blue": "Blue",
    "color_picker_color_teal": "Teal",
    "color_picker_color_aqua": "Aqua",
    "color_picker_color_aliceblue": "Alice Blue",
    "color_picker_color_antiquewhite": "Antique White",
    "color_picker_color_aquamarine": "Aquamarine",
    "color_picker_color_azure": "Azure",
    "color_picker_color_beige": "Beige",
    "color_picker_color_bisque": "Bisque",
    "color_picker_color_blanchedalmond": "Blanched Almond",
    "color_picker_color_blueviolet": "Blue Violet",
    "color_picker_color_brown": "Brown",
    "color_picker_color_burlywood": "Burly Wood",
    "color_picker_color_cadetblue": "Cadet Blue",
    "color_picker_color_chartreuse": "Chartreuse",
    "color_picker_color_chocolate": "Chocolate",
    "color_picker_color_coral": "Coral",
    "color_picker_color_cornflowerblue": "Cornflower Blue",
    "color_picker_color_cornsilk": "Cornsilk",
    "color_picker_color_crimson": "Crimson",
    "color_picker_color_cyan": "Cyan",
    "color_picker_color_darkblue": "Dark Blue",
    "color_picker_color_darkcyan": "Dark Cyan",
    "color_picker_color_darkgoldenrod": "Dark Golden Rod",
    "color_picker_color_darkgray": "Dark Gray",
    "color_picker_color_darkgreen": "Dark Green",
    "color_picker_color_darkkhaki": "Dark Khaki",
    "color_picker_color_darkmagenta": "Dark Magenta",
    "color_picker_color_darkolivegreen": "Dark Olive Green",
    "color_picker_color_darkorange": "Dark Orange",
    "color_picker_color_darkorchid": "Dark Orchid",
    "color_picker_color_darkred": "Dark Red",
    "color_picker_color_darksalmon": "Dark Salmon",
    "color_picker_color_darkseagreen": "Dark Sea Green",
    "color_picker_color_darkslateblue": "Dark Slate Blue",
    "color_picker_color_darkslategray": "Dark Slate Gray",
    "color_picker_color_darkturquoise": "Dark Turquoise",
    "color_picker_color_darkviolet": "Dark Violet",
    "color_picker_color_deeppink": "Deep Pink",
    "color_picker_color_deepskyblue": "Deep Sky Blue",
    "color_picker_color_dimgray": "Dim Gray",
    "color_picker_color_dodgerblue": "Dodger Blue",
    "color_picker_color_firebrick": "Fire Brick",
    "color_picker_color_floralwhite": "Floral White",
    "color_picker_color_forestgreen": "Forest Green",
    "color_picker_color_gainsboro": "Gainsboro",
    "color_picker_color_ghostwhite": "Ghost White",
    "color_picker_color_gold": "Gold",
    "color_picker_color_goldenrod": "Golden Rod",
    "color_picker_color_greenyellow": "Green Yellow",
    "color_picker_color_honeydew": "Honey Dew",
    "color_picker_color_hotpink": "Hot Pink",
    "color_picker_color_indianred": "Indian Red",
    "color_picker_color_indigo": "Indigo",
    "color_picker_color_ivory": "Ivory",
    "color_picker_color_khaki": "Khaki",
    "color_picker_color_lavender": "Lavender",
    "color_picker_color_lavenderblush": "Lavender Blush",
    "color_picker_color_lawngreen": "Lawn Green",
    "color_picker_color_lemonchiffon": "Lemon Chiffon",
    "color_picker_color_lightblue": "Light Blue",
    "color_picker_color_lightcoral": "Light Coral",
    "color_picker_color_lightcyan": "Light Cyan",
    "color_picker_color_lightgoldenrodyellow": "Light Golden Rod Yellow",
    "color_picker_color_lightgray": "Light Gray",
    "color_picker_color_lightgreen": "Light Green",
    "color_picker_color_lightpink": "Light Pink",
    "color_picker_color_lightsalmon": "Light Salmon",
    "color_picker_color_lightseagreen": "Light Sea Green",
    "color_picker_color_lightskyblue": "Light Sky Blue",
    "color_picker_color_lightslategray": "Light Slate Gray",
    "color_picker_color_lightsteelblue": "Light Steel Blue",
    "color_picker_color_lightyellow": "Light Yellow",
    "color_picker_color_limegreen": "Lime Green",
    "color_picker_color_linen": "Linen",
    "color_picker_color_magenta": "Magenta",
    "color_picker_color_mediumaquamarine": "Medium Aqua Marine",
    "color_picker_color_mediumblue": "Medium Blue",
    "color_picker_color_mediumorchid": "Medium Orchid",
    "color_picker_color_mediumpurple": "Medium Purple",
    "color_picker_color_mediumseagreen": "Medium Sea Green",
    "color_picker_color_mediumslateblue": "Medium Slate Blue",
    "color_picker_color_mediumspringgreen": "Medium Spring Green",
    "color_picker_color_mediumturquoise": "Medium Turquoise",
    "color_picker_color_mediumvioletred": "Medium Violet Red",
    "color_picker_color_midnightblue": "Midnight Blue",
    "color_picker_color_mintcream": "Mint Cream",
    "color_picker_color_mistyrose": "Misty Rose",
    "color_picker_color_moccasin": "Moccasin",
    "color_picker_color_navajowhite": "Navajo White",
    "color_picker_color_oldlace": "Old Lace",
    "color_picker_color_olivedrab": "Olive Drab",
    "color_picker_color_orange": "Orange",
    "color_picker_color_orangered": "Orange Red",
    "color_picker_color_orchid": "Orchid",
    "color_picker_color_palegoldenrod": "Pale Golden Rod",
    "color_picker_color_palegreen": "Pale Green",
    "color_picker_color_paleturquoise": "Pale Turquoise",
    "color_picker_color_palevioletred": "Pale Violet Red",
    "color_picker_color_papayawhip": "Papaya Whip",
    "color_picker_color_peachpuff": "Peach Puff",
    "color_picker_color_peru": "Peru",
    "color_picker_color_pink": "Pink",
    "color_picker_color_plum": "Plum",
    "color_picker_color_powderblue": "Powder Blue",
    "color_picker_color_rebeccapurple": "Rebecca Purple",
    "color_picker_color_rosybrown": "Rosy Brown",
    "color_picker_color_royalblue": "Royal Blue",
    "color_picker_color_saddlebrown": "Saddle Brown",
    "color_picker_color_salmon": "Salmon",
    "color_picker_color_sandybrown": "Sandy Brown",
    "color_picker_color_seagreen": "Sea Green",
    "color_picker_color_seashell": "Sea Shell",
    "color_picker_color_sienna": "Sienna",
    "color_picker_color_skyblue": "Sky Blue",
    "color_picker_color_slateblue": "Slate Blue",
    "color_picker_color_slategray": "Slate Gray",
    "color_picker_color_snow": "Snow",
    "color_picker_color_springgreen": "Spring Green",
    "color_picker_color_steelblue": "Steel Blue",
    "color_picker_color_tan": "Tan",
    "color_picker_color_thistle": "Thistle",
    "color_picker_color_tomato": "Tomato",
    "color_picker_color_turquoise": "Turquoise",
    "color_picker_color_violet": "Violet",
    "color_picker_color_wheat": "Wheat",
    "color_picker_color_whitesmoke": "White Smoke",
    "color_picker_color_yellowgreen": "Yellow Green",
}
