# Spanish lexemes main_menu.py
lexemes = {
    "group_file_label": "Archivo",
    "group_edit_label": "Editar",
    "group_tools_label": "Herramientas",
    "group_help_label": "Ayuda",

    "actions_file_label_new_document": "Nuevo documento",
    "actions_file_accessible_name_new_document": "Nuevo documento",
    "actions_file_label_open": "Abrir",
    "actions_file_accessible_name_open": "Abrir documento",
    "actions_file_label_save": "Guardar",
    "actions_file_accessible_name_save": "Guardar documento",
    "actions_file_label_save_as": "Guardar como",
    "actions_file_accessible_name_save_as": "Guardar como copia del documento",
    "actions_file_label_settings": "Configuración",
    "actions_file_accessible_name_settings": "Configuración de la aplicación",
    "actions_file_label_reset_settings": "Restablecer configuraciones",
    "actions_file_accessible_name_reset_settings": "Restablecer configuraciones",
    "actions_file_label_exit": "Salir",
    "actions_file_accessible_name_exit": "Salir de la aplicación",

    "actions_edit_edit_mode": "Editar",
    "actions_edit_accessible_name_edit_mode": "Editar archivo",
    "actions_edit_source_mode": "Fuente",
    "actions_edit_accessible_name_source_mode": "Código fuente",
    "actions_edit_bold": "Negrita",
    "actions_edit_accessible_name_bold": "Formato de texto en negrita",
    "actions_edit_italic": "Cursiva",
    "actions_edit_accessible_name_italic": "Formato de texto en cursiva",
    "actions_edit_underline": "Subrayado",
    "actions_edit_accessible_name_underline": "Formato de texto subrayado",
    "actions_edit_strikethrough": "Tachado",
    "actions_edit_accessible_name_strikethrough": "Formato de texto tachado",
    "actions_edit_blockquote": "Cita",
    "actions_edit_accessible_name_blockquote": "Formato de texto de cita",

    "actions_tools_ai_assistant": "Asistente de IA",
    "actions_tools_accessible_name_ai_assistant": "Lanzar el asistente de IA",
    "actions_tools_color_picker": "Selector de color",
    "actions_tools_accessible_name_color_picker": "Elegir un color de texto",

    "actions_help_label_md_syntax": "Sintaxis Markdown",
    "actions_help_accessible_name_md_syntax": "Sintaxis Markdown",
    "actions_help_label_check_for_updates": "Buscar actualizaciones",
    "actions_help_accessible_name_check_for_updates": "Buscar actualizaciones",
    "actions_help_label_bug_report": "Reportar error",
    "actions_help_accessible_name_bug_report": "Enviar reporte de error",
    "actions_help_label_about": "Acerca de",
    "actions_help_accessible_name_about": "Acerca de",
}
