# Russian lexemes common.py
lexemes = {
    # Common
    "module_ondevice_llm_name": "LLM на устройстве",

    "module_ondevice_llm_model_exception": "Ошибка: модель не найдена: {error_msg}",
    "module_ondevice_llm_task_exception": "Не удается инициировать генератор модели: {error_msg}",
}
