# Korean lexemes common.py
lexemes = {
    "module_llama_cpp_name": "모듈 llama.cpp",

    "module_llama_cpp_model_exception": "모델을 찾을 수 없음 오류: {error_msg}",
    "module_llama_cpp_task_exception": "모델 생성기를 초기화할 수 없음: {error_msg}",
}
