# Portuguese lexemes ai_assistant.py
lexemes = {
    # Assistente de IA
    "dialog_title": "Solicitação à IA",
    "dialog_prompt_input_placeholder_text": "Solicitação",
    "dialog_prompt_input_accessible_description": "Insira a solicitação para fornecer contexto ao assistente de IA",
    "dialog_response_output_placeholder_text": "Dados da resposta",
    "dialog_response_output_accessible_description": "Os dados da resposta aparecerão neste campo",
    "dialog_response_output_notice_empty_text": "Forneça uma entrada de texto para obter uma resposta de cerca de...",

    "dialog_usage_module_label": "MÓDULO",
    "dialog_usage_model_label": "MODELO",
    "dialog_usage_tokens_label": "TOKENS",
    "dialog_usage_tokens_prompt": "solicitação: {tokens}",
    "dialog_usage_tokens_answer": "resposta: {tokens}",
    "dialog_usage_tokens_total": "total: {tokens}",

    "dialog_button_send_request": "Enviar solicitação",
    "dialog_button_stop_request": "Parar",
    "dialog_button_save_history": "Salvar histórico do diálogo",

    "dialog_message_copy_tooltip": "Copiar texto",
    "dialog_message_copied_tooltip": "Copiado",

    "dialog_error_loading_model": "Erro ao carregar modelo personalizado",
}
