# Swedish lexemes color_picker_dialog.py
lexemes = {
    "color_picker_title": "Välj en färg",

    "color_picker_color_black": "Svart",
    "color_picker_color_silver": "Silver",
    "color_picker_color_gray": "Grå",
    "color_picker_color_white": "Vit",
    "color_picker_color_maroon": "Rödbrun",
    "color_picker_color_red": "Röd",
    "color_picker_color_purple": "Lila",
    "color_picker_color_fuchsia": "Fuchsia",
    "color_picker_color_green": "Grön",
    "color_picker_color_lime": "Limegrön",
    "color_picker_color_olive": "Oliv",
    "color_picker_color_yellow": "Gul",
    "color_picker_color_navy": "Marinblå",
    "color_picker_color_blue": "Blå",
    "color_picker_color_teal": "Teal",
    "color_picker_color_aqua": "Akvamarin",
    "color_picker_color_aliceblue": "Aliceblå",
    "color_picker_color_antiquewhite": "Antikvit",
    "color_picker_color_aquamarine": "Aquamarine",
    "color_picker_color_azure": "Azurblå",
    "color_picker_color_beige": "Beige",
    "color_picker_color_bisque": "Bisque",
    "color_picker_color_blanchedalmond": "Skållad mandel",
    "color_picker_color_blueviolet": "Blåviolett",
    "color_picker_color_brown": "Brun",
    "color_picker_color_burlywood": "Burlywood",
    "color_picker_color_cadetblue": "Kadettblå",
    "color_picker_color_chartreuse": "Chartreuse",
    "color_picker_color_chocolate": "Choklad",
    "color_picker_color_coral": "Korall",
    "color_picker_color_cornflowerblue": "Kornblå",
    "color_picker_color_cornsilk": "Majssilke",
    "color_picker_color_crimson": "Karmosin",
    "color_picker_color_cyan": "Cyan",
    "color_picker_color_darkblue": "Mörkblå",
    "color_picker_color_darkcyan": "Mörk cyan",
    "color_picker_color_darkgoldenrod": "Mörk gyllenstång",
    "color_picker_color_darkgray": "Mörkgrå",
    "color_picker_color_darkgreen": "Mörkgrön",
    "color_picker_color_darkkhaki": "Mörk khaki",
    "color_picker_color_darkmagenta": "Mörk magenta",
    "color_picker_color_darkolivegreen": "Mörkolivgrön",
    "color_picker_color_darkorange": "Mörkorange",
    "color_picker_color_darkorchid": "Mörk orkidé",
    "color_picker_color_darkred": "Mörkröd",
    "color_picker_color_darksalmon": "Mörklax",
    "color_picker_color_darkseagreen": "Mörkt havsgrön",
    "color_picker_color_darkslateblue": "Mörk skifferblå",
    "color_picker_color_darkslategray": "Mörk skiffergrå",
    "color_picker_color_darkturquoise": "Mörkturkos",
    "color_picker_color_darkviolet": "Mörkviolett",
    "color_picker_color_deeppink": "Djuprosa",
    "color_picker_color_deepskyblue": "Djuphimmelsblå",
    "color_picker_color_dimgray": "Dimgrå",
    "color_picker_color_dodgerblue": "Dodgerblå",
    "color_picker_color_firebrick": "Mursten",
    "color_picker_color_floralwhite": "Blomstervit",
    "color_picker_color_forestgreen": "Skogsgrön",
    "color_picker_color_gainsboro": "Gainsboro",
    "color_picker_color_ghostwhite": "Spökvit",
    "color_picker_color_gold": "Guld",
    "color_picker_color_goldenrod": "Gyllenstång",
    "color_picker_color_greenyellow": "Gröngul",
    "color_picker_color_honeydew": "Honungsdagg",
    "color_picker_color_hotpink": "Hett rosa",
    "color_picker_color_indianred": "Indisk röd",
    "color_picker_color_indigo": "Indigo",
    "color_picker_color_ivory": "Elfenben",
    "color_picker_color_khaki": "Khaki",
    "color_picker_color_lavender": "Lavendel",
    "color_picker_color_lavenderblush": "Lavendelrosa",
    "color_picker_color_lawngreen": "Gräsmattagrön",
    "color_picker_color_lemonchiffon": "Citronchiffong",
    "color_picker_color_lightblue": "Ljusblå",
    "color_picker_color_lightcoral": "Ljuskorall",
    "color_picker_color_lightcyan": "Ljus cyan",
    "color_picker_color_lightgoldenrodyellow": "Ljus gyllenstångsgul",
    "color_picker_color_lightgray": "Ljusgrå",
    "color_picker_color_lightgreen": "Ljusgrön",
    "color_picker_color_lightpink": "Ljusrosa",
    "color_picker_color_lightsalmon": "Ljuslax",
    "color_picker_color_lightseagreen": "Ljust havsgrön",
    "color_picker_color_lightskyblue": "Ljus himmelsblå",
    "color_picker_color_lightslategray": "Ljus skiffergrå",
    "color_picker_color_lightsteelblue": "Ljust stålblå",
    "color_picker_color_lightyellow": "Ljusgul",
    "color_picker_color_limegreen": "Limegrön",
    "color_picker_color_linen": "Linnetyg",
    "color_picker_color_magenta": "Magenta",
    "color_picker_color_mediumaquamarine": "Mellan aquamarine",
    "color_picker_color_mediumblue": "Mellanblå",
    "color_picker_color_mediumorchid": "Mellan orkidé",
    "color_picker_color_mediumpurple": "Mellanlila",
    "color_picker_color_mediumseagreen": "Mellant havsgrön",
    "color_picker_color_mediumslateblue": "Mellan skifferblå",
    "color_picker_color_mediumspringgreen": "Mellant vårgrön",
    "color_picker_color_mediumturquoise": "Mellanturkos",
    "color_picker_color_mediumvioletred": "Mellan violetröd",
    "color_picker_color_midnightblue": "Midnattsblå",
    "color_picker_color_mintcream": "Mintkräm",
    "color_picker_color_mistyrose": "Dimrosa",
    "color_picker_color_moccasin": "Mockasin",
    "color_picker_color_navajowhite": "Navajovit",
    "color_picker_color_oldlace": "Gammal spets",
    "color_picker_color_olivedrab": "Olivtrist",
    "color_picker_color_orange": "Orange",
    "color_picker_color_orangered": "Orangeröd",
    "color_picker_color_orchid": "Orkidé",
    "color_picker_color_palegoldenrod": "Blek gyllenstång",
    "color_picker_color_palegreen": "Blekgrön",
    "color_picker_color_paleturquoise": "Blekturkos",
    "color_picker_color_palevioletred": "Blek violetröd",
    "color_picker_color_papayawhip": "Papayagrädde",
    "color_picker_color_peachpuff": "Persikopuff",
    "color_picker_color_peru": "Peru",
    "color_picker_color_pink": "Rosa",
    "color_picker_color_plum": "Plommon",
    "color_picker_color_powderblue": "Pulverblå",
    "color_picker_color_rebeccapurple": "Rebeccalila",
    "color_picker_color_rosybrown": "Rosenbrun",
    "color_picker_color_royalblue": "Kungsblå",
    "color_picker_color_saddlebrown": "Sadelbrun",
    "color_picker_color_salmon": "Lax",
    "color_picker_color_sandybrown": "Sandbrun",
    "color_picker_color_seagreen": "Havsgrön",
    "color_picker_color_seashell": "Snäckskal",
    "color_picker_color_sienna": "Sienna",
    "color_picker_color_skyblue": "Himmelsblå",
    "color_picker_color_slateblue": "Skifferblå",
    "color_picker_color_slategray": "Skiffergrå",
    "color_picker_color_snow": "Snö",
    "color_picker_color_springgreen": "Vårgrön",
    "color_picker_color_steelblue": "Stålblå",
    "color_picker_color_tan": "Tan",
    "color_picker_color_thistle": "Tistel",
    "color_picker_color_tomato": "Tomat",
    "color_picker_color_turquoise": "Turkos",
    "color_picker_color_violet": "Violett",
    "color_picker_color_wheat": "Vete",
    "color_picker_color_whitesmoke": "Vitrök",
    "color_picker_color_yellowgreen": "Gulgrön"
}
