# Portuguese lexemes common.py
lexemes = {
    "module_llama_cpp_name": "Módulo llama.cpp",

    "module_llama_cpp_model_exception": "Erro de modelo não encontrado: {error_msg}",
    "module_llama_cpp_task_exception": "Não é possível iniciar o gerador de modelo: {error_msg}",
}
