# Korean lexemes ai_assistant.py
lexemes = {
    # AI 보조
    "dialog_title": "AI에게 요청",
    "dialog_prompt_input_placeholder_text": "요청",
    "dialog_prompt_input_accessible_description": "AI 보조에게 컨텍스트를 제공하기 위한 요청 입력",
    "dialog_response_output_placeholder_text": "응답 데이터",
    "dialog_response_output_accessible_description": "응답 데이터가 이 필드에 표시됩니다",
    "dialog_response_output_notice_empty_text": "텍스트 입력을 제공하여 대략...",

    "dialog_usage_module_label": "모듈",
    "dialog_usage_model_label": "모델",
    "dialog_usage_tokens_label": "토큰",
    "dialog_usage_tokens_prompt": "프롬프트: {tokens}",
    "dialog_usage_tokens_answer": "답변: {tokens}",
    "dialog_usage_tokens_total": "총계: {tokens}",

    "dialog_button_send_request": "요청 보내기",
    "dialog_button_stop_request": "중지",
    "dialog_button_save_history": "대화 기록 저장",

    "dialog_message_copy_tooltip": "텍스트 복사",
    "dialog_message_copied_tooltip": "복사됨",

    "dialog_error_loading_model": "사용자 정의 모델 로딩 오류",
}
