# Dutch lexemes color_picker_dialog.py
lexemes = {
    "color_picker_title": "Kies een kleur",

    "color_picker_color_black": "Zwart",
    "color_picker_color_silver": "Zilver",
    "color_picker_color_gray": "Grijs",
    "color_picker_color_white": "Wit",
    "color_picker_color_maroon": "Kastanjebruin",
    "color_picker_color_red": "Rood",
    "color_picker_color_purple": "Paars",
    "color_picker_color_fuchsia": "Fuchsia",
    "color_picker_color_green": "Groen",
    "color_picker_color_lime": "Limoen",
    "color_picker_color_olive": "Olijf",
    "color_picker_color_yellow": "Geel",
    "color_picker_color_navy": "Marineblauw",
    "color_picker_color_blue": "Blauw",
    "color_picker_color_teal": "Blauwgroen",
    "color_picker_color_aqua": "Aqua",
    "color_picker_color_aliceblue": "Aliceblauw",
    "color_picker_color_antiquewhite": "Antiek wit",
    "color_picker_color_aquamarine": "Aquamarijn",
    "color_picker_color_azure": "Azuriet",
    "color_picker_color_beige": "Beige",
    "color_picker_color_bisque": "Bisque",
    "color_picker_color_blanchedalmond": "Geblancheerde amandel",
    "color_picker_color_blueviolet": "Blauwviolet",
    "color_picker_color_brown": "Bruin",
    "color_picker_color_burlywood": "Ruwe houtkleur",
    "color_picker_color_cadetblue": "Cadetblauw",
    "color_picker_color_chartreuse": "Chartreuse",
    "color_picker_color_chocolate": "Chocoladebruin",
    "color_picker_color_coral": "Koraal",
    "color_picker_color_cornflowerblue": "Korenbloemblauw",
    "color_picker_color_cornsilk": "Maïszijde",
    "color_picker_color_crimson": "Karmozijn",
    "color_picker_color_cyan": "Cyaan",
    "color_picker_color_darkblue": "Donkerblauw",
    "color_picker_color_darkcyan": "Donkercyaan",
    "color_picker_color_darkgoldenrod": "Donkergoud",
    "color_picker_color_darkgray": "Donkergrijs",
    "color_picker_color_darkgreen": "Donkergroen",
    "color_picker_color_darkkhaki": "Donkerkaki",
    "color_picker_color_darkmagenta": "Donkermagenta",
    "color_picker_color_darkolivegreen": "Donkerolijfgroen",
    "color_picker_color_darkorange": "Donkeroranje",
    "color_picker_color_darkorchid": "Donkerorchidee",
    "color_picker_color_darkred": "Donkerrood",
    "color_picker_color_darksalmon": "Donkerzalm",
    "color_picker_color_darkseagreen": "Donkerzeegroen",
    "color_picker_color_darkslateblue": "Donker leiblauw",
    "color_picker_color_darkslategray": "Donker leigrijs",
    "color_picker_color_darkturquoise": "Donkerturkoois",
    "color_picker_color_darkviolet": "Donkerviolet",
    "color_picker_color_deeppink": "Dieproze",
    "color_picker_color_deepskyblue": "Diephemelsblauw",
    "color_picker_color_dimgray": "Gedimd grijs",
    "color_picker_color_dodgerblue": "Dodgerblauw",
    "color_picker_color_firebrick": "Vuursteenrood",
    "color_picker_color_floralwhite": "Bloemwit",
    "color_picker_color_forestgreen": "Bosgroen",
    "color_picker_color_gainsboro": "Gainsboro",
    "color_picker_color_ghostwhite": "Spookwit",
    "color_picker_color_gold": "Goud",
    "color_picker_color_goldenrod": "Goudbruin",
    "color_picker_color_greenyellow": "Groengeel",
    "color_picker_color_honeydew": "Honingdauw",
    "color_picker_color_hotpink": "Felroze",
    "color_picker_color_indianred": "Indiaansrood",
    "color_picker_color_indigo": "Indigo",
    "color_picker_color_ivory": "Ivoor",
    "color_picker_color_khaki": "Kaki",
    "color_picker_color_lavender": "Lavendel",
    "color_picker_color_lavenderblush": "Lavendelroze",
    "color_picker_color_lawngreen": "Grasgroen",
    "color_picker_color_lemonchiffon": "Citroenchiffon",
    "color_picker_color_lightblue": "Lichtblauw",
    "color_picker_color_lightcoral": "Lichtkoraal",
    "color_picker_color_lightcyan": "Lichtcyaan",
    "color_picker_color_lightgoldenrodyellow": "Licht goudgeel",
    "color_picker_color_lightgray": "Lichtgrijs",
    "color_picker_color_lightgreen": "Lichtgroen",
    "color_picker_color_lightpink": "Lichtroze",
    "color_picker_color_lightsalmon": "Lichtzalm",
    "color_picker_color_lightseagreen": "Lichtzeegroen",
    "color_picker_color_lightskyblue": "Lichthemelsblauw",
    "color_picker_color_lightslategray": "Licht leigrijs",
    "color_picker_color_lightsteelblue": "Licht staalblauw",
    "color_picker_color_lightyellow": "Lichtgeel",
    "color_picker_color_limegreen": "Limetgroen",
    "color_picker_color_linen": "Linnen",
    "color_picker_color_magenta": "Magenta",
    "color_picker_color_mediumaquamarine": "Middelaquamarijn",
    "color_picker_color_mediumblue": "Middenblauw",
    "color_picker_color_mediumorchid": "Middenorchidee",
    "color_picker_color_mediumpurple": "Middenpaars",
    "color_picker_color_mediumseagreen": "Middenseegroen",
    "color_picker_color_mediumslateblue": "Midden leiblauw",
    "color_picker_color_mediumspringgreen": "Midden lentegroen",
    "color_picker_color_mediumturquoise": "Middenturkoois",
    "color_picker_color_mediumvioletred": "Middenvioletrood",
    "color_picker_color_midnightblue": "Middernachtblauw",
    "color_picker_color_mintcream": "Muntcrème",
    "color_picker_color_mistyrose": "Mistige roos",
    "color_picker_color_moccasin": "Moccasin",
    "color_picker_color_navajowhite": "Navajo wit",
    "color_picker_color_oldlace": "Oud kant",
    "color_picker_color_olivedrab": "Olijfgrijs",
    "color_picker_color_orange": "Oranje",
    "color_picker_color_orangered": "Oranjerood",
    "color_picker_color_orchid": "Orchidee",
    "color_picker_color_palegoldenrod": "Bleekgoud",
    "color_picker_color_palegreen": "Bleekgroen",
    "color_picker_color_paleturquoise": "Bleekturkoois",
    "color_picker_color_palevioletred": "Bleekvioletrood",
    "color_picker_color_papayawhip": "Papajakleur",
    "color_picker_color_peachpuff": "Perzik",
    "color_picker_color_peru": "Peru",
    "color_picker_color_pink": "Roze",
    "color_picker_color_plum": "Pruim",
    "color_picker_color_powderblue": "Poederblauw",
    "color_picker_color_rebeccapurple": "Rebecca paars",
    "color_picker_color_rosybrown": "Rozebruin",
    "color_picker_color_royalblue": "Koningsblauw",
    "color_picker_color_saddlebrown": "Zadelbruin",
    "color_picker_color_salmon": "Zalm",
    "color_picker_color_sandybrown": "Zandbruin",
    "color_picker_color_seagreen": "Zeegroen",
    "color_picker_color_seashell": "Schelp",
    "color_picker_color_sienna": "Sienna",
    "color_picker_color_skyblue": "Hemelsblauw",
    "color_picker_color_slateblue": "Leiblauw",
    "color_picker_color_slategray": "Leigrijs",
    "color_picker_color_snow": "Sneeuw",
    "color_picker_color_springgreen": "Lentegroen",
    "color_picker_color_steelblue": "Staalblauw",
    "color_picker_color_tan": "Bruinbeige",
    "color_picker_color_thistle": "Distel",
    "color_picker_color_tomato": "Tomaatrood",
    "color_picker_color_turquoise": "Turkoois",
    "color_picker_color_violet": "Violet",
    "color_picker_color_wheat": "Tarwe",
    "color_picker_color_whitesmoke": "Witte rook",
    "color_picker_color_yellowgreen": "Geelgroen"
}
