# Portuguese lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "Novo documento",
    "actions_accessible_name_new_document": "Novo documento",
    "actions_label_open": "Abrir",
    "actions_accessible_name_open": "Abrir documento",
    "actions_label_save": "Salvar",
    "actions_accessible_name_save": "Salvar documento",
    "actions_label_save_as": "Salvar como",
    "actions_accessible_name_save_as": "Salvar como cópia do documento",
    "actions_label_sync": "Sincronizar",
    "actions_accessible_name_sync": "Sincronizar documento com armazenamento externo",
    "actions_label_edit": "Editar",
    "actions_accessible_name_edit": "Editar arquivo",
    "actions_label_source": "Fonte",
    "actions_accessible_name_source": "Código-fonte",
    "actions_label_encrypt": "Criptografar",
    "actions_accessible_name_encrypt": "Criptografar arquivo",
    "actions_label_decrypt": "Descriptografar",
    "actions_accessible_name_decrypt": "Descriptografar arquivo",
    "actions_label_bold": "Negrito",
    "actions_accessible_name_bold": "Formatar texto em negrito",
    "actions_label_italic": "Itálico",
    "actions_accessible_name_italic": "Formatar texto em itálico",
    "actions_label_underline": "Sublinhado",
    "actions_accessible_name_underline": "Formatar texto com sublinhado",
    "actions_label_strikethrough": "Riscado",
    "actions_accessible_name_strikethrough": "Formatar texto como riscado",
    "actions_label_blockquote": "Citação",
    "actions_accessible_name_blockquote": "Formatar texto como citação",
    "actions_label_color_picker": "Seletor de cores",
    "actions_accessible_name_color_picker": "Escolher uma cor de texto",
    "actions_label_ai_assistant": "Assistente de IA",
    "actions_accessible_name_ai_assistant": "Executar assistente de IA",
    "actions_label_about": "Sobre",
    "actions_accessible_name_about": "Sobre o App",
    "actions_label_exit": "Sair",
    "actions_accessible_name_exit": "Sair do App",
    "actions_label_settings": "Configurações",
    "actions_accessible_name_settings": "Configurações do aplicativo",

    "search_input_label": "Pesquisar",
    "search_input_placeholder_text": "Pesquisar texto no documento",
    "search_input_accessible_description": "Campo de entrada de pesquisa",
    "search_buttons_label_clear": "Limpar pesquisa",
    "search_buttons_accessible_name_clear": "Limpar campo de pesquisa",
    "search_buttons_label_prev": "Pesquisa anterior",
    "search_buttons_accessible_name_prev": "Resultado da pesquisa anterior",
    "search_buttons_label_next": "Próxima pesquisa",
    "search_buttons_accessible_name_next": "Resultado da próxima pesquisa",
    "search_case_sensitive_accessible_name": "Diferenciar maiúsculas de minúsculas",
    "search_case_sensitive_tooltip": "Pesquisa diferenciando maiúsculas de minúsculas",
}
