# Greek lexemes color_picker_dialog.py
lexemes = {
    "color_picker_title": "Επιλογή Χρώματος",

    "color_picker_color_black": "Μαύρο",
    "color_picker_color_silver": "Ασημί",
    "color_picker_color_gray": "Γκρι",
    "color_picker_color_white": "Λευκό",
    "color_picker_color_maroon": "Καστανοκόκκινο",
    "color_picker_color_red": "Κόκκινο",
    "color_picker_color_purple": "Μωβ",
    "color_picker_color_fuchsia": "Φούξια",
    "color_picker_color_green": "Πράσινο",
    "color_picker_color_lime": "Λαχανί",
    "color_picker_color_olive": "Ελαιόλαδο",
    "color_picker_color_yellow": "Κίτρινο",
    "color_picker_color_navy": "Μπλε ναυτικό",
    "color_picker_color_blue": "Μπλε",
    "color_picker_color_teal": "Γαλάζιο",
    "color_picker_color_aqua": "Υδρόμπλε",
    "color_picker_color_aliceblue": "Αλίς μπλε",
    "color_picker_color_antiquewhite": "Αντίκα Λευκό",
    "color_picker_color_aquamarine": "Ακουαμαρίν",
    "color_picker_color_azure": "Γαλανό",
    "color_picker_color_beige": "Μπεζ",
    "color_picker_color_bisque": "Μπισκ",
    "color_picker_color_blanchedalmond": "Αμύγδαλο ξεφλουδισμένο",
    "color_picker_color_blueviolet": "Μπλε Μωβ",
    "color_picker_color_brown": "Καφέ",
    "color_picker_color_burlywood": "Ξύλο Βέργα",
    "color_picker_color_cadetblue": "Μπλε Στρατιώτη",
    "color_picker_color_chartreuse": "Σαρτρέζ",
    "color_picker_color_chocolate": "Σοκολάτα",
    "color_picker_color_coral": "Κοραλί",
    "color_picker_color_cornflowerblue": "Μπλε Κενταυρίδας",
    "color_picker_color_cornsilk": "Μετάξι Καλαμποκιού",
    "color_picker_color_crimson": "Κόκκινο Βαθύ",
    "color_picker_color_cyan": "Κυανό",
    "color_picker_color_darkblue": "Σκούρο Μπλε",
    "color_picker_color_darkcyan": "Σκούρο Κυανό",
    "color_picker_color_darkgoldenrod": "Σκούρο Χρυσαφί Ράβδος",
    "color_picker_color_darkgray": "Σκούρο Γκρι",
    "color_picker_color_darkgreen": "Σκούρο Πράσινο",
    "color_picker_color_darkkhaki": "Σκούρο Χακί",
    "color_picker_color_darkmagenta": "Σκούρο Ματζέντα",
    "color_picker_color_darkolivegreen": "Σκούρο Πράσινο Ελιάς",
    "color_picker_color_darkorange": "Σκούρο Πορτοκαλί",
    "color_picker_color_darkorchid": "Σκούρο Ορχιδέα",
    "color_picker_color_darkred": "Σκούρο Κόκκινο",
    "color_picker_color_darksalmon": "Σκούρο Σολομός",
    "color_picker_color_darkseagreen": "Σκούρο Θαλασσί Πράσινο",
    "color_picker_color_darkslateblue": "Σκούρο Σχιστόλιθος Μπλε",
    "color_picker_color_darkslategray": "Σκούρο Σχιστόλιθος Γκρι",
    "color_picker_color_darkturquoise": "Σκούρο Τυρκουάζ",
    "color_picker_color_darkviolet": "Σκούρο Μωβ",
    "color_picker_color_deeppink": "Βαθύ Ροζ",
    "color_picker_color_deepskyblue": "Βαθύ Ουρανί Μπλε",
    "color_picker_color_dimgray": "Θαμπό Γκρι",
    "color_picker_color_dodgerblue": "Διαφυγή Μπλε",
    "color_picker_color_firebrick": "Τούβλο Φωτιάς",
    "color_picker_color_floralwhite": "Φλοράλ Λευκό",
    "color_picker_color_forestgreen": "Πράσινο Δάσους",
    "color_picker_color_gainsboro": "Γκέινσμπορο",
    "color_picker_color_ghostwhite": "Φάντασμα Λευκό",
    "color_picker_color_gold": "Χρυσαφί",
    "color_picker_color_goldenrod": "Χρυσαφί Ράβδος",
    "color_picker_color_greenyellow": "Πράσινο Κίτρινο",
    "color_picker_color_honeydew": "Δροσοσταλίδα",
    "color_picker_color_hotpink": "Ζεστό Ροζ",
    "color_picker_color_indianred": "Ινδικό Κόκκινο",
    "color_picker_color_indigo": "Ινδικό",
    "color_picker_color_ivory": "Ιβουάρ",
    "color_picker_color_khaki": "Χακί",
    "color_picker_color_lavender": "Λεβάντα",
    "color_picker_color_lavenderblush": "Λεβάντα Ροζ",
    "color_picker_color_lawngreen": "Πράσινο Γκαζόν",
    "color_picker_color_lemonchiffon": "Λεμονί Σιφόν",
    "color_picker_color_lightblue": "Ανοιχτό Μπλε",
    "color_picker_color_lightcoral": "Ανοιχτό Κοραλί",
    "color_picker_color_lightcyan": "Ανοιχτό Κυανό",
    "color_picker_color_lightgoldenrodyellow": "Ανοιχτό Χρυσαφί Ράβδος Κίτρινο",
    "color_picker_color_lightgray": "Ανοιχτό Γκρι",
    "color_picker_color_lightgreen": "Ανοιχτό Πράσινο",
    "color_picker_color_lightpink": "Ανοιχτό Ροζ",
    "color_picker_color_lightsalmon": "Ανοιχτό Σολομός",
    "color_picker_color_lightseagreen": "Ανοιχτό Θαλασσί Πράσινο",
    "color_picker_color_lightskyblue": "Ανοιχτό Ουρανί Μπλε",
    "color_picker_color_lightslategray": "Ανοιχτό Σχιστόλιθος Γκρι",
    "color_picker_color_lightsteelblue": "Ανοιχτό Μέταλλο Μπλε",
    "color_picker_color_lightyellow": "Ανοιχτό Κίτρινο",
    "color_picker_color_limegreen": "Λαχανί Πράσινο",
    "color_picker_color_linen": "Λινάρι",
    "color_picker_color_magenta": "Ματζέντα",
    "color_picker_color_mediumaquamarine": "Μέτριο Ακουαμαρίν",
    "color_picker_color_mediumblue": "Μέτριο Μπλε",
    "color_picker_color_mediumorchid": "Μέτριο Ορχιδέα",
    "color_picker_color_mediumpurple": "Μέτριο Μωβ",
    "color_picker_color_mediumseagreen": "Μέτριο Θαλασσί Πράσινο",
    "color_picker_color_mediumslateblue": "Μέτριο Σχιστόλιθος Μπλε",
    "color_picker_color_mediumspringgreen": "Μέτριο Ανοιξιάτικο Πράσινο",
    "color_picker_color_mediumturquoise": "Μέτριο Τυρκουάζ",
    "color_picker_color_mediumvioletred": "Μέτριο Μωβ Κόκκινο",
    "color_picker_color_midnightblue": "Μεσάνυχτα Μπλε",
    "color_picker_color_mintcream": "Κρέμα Μέντας",
    "color_picker_color_mistyrose": "Θολό Ροζ",
    "color_picker_color_moccasin": "Μοκασίνι",
    "color_picker_color_navajowhite": "Ναβάχο Λευκό",
    "color_picker_color_oldlace": "Παλιά Δαντέλα",
    "color_picker_color_olivedrab": "Στρατιωτικό Πράσινο",
    "color_picker_color_orange": "Πορτοκαλί",
    "color_picker_color_orangered": "Πορτοκαλοκόκκινο",
    "color_picker_color_orchid": "Ορχιδέα",
    "color_picker_color_palegoldenrod": "Αχνό Χρυσαφί Ράβδος",
    "color_picker_color_palegreen": "Αχνό Πράσινο",
    "color_picker_color_paleturquoise": "Αχνό Τυρκουάζ",
    "color_picker_color_palevioletred": "Αχνό Μωβ Κόκκινο",
    "color_picker_color_papayawhip": "Παπάγια Χτυπητή",
    "color_picker_color_peachpuff": "Ροδάκινο Φουσκωτό",
    "color_picker_color_peru": "Περού",
    "color_picker_color_pink": "Ροζ",
    "color_picker_color_plum": "Δαμάσκηνο",
    "color_picker_color_powderblue": "Πούδρα Μπλε",
    "color_picker_color_rebeccapurple": "Ρεβέκκα Μωβ",
    "color_picker_color_rosybrown": "Ροδαλό Καφέ",
    "color_picker_color_royalblue": "Βασιλικό Μπλε",
    "color_picker_color_saddlebrown": "Καφέ Σέλα",
    "color_picker_color_salmon": "Σολομός",
    "color_picker_color_sandybrown": "Αμμώδες Καφέ",
    "color_picker_color_seagreen": "Θαλασσί Πράσινο",
    "color_picker_color_seashell": "Κοχύλι",
    "color_picker_color_sienna": "Σιέννα",
    "color_picker_color_skyblue": "Ουρανί Μπλε",
    "color_picker_color_slateblue": "Σχιστόλιθος Μπλε",
    "color_picker_color_slategray": "Σχιστόλιθος Γκρι",
    "color_picker_color_snow": "Χιόνι",
    "color_picker_color_springgreen": "Ανοιξιάτικο Πράσινο",
    "color_picker_color_steelblue": "Μέταλλο Μπλε",
    "color_picker_color_tan": "Ταν",
    "color_picker_color_thistle": "Γαϊδουράγκαθο",
    "color_picker_color_tomato": "Ντομάτα",
    "color_picker_color_turquoise": "Τυρκουάζ",
    "color_picker_color_violet": "Βιολετί",
    "color_picker_color_wheat": "Σιτάρι",
    "color_picker_color_whitesmoke": "Λευκός Καπνός",
    "color_picker_color_yellowgreen": "Κίτρινο Πράσινο",
}
