# Latin lexemes main_menu.py
lexemes = {
    "group_file_label": "Fasciculus",
    "group_edit_label": "Recensere",
    "group_tools_label": "Instrumenta",
    "group_help_label": "Auxilium",

    "actions_file_label_new_document": "Documentum novum",
    "actions_file_accessible_name_new_document": "Documentum novum",
    "actions_file_label_open": "Aperire",
    "actions_file_accessible_name_open": "Documentum aperire",
    "actions_file_label_save": "Servare",
    "actions_file_accessible_name_save": "Documentum Servare",
    "actions_file_label_save_as": "Salvare ut",
    "actions_file_accessible_name_save_as": "Salvare ut exemplar documenti",
    "actions_file_label_settings": "Configurationes",
    "actions_file_accessible_name_settings": "Configurationes Applicatio",
    "actions_file_label_reset_settings": "Reddere ad initium",
    "actions_file_accessible_name_reset_settings": "Reddere ad initium",
    "actions_file_label_exit": "Excedere",
    "actions_file_accessible_name_exit": "Excedere applicationem",

    "actions_edit_edit_mode": "Recensere",
    "actions_edit_accessible_name_edit_mode": "Recensere fasciculum",
    "actions_edit_source_mode": "Fons",
    "actions_edit_accessible_name_source_mode": "Codex fontis",
    "actions_edit_bold": "Audax",
    "actions_edit_accessible_name_bold": "Formatum textus audacis",
    "actions_edit_italic": "Italicum",
    "actions_edit_accessible_name_italic": "Formatum textus italicum",
    "actions_edit_underline": "Sublineare",
    "actions_edit_accessible_name_underline": "Formatum textus sublinearis",
    "actions_edit_strikethrough": "Expungere",
    "actions_edit_accessible_name_strikethrough": "Formatum textus expungendi",
    "actions_edit_blockquote": "Blockquote",
    "actions_edit_accessible_name_blockquote": "Formatum textus blockquote",

    "actions_tools_ai_assistant": "Assistens AI",
    "actions_tools_accessible_name_ai_assistant": "Initiare Assistens AI",
    "actions_tools_color_picker": "Selector Coloris",
    "actions_tools_accessible_name_color_picker": "Eligere colorem textus",

    "actions_help_label_md_syntax": "Syntaxis markdown",
    "actions_help_accessible_name_md_syntax": "Syntaxis markdown",
    "actions_help_label_check_for_updates": "Repaginas scrutare",
    "actions_help_accessible_name_check_for_updates": "Repaginas scrutare",
    "actions_help_label_bug_report": "Falla nuntiare",
    "actions_help_accessible_name_bug_report": "Falla nuntiare",
    "actions_help_label_about": "De",
    "actions_help_accessible_name_about": "De",
}
