# Italian lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "Nuovo documento",
    "actions_accessible_name_new_document": "Nuovo documento",
    "actions_label_open": "Apri",
    "actions_accessible_name_open": "Apri documento",
    "actions_label_save": "Salva",
    "actions_accessible_name_save": "Salva documento",
    "actions_label_save_as": "Salva come",
    "actions_accessible_name_save_as": "Salva come copia del documento",
    "actions_label_sync": "Sincronizza",
    "actions_accessible_name_sync": "Sincronizza documento con storage esterno",
    "actions_label_edit": "Modifica",
    "actions_accessible_name_edit": "Modifica file",
    "actions_label_source": "Sorgente",
    "actions_accessible_name_source": "Codice sorgente",
    "actions_label_encrypt": "Cripta",
    "actions_accessible_name_encrypt": "Cripta file",
    "actions_label_decrypt": "Decripta",
    "actions_accessible_name_decrypt": "Decripta file",
    "actions_label_bold": "Grassetto",
    "actions_accessible_name_bold": "Formatta testo in grassetto",
    "actions_label_italic": "Corsivo",
    "actions_accessible_name_italic": "Formatta testo in corsivo",
    "actions_label_underline": "Sottolineato",
    "actions_accessible_name_underline": "Formatta testo sottolineato",
    "actions_label_strikethrough": "Barrato",
    "actions_accessible_name_strikethrough": "Formatta testo barrato",
    "actions_label_blockquote": "Citazione",
    "actions_accessible_name_blockquote": "Formatta testo come citazione",
    "actions_label_color_picker": "Selettore di colore",
    "actions_accessible_name_color_picker": "Scegli un colore di testo",
    "actions_label_ai_assistant": "Assistente IA",
    "actions_accessible_name_ai_assistant": "Esegui assistente IA",
    "actions_label_about": "Informazioni",
    "actions_accessible_name_about": "Informazioni sull'App",
    "actions_label_exit": "Esci",
    "actions_accessible_name_exit": "Esci dall'App",
    "actions_label_settings": "Impostazioni",
    "actions_accessible_name_settings": "Impostazioni dell'app",

    "search_input_label": "Cerca",
    "search_input_placeholder_text": "Cerca testo nel documento",
    "search_input_accessible_description": "Campo di input per la ricerca",
    "search_buttons_label_clear": "Pulisci ricerca",
    "search_buttons_accessible_name_clear": "Pulisci campo di ricerca",
    "search_buttons_label_prev": "Ricerca precedente",
    "search_buttons_accessible_name_prev": "Risultato ricerca precedente",
    "search_buttons_label_next": "Ricerca successiva",
    "search_buttons_accessible_name_next": "Risultato ricerca successiva",
    "search_case_sensitive_accessible_name": "Distingui maiuscole e minuscole",
    "search_case_sensitive_tooltip": "Ricerca con distinzione tra maiuscole e minuscole",
}
