# Japanese lexemes main_menu.py
lexemes = {
    "group_file_label": "ファイル",
    "group_edit_label": "編集",
    "group_tools_label": "ツール",
    "group_help_label": "ヘルプ",

    "actions_file_label_new_document": "新しいドキュメント",
    "actions_file_accessible_name_new_document": "新しいドキュメント",
    "actions_file_label_open": "開く",
    "actions_file_accessible_name_open": "ドキュメントを開く",
    "actions_file_label_save": "保存",
    "actions_file_accessible_name_save": "ドキュメントを保存",
    "actions_file_label_save_as": "名前を付けて保存",
    "actions_file_accessible_name_save_as": "ドキュメントのコピーを保存",
    "actions_file_label_settings": "設定",
    "actions_file_accessible_name_settings": "アプリ設定",
    "actions_file_label_reset_settings": "設定をリセット",
    "actions_file_accessible_name_reset_settings": "設定をリセット",
    "actions_file_label_exit": "アプリを終了",
    "actions_file_accessible_name_exit": "アプリを終了",

    "actions_edit_edit_mode": "編集",
    "actions_edit_accessible_name_edit_mode": "ファイルを編集",
    "actions_edit_source_mode": "ソース",
    "actions_edit_accessible_name_source_mode": "ソースコード",
    "actions_edit_bold": "太字",
    "actions_edit_accessible_name_bold": "太字テキスト形式",
    "actions_edit_italic": "イタリック",
    "actions_edit_accessible_name_italic": "イタリックテキスト形式",
    "actions_edit_underline": "下線",
    "actions_edit_accessible_name_underline": "下線テキスト形式",
    "actions_edit_strikethrough": "取り消し線",
    "actions_edit_accessible_name_strikethrough": "取り消し線テキスト形式",
    "actions_edit_blockquote": "ブロック引用",
    "actions_edit_accessible_name_blockquote": "ブロック引用テキスト形式",

    "actions_tools_ai_assistant": "AIアシスタント",
    "actions_tools_accessible_name_ai_assistant": "AIアシスタントを起動",
    "actions_tools_color_picker": "カラーピッカー",
    "actions_tools_accessible_name_color_picker": "テキスト色を選択",

    "actions_help_label_md_syntax": "Markdown 構文",
    "actions_help_accessible_name_md_syntax": "Markdown 構文",
    "actions_help_label_check_for_updates": "更新を確認",
    "actions_help_accessible_name_check_for_updates": "更新を確認",
    "actions_help_label_bug_report": "バグ報告",
    "actions_help_accessible_name_bug_report": "バグ報告を送信",
    "actions_help_label_about": "情報",
    "actions_help_accessible_name_about": "情報",
}
