# German lexemes main_menu.py
lexemes = {
    "group_file_label": "Datei",
    "group_edit_label": "Bearbeiten",
    "group_tools_label": "Werkzeuge",
    "group_help_label": "Hilfe",

    "actions_file_label_new_document": "Neues Dokument",
    "actions_file_accessible_name_new_document": "Neues Dokument",
    "actions_file_label_open": "Öffnen",
    "actions_file_accessible_name_open": "Dokument öffnen",
    "actions_file_label_save": "Speichern",
    "actions_file_accessible_name_save": "Dokument speichern",
    "actions_file_label_save_as": "Speichern unter",
    "actions_file_accessible_name_save_as": "Kopie des Dokuments speichern",
    "actions_file_label_settings": "Einstellungen",
    "actions_file_accessible_name_settings": "App-Einstellungen",
    "actions_file_label_reset_settings": "Einstellungen zurücksetzen",
    "actions_file_accessible_name_reset_settings": "Einstellungen zurücksetzen",
    "actions_file_label_exit": "Beenden",
    "actions_file_accessible_name_exit": "App beenden",

    "actions_edit_edit_mode": "Bearbeiten",
    "actions_edit_accessible_name_edit_mode": "Datei bearbeiten",
    "actions_edit_source_mode": "Quelle",
    "actions_edit_accessible_name_source_mode": "Quellcode",
    "actions_edit_bold": "Fett",
    "actions_edit_accessible_name_bold": "Fettschrift Format",
    "actions_edit_italic": "Kursiv",
    "actions_edit_accessible_name_italic": "Kursivschrift Format",
    "actions_edit_underline": "Unterstreichen",
    "actions_edit_accessible_name_underline": "Unterstrichen Textformat",
    "actions_edit_strikethrough": "Durchgestrichen",
    "actions_edit_accessible_name_strikethrough": "Durchgestrichenes Textformat",
    "actions_edit_blockquote": "Blockzitat",
    "actions_edit_accessible_name_blockquote": "Blockzitat Textformat",

    "actions_tools_ai_assistant": "KI-Assistent",
    "actions_tools_accessible_name_ai_assistant": "KI-Assistent starten",
    "actions_tools_color_picker": "Farbwähler",
    "actions_tools_accessible_name_color_picker": "Textfarbe auswählen",

    "actions_help_label_md_syntax": "Markdown-Syntax",
    "actions_help_accessible_name_md_syntax": "Markdown-Syntax",
    "actions_help_label_check_for_updates": "Auf Updates prüfen",
    "actions_help_accessible_name_check_for_updates": "Auf Updates prüfen",
    "actions_help_label_bug_report": "Fehlerbericht",
    "actions_help_accessible_name_bug_report": "Fehlerbericht senden",
    "actions_help_label_about": "Über",
    "actions_help_accessible_name_about": "Über",
}
