# Swedish lexemes ai_assistant.py
lexemes = {
    # AI assistant dialog
    "dialog_title": "Förfrågan till AI",
    "dialog_prompt_input_placeholder_text": "Förfrågan",
    "dialog_prompt_input_accessible_description": "Ange en förfrågan för att ge kontext till AI-assistenten",
    "dialog_response_output_placeholder_text": "Svarsdata",
    "dialog_response_output_accessible_description": "Svarsdata kommer att visas i detta fält",
    "dialog_response_output_notice_empty_text": "Ange text för att få ett svar om...",

    "dialog_usage_module_label": "MODUL",
    "dialog_usage_model_label": "MODELL",
    "dialog_usage_tokens_label": "TOKENS",
    "dialog_usage_tokens_prompt": "prompt: {tokens}",
    "dialog_usage_tokens_answer": "svar: {tokens}",
    "dialog_usage_tokens_total": "totalt: {tokens}",

    "dialog_button_send_request": "Skicka förfrågan",
    "dialog_button_stop_request": "Stoppa",
    "dialog_button_save_history": "Spara dialoghistorik",

    "dialog_message_copy_tooltip": "Kopiera text",
    "dialog_message_copied_tooltip": "Kopierad",

    "dialog_error_loading_model": "Fel vid laddning av anpassad modell",
}
