# Georgian lexemes ai_assistant.py
lexemes = {
    # ხელმძღვანელობა AI-თან დიალოგი
    "dialog_title": "მოთხოვნა AI-სთან",
    "dialog_prompt_input_placeholder_text": "მოთხოვნა",
    "dialog_prompt_input_accessible_description": "შეიყვანეთ მოთხოვნა, რათა მიეცით კონტექსტი AI ასისტენტს",
    "dialog_response_output_placeholder_text": "პასუხის მონაცემები",
    "dialog_response_output_accessible_description": "პასუხის მონაცემები გამოჩნდება ამ ველში",
    "dialog_response_output_notice_empty_text": "შეიყვანეთ ტექსტი, რათა მიიღოთ პასუხი დაახლოებით...",

    "dialog_usage_module_label": "მოდული",
    "dialog_usage_model_label": "მოდელი",
    "dialog_usage_tokens_label": "ტოკენები",
    "dialog_usage_tokens_prompt": "მოთხოვნა: {tokens}",
    "dialog_usage_tokens_answer": "პასუხი: {tokens}",
    "dialog_usage_tokens_total": "ჯამში: {tokens}",

    "dialog_button_send_request": "მოთხოვნის გაგზავნა",
    "dialog_button_stop_request": "შეჩერე",
    "dialog_button_save_history": "დიალოგის ისტორიის შენახვა",

    "dialog_message_copy_tooltip": "ტექსტის კოპირება",
    "dialog_message_copied_tooltip": "დაკოპირებულია",

    "dialog_error_loading_model": "შეცდომა საბაჟო მოდელის ჩატვირთვისას",
}
