# Latin lexemes common.py
lexemes = {
    "module_llama_cpp_name": "Modulus llama.cpp",

    "module_llama_cpp_model_exception": "Error: Model non inventus: {error_msg}",
    "module_llama_cpp_task_exception": "Generatorem modeli initiare non potest: {error_msg}",
}
