# French lexemes common.py
lexemes = {
    "module_llama_cpp_name": "Module llama.cpp",

    "module_llama_cpp_model_exception": "Erreur modèle non trouvé : {error_msg}",
    "module_llama_cpp_task_exception": "Impossible d'initialiser le générateur de modèle : {error_msg}",
}
