# Portuguese lexemes common.py
lexemes = {
    # Common
    "module_ondevice_llm_name": "LLM no dispositivo",

    "module_ondevice_llm_model_exception": "Erro de modelo não encontrado: {error_msg}",
    "module_ondevice_llm_task_exception": "Não é possível iniciar o gerador de modelo: {error_msg}",
}
