QDialog {
    background-color: #3F3F3F;
    border: none;
}
QFrame {
    border: none;
}
QLabel {
    color: #eeeeee;
}
QLabel#app_icon {
    margin: 0 0 15px;
}
QLabel#app_name {
    font-weight: bold;
    margin: 0;
}
QLabel#app_name_caption {
    color: grey;
    margin: 0 0 15px;
}
QLabel#label_widget {
    font-weight: bold;
}
QLabel#value_widget {
    text-align: left;
}
QPushButton#value_widget_link {
    color: orangeRed;
    text-decoration: underline;
    border: none;
    background-color: transparent;
    text-align: left;
}
QPushButton#value_widget_icon_link {
    border: none;
    background-color: transparent;
}
QPushButton#value_widget_link:hover {
    color: white;
    background-color: orangeRed;
    text-decoration: none;
}
