# German lexemes settings_dialog.py
lexemes = {
    # Einstellungen
    "window_title": "Einstellungen",

    "button_close": "Schließen",

    "tab_general": "Allgemein",
    "tab_editor_config": "Editor",
    "tab_viewer_config": "Betrachter",
    "tab_ai_config": "KI-Konfiguration",

    "general_app_config_label": "App-Konfiguration",
    "general_app_language_label": "Sprache",
    "general_app_language_combo_placeholder_text": "Sprache wählen",
    "general_app_language_combo_accessible_description": "Sprache der App-Oberfläche",
    "general_app_theme_label": "Thema",
    "general_app_theme_combo_placeholder_text": "Thema wählen",
    "general_app_theme_combo_accessible_description": "Thema der App-Oberfläche",
    "general_app_main_menu_label": "Hauptmenü",
    "general_app_main_menu_checkbox": "Hauptmenü anzeigen",
    "general_app_main_menu_checkbox_accessible_description": "Das Haupt-Dropdown-Menü der App anzeigen",
    "general_app_font_size_label": "Schriftgröße: {size}pt",
    "general_app_font_size_slider_accessible_description": "Globale Schriftgröße der App anpassen",

    "general_statusbar_label": "Statusleiste",
    "general_statusbar_show_global_cursor_position_checkbox": "Globale Cursorposition anzeigen",
    "general_statusbar_show_global_cursor_position_checkbox_accessible_description":
        "Globale Cursorposition in der Statusleiste anzeigen",

    "editor_config_label": "Editor-Konfiguration",
    "editor_config_show_line_numbers_checkbox": "Zeilennummern anzeigen",
    "editor_config_show_line_numbers_checkbox_accessible_description": "Zeilennummern im Editor anzeigen",

    "viewer_config_label": "Viewer-Konfiguration",
    "viewer_config_process_emojis_checkbox": "Text-Emojis in Grafiken umwandeln",
    "viewer_config_process_emojis_checkbox_accessible_description": "Text-Emojis in grafische Darstellungen umwandeln",
    "viewer_config_highlight_todos_checkbox": "TODOs hervorheben",
    "viewer_config_highlight_todos_checkbox_accessible_description": "TODOs im Text hervorheben",
    "viewer_config_open_link_confirmation_checkbox": "Bestätigung vor dem Öffnen von Links erforderlich",
    "viewer_config_open_link_confirmation_checkbox_accessible_description":
        "Vor dem Öffnen von Links eine Bestätigung anfordern",
    "viewer_config_save_resources_checkbox": "Externe Bilder automatisch auf Festplatte speichern",
    "viewer_config_save_resources_checkbox_accessible_description":
        "Speichert automatisch Kopien von externen Bildern auf der Festplatte für den Offline-Zugriff.",

    "ai_config_inference_module_label": "Inferenzmodul",
    "ai_config_inference_module_names_combo_label": "Aktives Inferenzmodul",
    "ai_config_inference_module_names_combo_placeholder_text": "Modul wählen",
    "ai_config_inference_module_names_combo_accessible_description":
        "Wählen Sie aus den verfügbaren KI-Inferenzmodulen, um mit dem AI-Assistenten zu arbeiten.\n"
        "Optionen umfassen lokale große Sprachmodelle (LLM) mit Echtzeitverarbeitung oder API-basierte Funktionalitäten.",

    "ai_config_base_label": "Grundlegende Parameter",
    "ai_config_multi_turn_dialogue_checkbox": "Mehrstufiger Dialog mit Gesprächsspeicher",
    "ai_config_multi_turn_dialogue_checkbox_accessible_description":
        "Aktivieren Sie einen mehrstufigen Dialog, der die vorherige Eingabe für den Gesprächsspeicher beibehält.\n"
        "Wenn deaktiviert, beeinflussen nur die neue Nachricht und die Systemaufforderung die Antwort.",
    "ai_config_convert_to_md_checkbox": "Ergebnis in Markdown umwandeln",
    "ai_config_convert_to_md_checkbox_accessible_description":
        "Konvertieren Sie die Ausgabemeldung in das Markdown-Format.",
}
