# Hindi lexemes main_menu.py
lexemes = {
    "group_file_label": "फ़ाइल",
    "group_edit_label": "संपादित करें",
    "group_tools_label": "उपकरण",
    "group_help_label": "सहायता",

    "actions_file_label_new_document": "नया दस्तावेज़",
    "actions_file_accessible_name_new_document": "नया दस्तावेज़",
    "actions_file_label_open": "खोलें",
    "actions_file_accessible_name_open": "दस्तावेज़ खोलें",
    "actions_file_label_save": "सहेजें",
    "actions_file_accessible_name_save": "दस्तावेज़ सहेजें",
    "actions_file_label_save_as": "इस रूप में सहेजें",
    "actions_file_accessible_name_save_as": "दस्तावेज़ की प्रतिलिपि सहेजें",
    "actions_file_label_settings": "सेटिंग्स",
    "actions_file_accessible_name_settings": "ऐप सेटिंग्स",
    "actions_file_label_reset_settings": "सेटिंग्स रीसेट करें",
    "actions_file_accessible_name_reset_settings": "सेटिंग्स रीसेट करें",
    "actions_file_label_exit": "बाहर निकलें",
    "actions_file_accessible_name_exit": "ऐप से बाहर निकलें",

    "actions_edit_edit_mode": "संपादन",
    "actions_edit_accessible_name_edit_mode": "फ़ाइल संपादित करें",
    "actions_edit_source_mode": "स्रोत",
    "actions_edit_accessible_name_source_mode": "स्रोत कोड",
    "actions_edit_bold": "बोल्ड",
    "actions_edit_accessible_name_bold": "बोल्ड पाठ स्वरूप",
    "actions_edit_italic": "इटैलिक",
    "actions_edit_accessible_name_italic": "इटैलिक पाठ स्वरूप",
    "actions_edit_underline": "रेखांकित",
    "actions_edit_accessible_name_underline": "रेखांकित पाठ स्वरूप",
    "actions_edit_strikethrough": "कटाई",
    "actions_edit_accessible_name_strikethrough": "कटाई पाठ स्वरूप",
    "actions_edit_blockquote": "ब्लॉककोट",
    "actions_edit_accessible_name_blockquote": "ब्लॉककोट पाठ स्वरूप",

    "actions_tools_ai_assistant": "एआई सहायक",
    "actions_tools_accessible_name_ai_assistant": "एआई सहायक शुरू करें",
    "actions_tools_color_picker": "रंग चयनकर्ता",
    "actions_tools_accessible_name_color_picker": "पाठ का रंग चुनें",

    "actions_help_label_md_syntax": "मार्कडाउन वाक्य रचना",
    "actions_help_accessible_name_md_syntax": "मार्कडाउन वाक्य रचना",
    "actions_help_label_check_for_updates": "अपडेट की जाँच करें",
    "actions_help_accessible_name_check_for_updates": "अपडेट की जाँच करें",
    "actions_help_label_bug_report":  "बग रिपोर्ट",
    "actions_help_accessible_name_bug_report": "बग रिपोर्ट जमा करें",
    "actions_help_label_about": "बारे में",
    "actions_help_accessible_name_about": "बारे में"
}
