# Georgian lexemes main_menu.py
lexemes = {
    "group_file_label": "ფაილი",
    "group_edit_label": "რედაქტირება",
    "group_tools_label": "ინსტრუმენტები",
    "group_help_label": "დახმარება",

    "actions_file_label_new_document": "ახალი დოკუმენტი",
    "actions_file_accessible_name_new_document": "ახალი დოკუმენტი",
    "actions_file_label_open": "გახსნა",
    "actions_file_accessible_name_open": "დოკუმენტის გახსნა",
    "actions_file_label_save": "შენახვა",
    "actions_file_accessible_name_save": "დოკუმენტის შენახვა",
    "actions_file_label_save_as": "შენახვა როგორც",
    "actions_file_accessible_name_save_as": "დოკუმენტის ასლის შენახვა",
    "actions_file_label_settings": "პარამეტრები",
    "actions_file_accessible_name_settings": "აპლიკაციის პარამეტრები",
    "actions_file_label_reset_settings": "პარამეტრების აღდგენა",
    "actions_file_accessible_name_reset_settings": "პარამეტრების აღდგენა",
    "actions_file_label_exit": "გასვლა",
    "actions_file_accessible_name_exit": "აპლიკაციის დატოვება",

    "actions_edit_edit_mode": "რედაქტირების რეჟიმი",
    "actions_edit_accessible_name_edit_mode": "ფაილის რედაქტირება",
    "actions_edit_source_mode": "წყარო",
    "actions_edit_accessible_name_source_mode": "წყაროს კოდი",
    "actions_edit_bold": "მუქი",
    "actions_edit_accessible_name_bold": "ტექსტის მუქი ფორმატი",
    "actions_edit_italic": "კურსივი",
    "actions_edit_accessible_name_italic": "ტექსტის კურსივის ფორმატი",
    "actions_edit_underline": "ხაზგასმა",
    "actions_edit_accessible_name_underline": "ტექსტის ხაზგასმის ფორმატი",
    "actions_edit_strikethrough": "ხაზზეთმის ფორმატი",
    "actions_edit_accessible_name_strikethrough": "ტექსტის ხაზზეთმის ფორმატი",
    "actions_edit_blockquote": "ციტატა",
    "actions_edit_accessible_name_blockquote": "ტექსტის ციტირების ფორმატი",

    "actions_tools_ai_assistant": "AI ასისტენტი",
    "actions_tools_accessible_name_ai_assistant": "AI ასისტენტის გაშვება",
    "actions_tools_color_picker": "ფერის შერჩევის ინსტრუმენტი",
    "actions_tools_accessible_name_color_picker": "ტექსტის ფერის არჩევა",

    "actions_help_label_md_syntax": "Markdown სინტაქსი",
    "actions_help_accessible_name_md_syntax": "Markdown სინტაქსი",
    "actions_help_label_check_for_updates": "განახლებების შემოწმება",
    "actions_help_accessible_name_check_for_updates": "განახლებების შემოწმება",
    "actions_help_label_bug_report": "შეცდომის რეპორტი",
    "actions_help_accessible_name_bug_report": "შეცდომის რეპორტის შეყვანა",
    "actions_help_label_about": "შესახებ",
    "actions_help_accessible_name_about": "აპლიკაციის შესახებ",
}
