QToolBar QLineEdit#search_input {
    color: whiteSmoke;
}
QToolBar QPushButton {
    margin-left: 2px;
}
QToolBar QLabel#search_count_label {
    background-color: rgba(255, 0, 0, 0.8);
    color: whiteSmoke;
    border-radius: 2px;
    font-weight: bold;
    margin: 1px;
}
QToolBar QLabel#search_pos_label {
    background-color: white;
    color: red;
    border-radius: 2px;
    margin: 3px 2px;
}
