# Italian lexemes ai_assistant.py
lexemes = {
    # Assistente IA
    "dialog_title": "Richiesta all'IA",
    "dialog_prompt_input_placeholder_text": "Richiesta",
    "dialog_prompt_input_accessible_description": "Inserisci richiesta per fornire contesto all'assistente IA",
    "dialog_response_output_placeholder_text": "Dati di risposta",
    "dialog_response_output_accessible_description": "I dati di risposta appariranno in questo campo",
    "dialog_response_output_notice_empty_text": "Fornisci un input di testo per ricevere una risposta di circa...",

    "dialog_usage_module_label": "MODULO",
    "dialog_usage_model_label": "MODELLO",
    "dialog_usage_tokens_label": "TOKEN",
    "dialog_usage_tokens_prompt": "prompt: {tokens}",
    "dialog_usage_tokens_answer": "risposta: {tokens}",
    "dialog_usage_tokens_total": "totale: {tokens}",

    "dialog_button_send_request": "Invia richiesta",
    "dialog_button_stop_request": "Stop",
    "dialog_button_save_history": "Salva la cronologia della conversazione",

    "dialog_message_copy_tooltip": "Copia testo",
    "dialog_message_copied_tooltip": "Copiato",

    "dialog_error_loading_model": "Errore nel caricamento del modello personalizzato",
}
