# Hindi lexemes ai_assistant.py
lexemes = {
    "dialog_title": "एआई से अनुरोध",
    "dialog_prompt_input_placeholder_text": "अनुरोध",
    "dialog_prompt_input_accessible_description": "एआई-सहायक को संदर्भ प्रदान करने के लिए अनुरोध दर्ज करें",
    "dialog_response_output_placeholder_text": "प्रतिक्रिया डेटा",
    "dialog_response_output_accessible_description": "प्रतिक्रिया डेटा इस फ़ील्ड में प्रदर्शित होगा",
    "dialog_response_output_notice_empty_text": "प्रतिक्रिया प्राप्त करने के लिए पाठ इनपुट प्रदान करें...",

    "dialog_usage_module_label": "मॉड्यूल",
    "dialog_usage_model_label": "मॉडल",
    "dialog_usage_tokens_label": "टोकन",
    "dialog_usage_tokens_prompt": "प्रॉम्प्ट: {tokens}",
    "dialog_usage_tokens_answer": "उत्तर: {tokens}",
    "dialog_usage_tokens_total": "कुल: {tokens}",

    "dialog_button_send_request": "अनुरोध भेजें",
    "dialog_button_stop_request": "रोकें",
    "dialog_button_save_history": "डायलॉग इतिहास सहेजें",

    "dialog_message_copy_tooltip": "पाठ कॉपी करें",
    "dialog_message_copied_tooltip": "कॉपी किया गया",

    "dialog_error_loading_model": "कस्टम मॉडल लोड करने में त्रुटि",
}
