# Portuguese lexemes color_picker_dialog.py
lexemes = {
    "color_picker_title": "Selecionar uma cor",

    "color_picker_color_black": "Preto",
    "color_picker_color_silver": "Prata",
    "color_picker_color_gray": "Cinza",
    "color_picker_color_white": "Branco",
    "color_picker_color_maroon": "Bordô",
    "color_picker_color_red": "Vermelho",
    "color_picker_color_purple": "Roxo",
    "color_picker_color_fuchsia": "Fúcsia",
    "color_picker_color_green": "Verde",
    "color_picker_color_lime": "Lima",
    "color_picker_color_olive": "Oliva",
    "color_picker_color_yellow": "Amarelo",
    "color_picker_color_navy": "Azul-marinho",
    "color_picker_color_blue": "Azul",
    "color_picker_color_teal": "Azul-petróleo",
    "color_picker_color_aqua": "Água",
    "color_picker_color_aliceblue": "Azul Alice",
    "color_picker_color_antiquewhite": "Branco Antigo",
    "color_picker_color_aquamarine": "Água-marinha",
    "color_picker_color_azure": "Azul-celeste",
    "color_picker_color_beige": "Bege",
    "color_picker_color_bisque": "Biscoito",
    "color_picker_color_blanchedalmond": "Amêndoa Branqueada",
    "color_picker_color_blueviolet": "Azul-violeta",
    "color_picker_color_brown": "Marrom",
    "color_picker_color_burlywood": "Madeira",
    "color_picker_color_cadetblue": "Azul Cadete",
    "color_picker_color_chartreuse": "Chartreuse",
    "color_picker_color_chocolate": "Chocolate",
    "color_picker_color_coral": "Coral",
    "color_picker_color_cornflowerblue": "Azul Centáurea",
    "color_picker_color_cornsilk": "Seda de Milho",
    "color_picker_color_crimson": "Carmesim",
    "color_picker_color_cyan": "Ciano",
    "color_picker_color_darkblue": "Azul Escuro",
    "color_picker_color_darkcyan": "Ciano Escuro",
    "color_picker_color_darkgoldenrod": "Dourado Escuro",
    "color_picker_color_darkgray": "Cinza Escuro",
    "color_picker_color_darkgreen": "Verde Escuro",
    "color_picker_color_darkkhaki": "Caqui Escuro",
    "color_picker_color_darkmagenta": "Magenta Escuro",
    "color_picker_color_darkolivegreen": "Oliva Escura",
    "color_picker_color_darkorange": "Laranja Escuro",
    "color_picker_color_darkorchid": "Orquídea Escura",
    "color_picker_color_darkred": "Vermelho Escuro",
    "color_picker_color_darksalmon": "Salmão Escuro",
    "color_picker_color_darkseagreen": "Verde-mar Escuro",
    "color_picker_color_darkslateblue": "Azul-ardósia Escuro",
    "color_picker_color_darkslategray": "Cinza-ardósia Escuro",
    "color_picker_color_darkturquoise": "Turquesa Escuro",
    "color_picker_color_darkviolet": "Violeta Escuro",
    "color_picker_color_deeppink": "Rosa Profundo",
    "color_picker_color_deepskyblue": "Azul Céu Profundo",
    "color_picker_color_dimgray": "Cinza Escuro",
    "color_picker_color_dodgerblue": "Azul Dodger",
    "color_picker_color_firebrick": "Tijolo Refratário",
    "color_picker_color_floralwhite": "Branco Floral",
    "color_picker_color_forestgreen": "Verde Floresta",
    "color_picker_color_gainsboro": "Gainsboro",
    "color_picker_color_ghostwhite": "Branco Fantasma",
    "color_picker_color_gold": "Ouro",
    "color_picker_color_goldenrod": "Dourado",
    "color_picker_color_greenyellow": "Verde Amarelado",
    "color_picker_color_honeydew": "Mel",
    "color_picker_color_hotpink": "Rosa Choque",
    "color_picker_color_indianred": "Vermelho Índio",
    "color_picker_color_indigo": "Índigo",
    "color_picker_color_ivory": "Marfim",
    "color_picker_color_khaki": "Caqui",
    "color_picker_color_lavender": "Lavanda",
    "color_picker_color_lavenderblush": "Lavanda Rosada",
    "color_picker_color_lawngreen": "Verde Grama",
    "color_picker_color_lemonchiffon": "Chiffon de Limão",
    "color_picker_color_lightblue": "Azul Claro",
    "color_picker_color_lightcoral": "Coral Claro",
    "color_picker_color_lightcyan": "Ciano Claro",
    "color_picker_color_lightgoldenrodyellow": "Amarelo Ouro Claro",
    "color_picker_color_lightgray": "Cinza Claro",
    "color_picker_color_lightgreen": "Verde Claro",
    "color_picker_color_lightpink": "Rosa Claro",
    "color_picker_color_lightsalmon": "Salmão Claro",
    "color_picker_color_lightseagreen": "Verde-mar Claro",
    "color_picker_color_lightskyblue": "Azul Céu Claro",
    "color_picker_color_lightslategray": "Cinza-ardósia Claro",
    "color_picker_color_lightsteelblue": "Azul Aço Claro",
    "color_picker_color_lightyellow": "Amarelo Claro",
    "color_picker_color_limegreen": "Verde Lima",
    "color_picker_color_linen": "Linho",
    "color_picker_color_magenta": "Magenta",
    "color_picker_color_mediumaquamarine": "Água-marinha Médio",
    "color_picker_color_mediumblue": "Azul Médio",
    "color_picker_color_mediumorchid": "Orquídea Média",
    "color_picker_color_mediumpurple": "Púrpura Médio",
    "color_picker_color_mediumseagreen": "Verde-mar Médio",
    "color_picker_color_mediumslateblue": "Azul-ardósia Médio",
    "color_picker_color_mediumspringgreen": "Verde Primavera Médio",
    "color_picker_color_mediumturquoise": "Turquesa Médio",
    "color_picker_color_mediumvioletred": "Vermelho-violeta Médio",
    "color_picker_color_midnightblue": "Azul Meia-noite",
    "color_picker_color_mintcream": "Creme de Menta",
    "color_picker_color_mistyrose": "Rosa Névoa",
    "color_picker_color_moccasin": "Mocassim",
    "color_picker_color_navajowhite": "Branco Navajo",
    "color_picker_color_oldlace": "Renda Antiga",
    "color_picker_color_olivedrab": "Oliva Parda",
    "color_picker_color_orange": "Laranja",
    "color_picker_color_orangered": "Vermelho-laranja",
    "color_picker_color_orchid": "Orquídea",
    "color_picker_color_palegoldenrod": "Dourado Pálido",
    "color_picker_color_palegreen": "Verde Pálido",
    "color_picker_color_paleturquoise": "Turquesa Pálido",
    "color_picker_color_palevioletred": "Vermelho-violeta Pálido",
    "color_picker_color_papayawhip": "Creme de Papaia",
    "color_picker_color_peachpuff": "Pêssego",
    "color_picker_color_peru": "Peru",
    "color_picker_color_pink": "Rosa",
    "color_picker_color_plum": "Ameixa",
    "color_picker_color_powderblue": "Azul Pó",
    "color_picker_color_rebeccapurple": "Roxo Rebecca",
    "color_picker_color_rosybrown": "Marrom Rosado",
    "color_picker_color_royalblue": "Azul Real",
    "color_picker_color_saddlebrown": "Marrom Sela",
    "color_picker_color_salmon": "Salmão",
    "color_picker_color_sandybrown": "Marrom Areia",
    "color_picker_color_seagreen": "Verde-mar",
    "color_picker_color_seashell": "Concha",
    "color_picker_color_sienna": "Siena",
    "color_picker_color_skyblue": "Azul Céu",
    "color_picker_color_slateblue": "Azul Ardósia",
    "color_picker_color_slategray": "Cinza Ardósia",
    "color_picker_color_snow": "Neve",
    "color_picker_color_springgreen": "Verde Primavera",
    "color_picker_color_steelblue": "Azul Aço",
    "color_picker_color_tan": "Bronzeado",
    "color_picker_color_thistle": "Cardo",
    "color_picker_color_tomato": "Tomate",
    "color_picker_color_turquoise": "Turquesa",
    "color_picker_color_violet": "Violeta",
    "color_picker_color_wheat": "Trigo",
    "color_picker_color_whitesmoke": "Fumaça Branca",
    "color_picker_color_yellowgreen": "Verde-amarelo",
}
