# Chinese lexemes ai_assistant.py
lexemes = {
    # AI 助手
    "dialog_title": "向 AI 提问",
    "dialog_prompt_input_placeholder_text": "请求",
    "dialog_prompt_input_accessible_description": "输入请求以提供给 AI 助手上下文",
    "dialog_response_output_placeholder_text": "响应数据",
    "dialog_response_output_accessible_description": "响应数据将出现在此字段",
    "dialog_response_output_notice_empty_text": "提供文本输入以获得大约...",

    "dialog_usage_module_label": "模块",
    "dialog_usage_model_label": "模型",
    "dialog_usage_tokens_label": "令牌",
    "dialog_usage_tokens_prompt": "提示：{tokens}",
    "dialog_usage_tokens_answer": "答案：{tokens}",
    "dialog_usage_tokens_total": "总计：{tokens}",

    "dialog_button_send_request": "发送请求",
    "dialog_button_stop_request": "停止",
    "dialog_button_save_history": "保存对话历史",

    "dialog_message_copy_tooltip": "复制文本",
    "dialog_message_copied_tooltip": "已复制",

    "dialog_error_loading_model": "加载自定义模型错误",
}
