# Turkish lexemes ai_assistant.py
lexemes = {
    "dialog_title": "AI'ya İstek",
    "dialog_prompt_input_placeholder_text": "İstek",
    "dialog_prompt_input_accessible_description": "AI yardımcısına bağlam sağlamak için istek girin",
    "dialog_response_output_placeholder_text": "Yanıt verisi",
    "dialog_response_output_accessible_description": "Yanıt verisi bu alanda görünecek",
    "dialog_response_output_notice_empty_text": "Yaklaşık bir yanıt almak için metin girişi sağlayın",

    "dialog_usage_module_label": "MODÜL",
    "dialog_usage_model_label": "MODEL",
    "dialog_usage_tokens_label": "TOKENLAR",
    "dialog_usage_tokens_prompt": "istek: {tokens}",
    "dialog_usage_tokens_answer": "cevap: {tokens}",
    "dialog_usage_tokens_total": "toplam: {tokens}",

    "dialog_button_send_request": "İstek Gönder",
    "dialog_button_stop_request": "Durdur",
    "dialog_button_save_history": "Sohbet geçmişini kaydet",

    "dialog_message_copy_tooltip": "Metni kopyala",
    "dialog_message_copied_tooltip": "Kopyalandı",

    "dialog_error_loading_model": "Özel model yüklenirken hata",
}
