# Dutch lexemes common.py
lexemes = {
    "module_llama_cpp_name": "Module llama.cpp",

    "module_llama_cpp_model_exception": "Model niet gevonden fout: {error_msg}",
    "module_llama_cpp_task_exception": "Kan modelgenerator niet initialiseren: {error_msg}",
}
