# French lexemes main_menu.py
lexemes = {
    "group_file_label": "Fichier",
    "group_edit_label": "Éditer",
    "group_tools_label": "Outils",
    "group_help_label": "Aide",

    "actions_file_label_new_document": "Nouveau document",
    "actions_file_accessible_name_new_document": "Nouveau document",
    "actions_file_label_open": "Ouvrir",
    "actions_file_accessible_name_open": "Ouvrir le document",
    "actions_file_label_save": "Enregistrer",
    "actions_file_accessible_name_save": "Enregistrer le document",
    "actions_file_label_save_as": "Enregistrer sous",
    "actions_file_accessible_name_save_as": "Enregistrer une copie du document",
    "actions_file_label_settings": "Paramètres",
    "actions_file_accessible_name_settings": "Paramètres de l'application",
    "actions_file_label_reset_settings": "Réinitialiser les paramètres",
    "actions_file_accessible_name_reset_settings": "Réinitialiser les paramètres",
    "actions_file_label_exit": "Quitter",
    "actions_file_accessible_name_exit": "Quitter l'application",

    "actions_edit_edit_mode": "Modifier",
    "actions_edit_accessible_name_edit_mode": "Modifier le fichier",
    "actions_edit_source_mode": "Source",
    "actions_edit_accessible_name_source_mode": "Code source",
    "actions_edit_bold": "Gras",
    "actions_edit_accessible_name_bold": "Format de texte en gras",
    "actions_edit_italic": "Italique",
    "actions_edit_accessible_name_italic": "Format de texte en italique",
    "actions_edit_underline": "Souligner",
    "actions_edit_accessible_name_underline": "Format de texte souligné",
    "actions_edit_strikethrough": "Barré",
    "actions_edit_accessible_name_strikethrough": "Format de texte barré",
    "actions_edit_blockquote": "Citation",
    "actions_edit_accessible_name_blockquote": "Format de texte de citation",

    "actions_tools_ai_assistant": "Assistant IA",
    "actions_tools_accessible_name_ai_assistant": "Lancer l'assistant IA",
    "actions_tools_color_picker": "Sélecteur de couleur",
    "actions_tools_accessible_name_color_picker": "Choisir une couleur de texte",

    "actions_help_label_md_syntax": "Syntaxe Markdown",
    "actions_help_accessible_name_md_syntax": "Syntaxe Markdown",
    "actions_help_label_check_for_updates": "Vérifier les mises à jour",
    "actions_help_accessible_name_check_for_updates": "Vérifier les mises à jour",
    "actions_help_label_bug_report": "Rapport de bug",
    "actions_help_accessible_name_bug_report": "Soumettre un rapport de bug",
    "actions_help_label_about": "À propos",
    "actions_help_accessible_name_about": "À propos",
}
