# Dutch lexemes statusbar.py
lexemes = {
    "statusbar_litter_bin_label": "Prullenbak",
    "statusbar_litter_bin_accessible_name": "Toon inhoud prullenbak",

    "statusbar_save_progress_label": b'\xf0\x9f\x92\xbe',
    "statusbar_encryption_symbol_encrypted_label": b'\xf0\x9f\x94\x92',
    "statusbar_encryption_symbol_unencrypted_label": b'\xf0\x9f\x94\x93',

    "statusbar_mode_label_mode_view": "Weergavemodus",
    "statusbar_mode_label_mode_edit": "Bewerkingsmodus",
    "statusbar_mode_label_mode_source": "Bronmodus",

    "statusbar_source_label_source_markdown": "Markdown",
    "statusbar_source_label_source_html": "HTML",

    "statusbar_encryption_label": "{encryption} {icon}",
    "statusbar_encryption_label_encryption_plain": "Ongesleuteld",
    "statusbar_encryption_label_encryption_encrypted": "Versleuteld",

    "statusbar_cursor_label": "regel: {line} → kol: {column}",
    "statusbar_cursor_label_selected": "regel: {line} → kol: {column} → sel: {selected}",
    "statusbar_cursor_label_with_global": "regel: {line} → kol: {column} → pos: {position}",
    "statusbar_cursor_label_selected_with_global": "regel: {line} → kol: {column} → pos: {position} → sel: {selected}",
}
