# Finnish lexemes ai_assistant.py
lexemes = {
    # AI-assistentin dialogi
    "dialog_title": "Pyyntö tekoälylle",
    "dialog_prompt_input_placeholder_text": "Pyyntö",
    "dialog_prompt_input_accessible_description": "Syötä pyyntö antaaksesi kontekstin tekoälyavustajalle",
    "dialog_response_output_placeholder_text": "Vastausdata",
    "dialog_response_output_accessible_description": "Vastausdata tulee näkyviin tähän kenttään",
    "dialog_response_output_notice_empty_text": "Anna tekstisyöte saadaksesi vastauksen noin...",

    "dialog_usage_module_label": "MODUULI",
    "dialog_usage_model_label": "MALLI",
    "dialog_usage_tokens_label": "TOKENIT",
    "dialog_usage_tokens_prompt": "kehoite: {tokens}",
    "dialog_usage_tokens_answer": "vastaus: {tokens}",
    "dialog_usage_tokens_total": "yhteensä: {tokens}",

    "dialog_button_send_request": "Lähetä pyyntö",
    "dialog_button_stop_request": "Pysäytä",
    "dialog_button_save_history": "Tallenna keskusteluhistoria",

    "dialog_message_copy_tooltip": "Kopioi teksti",
    "dialog_message_copied_tooltip": "Kopioitu",

    "dialog_error_loading_model": "Virhe ladattaessa mukautettua mallia",
}
