# English lexemes common.py
lexemes = {
    "module_llama_cpp_name": "Module llama.cpp",

    "module_llama_cpp_model_exception": "Model not found error: {error_msg}",
    "module_llama_cpp_task_exception": "Cannot init model generator: {error_msg}",
}
