# Dutch lexemes ai_assistant.py
lexemes = {
    # AI assistant dialog
    "dialog_title": "Verzoek aan AI",
    "dialog_prompt_input_placeholder_text": "Verzoek",
    "dialog_prompt_input_accessible_description": "Voer een verzoek in om context te geven aan de AI-assistent",
    "dialog_response_output_placeholder_text": "Responsdata",
    "dialog_response_output_accessible_description": "Responsdata zal hier getoond worden",
    "dialog_response_output_notice_empty_text": "Voer tekst in om een respons van ongeveer... te krijgen",

    "dialog_usage_module_label": "MODULE",
    "dialog_usage_model_label": "MODEL",
    "dialog_usage_tokens_label": "TOKENS",
    "dialog_usage_tokens_prompt": "prompt: {tokens}",
    "dialog_usage_tokens_answer": "antwoord: {tokens}",
    "dialog_usage_tokens_total": "totaal: {tokens}",

    "dialog_button_send_request": "Verstuur Verzoek",
    "dialog_button_stop_request": "Stop",
    "dialog_button_save_history": "Gespreksgeschiedenis opslaan",

    "dialog_message_copy_tooltip": "Tekst kopiëren",
    "dialog_message_copied_tooltip": "Gekopieerd",

    "dialog_error_loading_model": "Fout bij laden aangepast model",
}
