# Chinese lexemes color_picker_dialog.py
lexemes = {
    "color_picker_title": "选择颜色",

    "color_picker_color_black": "黑色",
    "color_picker_color_silver": "银色",
    "color_picker_color_gray": "灰色",
    "color_picker_color_white": "白色",
    "color_picker_color_maroon": "栗色",
    "color_picker_color_red": "红色",
    "color_picker_color_purple": "紫色",
    "color_picker_color_fuchsia": "紫红色",
    "color_picker_color_green": "绿色",
    "color_picker_color_lime": "酸橙色",
    "color_picker_color_olive": "橄榄色",
    "color_picker_color_yellow": "黄色",
    "color_picker_color_navy": "海军蓝",
    "color_picker_color_blue": "蓝色",
    "color_picker_color_teal": "水鸭色",
    "color_picker_color_aqua": "水色",
    "color_picker_color_aliceblue": "爱丽丝蓝",
    "color_picker_color_antiquewhite": "古董白",
    "color_picker_color_aquamarine": "碧绿色",
    "color_picker_color_azure": "天蓝色",
    "color_picker_color_beige": "米色",
    "color_picker_color_bisque": "桔黄色",
    "color_picker_color_blanchedalmond": "漂白杏仁",
    "color_picker_color_blueviolet": "蓝紫色",
    "color_picker_color_brown": "棕色",
    "color_picker_color_burlywood": "硬木色",
    "color_picker_color_cadetblue": "军校蓝",
    "color_picker_color_chartreuse": "查特酒绿",
    "color_picker_color_chocolate": "巧克力色",
    "color_picker_color_coral": "珊瑚色",
    "color_picker_color_cornflowerblue": "矢车菊蓝",
    "color_picker_color_cornsilk": "玉米丝色",
    "color_picker_color_crimson": "深红色",
    "color_picker_color_cyan": "青色",
    "color_picker_color_darkblue": "深蓝色",
    "color_picker_color_darkcyan": "深青色",
    "color_picker_color_darkgoldenrod": "深金黄色",
    "color_picker_color_darkgray": "深灰色",
    "color_picker_color_darkgreen": "深绿色",
    "color_picker_color_darkkhaki": "深卡其布色",
    "color_picker_color_darkmagenta": "深洋红色",
    "color_picker_color_darkolivegreen": "深橄榄绿",
    "color_picker_color_darkorange": "深橙色",
    "color_picker_color_darkorchid": "暗兰花色",
    "color_picker_color_darkred": "深红色",
    "color_picker_color_darksalmon": "深肉色",
    "color_picker_color_darkseagreen": "深海洋绿",
    "color_picker_color_darkslateblue": "深青蓝",
    "color_picker_color_darkslategray": "深石板灰",
    "color_picker_color_darkturquoise": "深绿宝石",
    "color_picker_color_darkviolet": "深紫罗兰色",
    "color_picker_color_deeppink": "深粉色",
    "color_picker_color_deepskyblue": "深天蓝色",
    "color_picker_color_dimgray": "暗灰色",
    "color_picker_color_dodgerblue": "道奇蓝",
    "color_picker_color_firebrick": "火砖色",
    "color_picker_color_floralwhite": "花的白色",
    "color_picker_color_forestgreen": "森林绿",
    "color_picker_color_gainsboro": "淡灰色",
    "color_picker_color_ghostwhite": "幽灵白",
    "color_picker_color_gold": "金色",
    "color_picker_color_goldenrod": "金麒麟色",
    "color_picker_color_greenyellow": "绿黄色",
    "color_picker_color_honeydew": "蜜瓜色",
    "color_picker_color_hotpink": "热粉色",
    "color_picker_color_indianred": "印第安红",
    "color_picker_color_indigo": "靛青",
    "color_picker_color_ivory": "象牙色",
    "color_picker_color_khaki": "卡其色",
    "color_picker_color_lavender": "薰衣草色",
    "color_picker_color_lavenderblush": "薰衣草红",
    "color_picker_color_lawngreen": "草坪绿",
    "color_picker_color_lemonchiffon": "柠檬绸",
    "color_picker_color_lightblue": "淡蓝色",
    "color_picker_color_lightcoral": "浅珊瑚色",
    "color_picker_color_lightcyan": "淡青色",
    "color_picker_color_lightgoldenrodyellow": "淡金黄色",
    "color_picker_color_lightgray": "浅灰色",
    "color_picker_color_lightgreen": "浅绿色",
    "color_picker_color_lightpink": "浅粉色",
    "color_picker_color_lightsalmon": "浅肉色",
    "color_picker_color_lightseagreen": "浅海洋绿",
    "color_picker_color_lightskyblue": "浅天蓝色",
    "color_picker_color_lightslategray": "浅石板灰",
    "color_picker_color_lightsteelblue": "浅钢蓝",
    "color_picker_color_lightyellow": "浅黄色",
    "color_picker_color_limegreen": "酸橙绿",
    "color_picker_color_linen": "亚麻色",
    "color_picker_color_magenta": "品红",
    "color_picker_color_mediumaquamarine": "中碧绿色",
    "color_picker_color_mediumblue": "中蓝色",
    "color_picker_color_mediumorchid": "中兰花紫",
    "color_picker_color_mediumpurple": "中紫色",
    "color_picker_color_mediumseagreen": "中海洋绿",
    "color_picker_color_mediumslateblue": "中暗蓝色",
    "color_picker_color_mediumspringgreen": "中春绿色",
    "color_picker_color_mediumturquoise": "中绿宝石",
    "color_picker_color_mediumvioletred": "中紫罗兰红色",
    "color_picker_color_midnightblue": "午夜蓝",
    "color_picker_color_mintcream": "薄荷奶油",
    "color_picker_color_mistyrose": "浅玫瑰色",
    "color_picker_color_moccasin": "鹿皮鞋色",
    "color_picker_color_navajowhite": "纳瓦白",
    "color_picker_color_oldlace": "旧蕾丝",
    "color_picker_color_olivedrab": "橄榄褐",
    "color_picker_color_orange": "橙色",
    "color_picker_color_orangered": "橙红色",
    "color_picker_color_orchid": "兰花紫",
    "color_picker_color_palegoldenrod": "苍麒麟",
    "color_picker_color_palegreen": "苍绿色",
    "color_picker_color_paleturquoise": "苍绿宝石",
    "color_picker_color_palevioletred": "苍紫罗兰红",
    "color_picker_color_papayawhip": "番木瓜",
    "color_picker_color_peachpuff": "桃色",
    "color_picker_color_peru": "秘鲁色",
    "color_picker_color_pink": "粉红色",
    "color_picker_color_plum": "李子色",
    "color_picker_color_powderblue": "粉蓝色",
    "color_picker_color_rebeccapurple": "丽贝卡紫",
    "color_picker_color_rosybrown": "玫瑰棕色",
    "color_picker_color_royalblue": "宝蓝色",
    "color_picker_color_saddlebrown": "鞍棕色",
    "color_picker_color_salmon": "鲜肉色",
    "color_picker_color_sandybrown": "沙棕色",
    "color_picker_color_seagreen": "海绿色",
    "color_picker_color_seashell": "海贝壳",
    "color_picker_color_sienna": "黄土赭色",
    "color_picker_color_skyblue": "天蓝色",
    "color_picker_color_slateblue": "石蓝色",
    "color_picker_color_slategray": "灰石色",
    "color_picker_color_snow": "雪白色",
    "color_picker_color_springgreen": "春绿色",
    "color_picker_color_steelblue": "钢蓝色",
    "color_picker_color_tan": "棕褐色",
    "color_picker_color_thistle": "蓟色",
    "color_picker_color_tomato": "西红柿红",
    "color_picker_color_turquoise": "绿松石",
    "color_picker_color_violet": "紫罗兰",
    "color_picker_color_wheat": "小麦色",
    "color_picker_color_whitesmoke": "白烟",
    "color_picker_color_yellowgreen": "黄绿色",
}
