# Turkish lexemes color_picker_dialog.py
lexemes = {
    "color_picker_title": "Renk Seç",

    "color_picker_color_black": "Siyah",
    "color_picker_color_silver": "Gümüş",
    "color_picker_color_gray": "Gri",
    "color_picker_color_white": "Beyaz",
    "color_picker_color_maroon": "Bordo",
    "color_picker_color_red": "Kırmızı",
    "color_picker_color_purple": "Mor",
    "color_picker_color_fuchsia": "Fuşya",
    "color_picker_color_green": "Yeşil",
    "color_picker_color_lime": "Açık Yeşil",
    "color_picker_color_olive": "Zeytin Yeşili",
    "color_picker_color_yellow": "Sarı",
    "color_picker_color_navy": "Lacivert",
    "color_picker_color_blue": "Mavi",
    "color_picker_color_teal": "Teal",
    "color_picker_color_aqua": "Su Mavisi",
    "color_picker_color_aliceblue": "Alice Mavisi",
    "color_picker_color_antiquewhite": "Antik Beyaz",
    "color_picker_color_aquamarine": "Akuamarin",
    "color_picker_color_azure": "Gökyüzü Mavisi",
    "color_picker_color_beige": "Bej",
    "color_picker_color_bisque": "Bisküvi",
    "color_picker_color_blanchedalmond": "Beyazlaştırılmış Badem",
    "color_picker_color_blueviolet": "Mavi Menekşe",
    "color_picker_color_brown": "Kahverengi",
    "color_picker_color_burlywood": "Koyu Kavuniçi",
    "color_picker_color_cadetblue": "Askeri Mavi",
    "color_picker_color_chartreuse": "Parlak Sarı Yeşil",
    "color_picker_color_chocolate": "Çikolata",
    "color_picker_color_coral": "Mercan",
    "color_picker_color_cornflowerblue": "Mısır Çiçeği Mavisi",
    "color_picker_color_cornsilk": "Mısır İpeği",
    "color_picker_color_crimson": "Koyu Kırmızı",
    "color_picker_color_cyan": "Cam Göbeği",
    "color_picker_color_darkblue": "Koyu Mavi",
    "color_picker_color_darkcyan": "Koyu Camgöbeği",
    "color_picker_color_darkgoldenrod": "Koyu Altın Rengi",
    "color_picker_color_darkgray": "Koyu Gri",
    "color_picker_color_darkgreen": "Koyu Yeşil",
    "color_picker_color_darkkhaki": "Koyu Haki",
    "color_picker_color_darkmagenta": "Koyu Magenta",
    "color_picker_color_darkolivegreen": "Koyu Zeytin Yeşili",
    "color_picker_color_darkorange": "Koyu Turuncu",
    "color_picker_color_darkorchid": "Koyu Orkide",
    "color_picker_color_darkred": "Koyu Kırmızı",
    "color_picker_color_darksalmon": "Koyu Somon",
    "color_picker_color_darkseagreen": "Koyu Deniz Yeşili",
    "color_picker_color_darkslateblue": "Koyu Arduvaz Mavisi",
    "color_picker_color_darkslategray": "Koyu Arduvaz Gri",
    "color_picker_color_darkturquoise": "Koyu Turkuaz",
    "color_picker_color_darkviolet": "Koyu Menekşe",
    "color_picker_color_deeppink": "Derin Pembe",
    "color_picker_color_deepskyblue": "Derin Gökyüzü Mavisi",
    "color_picker_color_dimgray": "Sisli Gri",
    "color_picker_color_dodgerblue": "Dodger Mavisi",
    "color_picker_color_firebrick": "Ateş Tuğlası",
    "color_picker_color_floralwhite": "Çiçek Beyazı",
    "color_picker_color_forestgreen": "Orman Yeşili",
    "color_picker_color_gainsboro": "Gainsboro",
    "color_picker_color_ghostwhite": "Hayalet Beyazı",
    "color_picker_color_gold": "Altın",
    "color_picker_color_goldenrod": "Altın Rengi",
    "color_picker_color_greenyellow": "Yeşil Sarı",
    "color_picker_color_honeydew": "Bal Rengi",
    "color_picker_color_hotpink": "Canlı Pembe",
    "color_picker_color_indianred": "Hindistan Kırmızısı",
    "color_picker_color_indigo": "Çivit",
    "color_picker_color_ivory": "Fildişi",
    "color_picker_color_khaki": "Haki",
    "color_picker_color_lavender": "Lavanta",
    "color_picker_color_lavenderblush": "Lavanta Pembesi",
    "color_picker_color_lawngreen": "Çim Yeşili",
    "color_picker_color_lemonchiffon": "Limon Şifon",
    "color_picker_color_lightblue": "Açık Mavi",
    "color_picker_color_lightcoral": "Açık Mercan",
    "color_picker_color_lightcyan": "Açık Camgöbeği",
    "color_picker_color_lightgoldenrodyellow": "Açık Altın Sarısı",
    "color_picker_color_lightgray": "Açık Gri",
    "color_picker_color_lightgreen": "Açık Yeşil",
    "color_picker_color_lightpink": "Açık Pembe",
    "color_picker_color_lightsalmon": "Açık Somon",
    "color_picker_color_lightseagreen": "Açık Deniz Yeşili",
    "color_picker_color_lightskyblue": "Açık Gökyüzü Mavisi",
    "color_picker_color_lightslategray": "Açık Arduvaz Gri",
    "color_picker_color_lightsteelblue": "Açık Çelik Mavisi",
    "color_picker_color_lightyellow": "Açık Sarı",
    "color_picker_color_limegreen": "Limon Yeşili",
    "color_picker_color_linen": "Keten",
    "color_picker_color_magenta": "Macenta",
    "color_picker_color_mediumaquamarine": "Orta Akuamarin",
    "color_picker_color_mediumblue": "Orta Mavi",
    "color_picker_color_mediumorchid": "Orta Orkide",
    "color_picker_color_mediumpurple": "Orta Mor",
    "color_picker_color_mediumseagreen": "Orta Deniz Yeşili",
    "color_picker_color_mediumslateblue": "Orta Arduvaz Mavisi",
    "color_picker_color_mediumspringgreen": "Orta İlkbahar Yeşili",
    "color_picker_color_mediumturquoise": "Orta Turkuaz",
    "color_picker_color_mediumvioletred": "Orta Menekşe Kırmızısı",
    "color_picker_color_midnightblue": "Gece Mavisi",
    "color_picker_color_mintcream": "Nane Kreması",
    "color_picker_color_mistyrose": "Sisli Gül",
    "color_picker_color_moccasin": "Mokasen",
    "color_picker_color_navajowhite": "Navajo Beyazı",
    "color_picker_color_oldlace": "Eski Dantel",
    "color_picker_color_olivedrab": "Zeytin Yeşili",
    "color_picker_color_orange": "Turuncu",
    "color_picker_color_orangered": "Turuncu Kırmızı",
    "color_picker_color_orchid": "Orkide",
    "color_picker_color_palegoldenrod": "Soluk Altın Rengi",
    "color_picker_color_palegreen": "Soluk Yeşil",
    "color_picker_color_paleturquoise": "Soluk Turkuaz",
    "color_picker_color_palevioletred": "Soluk Menekşe Kırmızısı",
    "color_picker_color_papayawhip": "Papaya Kreması",
    "color_picker_color_peachpuff": "Şeftali Puf",
    "color_picker_color_peru": "Peru",
    "color_picker_color_pink": "Pembe",
    "color_picker_color_plum": "Erik",
    "color_picker_color_powderblue": "Toz Mavi",
    "color_picker_color_rebeccapurple": "Rebecca Moru",
    "color_picker_color_rosybrown": "Gül Kahverengi",
    "color_picker_color_royalblue": "Kraliyet Mavisi",
    "color_picker_color_saddlebrown": "Eyer Kahverengi",
    "color_picker_color_salmon": "Somon",
    "color_picker_color_sandybrown": "Kum Kahverengi",
    "color_picker_color_seagreen": "Deniz Yeşili",
    "color_picker_color_seashell": "Deniz Kabuğu",
    "color_picker_color_sienna": "Siyenna",
    "color_picker_color_skyblue": "Gökyüzü Mavisi",
    "color_picker_color_slateblue": "Arduvaz Mavisi",
    "color_picker_color_slategray": "Arduvaz Gri",
    "color_picker_color_snow": "Kar",
    "color_picker_color_springgreen": "Bahar Yeşili",
    "color_picker_color_steelblue": "Çelik Mavisi",
    "color_picker_color_tan": "Bronz",
    "color_picker_color_thistle": "Devedikeni",
    "color_picker_color_tomato": "Domates",
    "color_picker_color_turquoise": "Turkuaz",
    "color_picker_color_violet": "Menekşe",
    "color_picker_color_wheat": "Buğday",
    "color_picker_color_whitesmoke": "Beyaz Duman",
    "color_picker_color_yellowgreen": "Sarı Yeşil",
}
