# Hindi lexemes common.py
lexemes = {
    "module_llama_cpp_name": "मॉड्यूल llama.cpp",

    "module_llama_cpp_model_exception": "मॉडल नहीं मिलने की त्रुटि: {error_msg}",
    "module_llama_cpp_task_exception": "मॉडल जनरेटर प्रारंभ नहीं किया जा सकता: {error_msg}",
}
