# Greek lexemes common.py
lexemes = {
    "module_llama_cpp_name": "Μονάδα llama.cpp",

    "module_llama_cpp_model_exception": "Σφάλμα μη εύρεσης μοντέλου: {error_msg}",
    "module_llama_cpp_task_exception": "Αδυναμία αρχικοποίησης του γεννήτριας μοντέλων: {error_msg}",
}
