# Korean lexemes color_picker_dialog.py
lexemes = {
    "color_picker_title": "색상 선택",

    "color_picker_color_black": "검정",
    "color_picker_color_silver": "은색",
    "color_picker_color_gray": "회색",
    "color_picker_color_white": "하얀색",
    "color_picker_color_maroon": "적갈색",
    "color_picker_color_red": "빨간색",
    "color_picker_color_purple": "보라색",
    "color_picker_color_fuchsia": "자홍색",
    "color_picker_color_green": "녹색",
    "color_picker_color_lime": "라임색",
    "color_picker_color_olive": "올리브색",
    "color_picker_color_yellow": "노란색",
    "color_picker_color_navy": "남색",
    "color_picker_color_blue": "파란색",
    "color_picker_color_teal": "청록색",
    "color_picker_color_aqua": "아쿠아",
    "color_picker_color_aliceblue": "앨리스 블루",
    "color_picker_color_antiquewhite": "앤틱 화이트",
    "color_picker_color_aquamarine": "아쿠아마린",
    "color_picker_color_azure": "청색",
    "color_picker_color_beige": "베이지",
    "color_picker_color_bisque": "비스크",
    "color_picker_color_blanchedalmond": "표백 아몬드",
    "color_picker_color_blueviolet": "파랑보라색",
    "color_picker_color_brown": "갈색",
    "color_picker_color_burlywood": "버들나무색",
    "color_picker_color_cadetblue": "카뎃블루",
    "color_picker_color_chartreuse": "샤르트뢰즈",
    "color_picker_color_chocolate": "초콜릿색",
    "color_picker_color_coral": "코랄",
    "color_picker_color_cornflowerblue": "콘플라워 블루",
    "color_picker_color_cornsilk": "콘실크",
    "color_picker_color_crimson": "진홍색",
    "color_picker_color_cyan": "청록색",
    "color_picker_color_darkblue": "어두운 파랑",
    "color_picker_color_darkcyan": "어두운 청록색",
    "color_picker_color_darkgoldenrod": "어두운 황금색",
    "color_picker_color_darkgray": "어두운 회색",
    "color_picker_color_darkgreen": "어두운 녹색",
    "color_picker_color_darkkhaki": "어두운 카키색",
    "color_picker_color_darkmagenta": "어두운 마젠타",
    "color_picker_color_darkolivegreen": "어두운 올리브 그린",
    "color_picker_color_darkorange": "어두운 주황색",
    "color_picker_color_darkorchid": "어두운 난초색",
    "color_picker_color_darkred": "어두운 빨간색",
    "color_picker_color_darksalmon": "어두운 연어색",
    "color_picker_color_darkseagreen": "어두운 바다색",
    "color_picker_color_darkslateblue": "어두운 슬레이트 블루",
    "color_picker_color_darkslategray": "어두운 슬레이트 그레이",
    "color_picker_color_darkturquoise": "어두운 터키석색",
    "color_picker_color_darkviolet": "어두운 보라색",
    "color_picker_color_deeppink": "진분홍색",
    "color_picker_color_deepskyblue": "깊은 하늘색",
    "color_picker_color_dimgray": "탁한 회색",
    "color_picker_color_dodgerblue": "도저 블루",
    "color_picker_color_firebrick": "벽돌색",
    "color_picker_color_floralwhite": "플로랄 화이트",
    "color_picker_color_forestgreen": "숲색",
    "color_picker_color_gainsboro": "게인스보로",
    "color_picker_color_ghostwhite": "고스트 화이트",
    "color_picker_color_gold": "금색",
    "color_picker_color_goldenrod": "황금빛",
    "color_picker_color_greenyellow": "녹황색",
    "color_picker_color_honeydew": "허니듀",
    "color_picker_color_hotpink": "핫핑크",
    "color_picker_color_indianred": "인디언 레드",
    "color_picker_color_indigo": "인디고",
    "color_picker_color_ivory": "상아색",
    "color_picker_color_khaki": "카키",
    "color_picker_color_lavender": "라벤더",
    "color_picker_color_lavenderblush": "라벤더 블러시",
    "color_picker_color_lawngreen": "잔디색",
    "color_picker_color_lemonchiffon": "레몬 쉬폰",
    "color_picker_color_lightblue": "밝은 파랑",
    "color_picker_color_lightcoral": "밝은 산호색",
    "color_picker_color_lightcyan": "밝은 청록색",
    "color_picker_color_lightgoldenrodyellow": "밝은 황금빛",
    "color_picker_color_lightgray": "밝은 회색",
    "color_picker_color_lightgreen": "밝은 녹색",
    "color_picker_color_lightpink": "밝은 핑크",
    "color_picker_color_lightsalmon": "밝은 연어색",
    "color_picker_color_lightseagreen": "밝은 바다색",
    "color_picker_color_lightskyblue": "밝은 하늘색",
    "color_picker_color_lightslategray": "밝은 슬레이트 그레이",
    "color_picker_color_lightsteelblue": "밝은 스틸 블루",
    "color_picker_color_lightyellow": "밝은 노란색",
    "color_picker_color_limegreen": "라임그린",
    "color_picker_color_linen": "리넨",
    "color_picker_color_magenta": "마젠타",
    "color_picker_color_mediumaquamarine": "중간 아쿠아마린",
    "color_picker_color_mediumblue": "중간 파랑",
    "color_picker_color_mediumorchid": "중간 난초",
    "color_picker_color_mediumpurple": "중간 보라",
    "color_picker_color_mediumseagreen": "중간 바다색",
    "color_picker_color_mediumslateblue": "중간 슬레이트 블루",
    "color_picker_color_mediumspringgreen": "중간 봄색",
    "color_picker_color_mediumturquoise": "중간 터키석",
    "color_picker_color_mediumvioletred": "중간 보라빛 붉은색",
    "color_picker_color_midnightblue": "자정 블루",
    "color_picker_color_mintcream": "민트 크림",
    "color_picker_color_mistyrose": "안개 장미",
    "color_picker_color_moccasin": "모카신",
    "color_picker_color_navajowhite": "나바호 화이트",
    "color_picker_color_oldlace": "오래된 레이스",
    "color_picker_color_olivedrab": "올리브 드랩",
    "color_picker_color_orange": "주황색",
    "color_picker_color_orangered": "오렌지 레드",
    "color_picker_color_orchid": "난초",
    "color_picker_color_palegoldenrod": "창백한 황금빛",
    "color_picker_color_palegreen": "창백한 녹색",
    "color_picker_color_paleturquoise": "창백한 터키석",
    "color_picker_color_palevioletred": "창백한 보라빛 붉은색",
    "color_picker_color_papayawhip": "파파야",
    "color_picker_color_peachpuff": "복숭아",
    "color_picker_color_peru": "페루",
    "color_picker_color_pink": "핑크",
    "color_picker_color_plum": "자두",
    "color_picker_color_powderblue": "파우더 블루",
    "color_picker_color_rebeccapurple": "레베카 보라색",
    "color_picker_color_rosybrown": "장미 빛 갈색",
    "color_picker_color_royalblue": "로열 블루",
    "color_picker_color_saddlebrown": "안장 갈색",
    "color_picker_color_salmon": "연어",
    "color_picker_color_sandybrown": "사막 갈색",
    "color_picker_color_seagreen": "바다색",
    "color_picker_color_seashell": "해파리",
    "color_picker_color_sienna": "시에나",
    "color_picker_color_skyblue": "하늘색",
    "color_picker_color_slateblue": "슬레이트 블루",
    "color_picker_color_slategray": "슬레이트 그레이",
    "color_picker_color_snow": "눈",
    "color_picker_color_springgreen": "봄색",
    "color_picker_color_steelblue": "강철 블루",
    "color_picker_color_tan": "황갈색",
    "color_picker_color_thistle": "엉겅퀴",
    "color_picker_color_tomato": "토마토",
    "color_picker_color_turquoise": "터키석색",
    "color_picker_color_violet": "보라색",
    "color_picker_color_wheat": "밀색",
    "color_picker_color_whitesmoke": "흰 연기",
    "color_picker_color_yellowgreen": "노랑-초록",
}
