# German lexemes common.py
lexemes = {
    "module_llama_cpp_name": "Modul llama.cpp",

    "module_llama_cpp_model_exception": "Modell nicht gefunden Fehler: {error_msg}",
    "module_llama_cpp_task_exception": "Modellgenerator kann nicht initialisiert werden: {error_msg}",
}
