# Finnish lexemes color_picker_dialog.py
lexemes = {
    "color_picker_title": "Valitse väri",

    "color_picker_color_black": "Musta",
    "color_picker_color_silver": "Hopea",
    "color_picker_color_gray": "Harmaa",
    "color_picker_color_white": "Valkoinen",
    "color_picker_color_maroon": "Kastanjanruskea",
    "color_picker_color_red": "Punainen",
    "color_picker_color_purple": "Purppura",
    "color_picker_color_fuchsia": "Fuksia",
    "color_picker_color_green": "Vihreä",
    "color_picker_color_lime": "Limenvihreä",
    "color_picker_color_olive": "Oliivinvihreä",
    "color_picker_color_yellow": "Keltainen",
    "color_picker_color_navy": "Laivastonsininen",
    "color_picker_color_blue": "Sininen",
    "color_picker_color_teal": "Sinivihreä",
    "color_picker_color_aqua": "Turkoosi",
    "color_picker_color_aliceblue": "Alicantensininen",
    "color_picker_color_antiquewhite": "Antiikinvalkoinen",
    "color_picker_color_aquamarine": "Akvamariini",
    "color_picker_color_azure": "Atsolansininen",
    "color_picker_color_beige": "Beesi",
    "color_picker_color_bisque": "Bisque",
    "color_picker_color_blanchedalmond": "Mantelinvaalea",
    "color_picker_color_blueviolet": "Sinivioletti",
    "color_picker_color_brown": "Ruskea",
    "color_picker_color_burlywood": "Ruskeankeltainen",
    "color_picker_color_cadetblue": "Kadetinsininen",
    "color_picker_color_chartreuse": "Chartreuse",
    "color_picker_color_chocolate": "Suklaanruskea",
    "color_picker_color_coral": "Koralli",
    "color_picker_color_cornflowerblue": "Ruiskukansininen",
    "color_picker_color_cornsilk": "Riisinkeltainen",
    "color_picker_color_crimson": "Karmiininpunainen",
    "color_picker_color_cyan": "Syanoosi",
    "color_picker_color_darkblue": "Tummansininen",
    "color_picker_color_darkcyan": "Tumma syaani",
    "color_picker_color_darkgoldenrod": "Tumma kultapiisku",
    "color_picker_color_darkgray": "Tummanharmaa",
    "color_picker_color_darkgreen": "Tummanvihreä",
    "color_picker_color_darkkhaki": "Tumma khaki",
    "color_picker_color_darkmagenta": "Tumma magenta",
    "color_picker_color_darkolivegreen": "Tumma oliivinvihreä",
    "color_picker_color_darkorange": "Tumma oranssi",
    "color_picker_color_darkorchid": "Tumma orkidea",
    "color_picker_color_darkred": "Tummanpunainen",
    "color_picker_color_darksalmon": "Tumma lohenpunainen",
    "color_picker_color_darkseagreen": "Tumma merenvihreä",
    "color_picker_color_darkslateblue": "Tumma liuskekivisininen",
    "color_picker_color_darkslategray": "Tumma liuskekiviharmaa",
    "color_picker_color_darkturquoise": "Tumma turkoosi",
    "color_picker_color_darkviolet": "Tumma violetti",
    "color_picker_color_deeppink": "Syvä pinkki",
    "color_picker_color_deepskyblue": "Syvä taivaansininen",
    "color_picker_color_dimgray": "Himmeä harmaa",
    "color_picker_color_dodgerblue": "Kiertäjänsininen",
    "color_picker_color_firebrick": "Tiilenpunainen",
    "color_picker_color_floralwhite": "Kukkavalkoinen",
    "color_picker_color_forestgreen": "Metsänvihreä",
    "color_picker_color_gainsboro": "Gainsboronharmaa",
    "color_picker_color_ghostwhite": "Haamunvalkoinen",
    "color_picker_color_gold": "Kulta",
    "color_picker_color_goldenrod": "Kultapiisku",
    "color_picker_color_greenyellow": "Vihreänkeltainen",
    "color_picker_color_honeydew": "Hunajameloni",
    "color_picker_color_hotpink": "Kuuma pinkki",
    "color_picker_color_indianred": "Intianpunainen",
    "color_picker_color_indigo": "Indigo",
    "color_picker_color_ivory": "Norsunluu",
    "color_picker_color_khaki": "Khaki",
    "color_picker_color_lavender": "Laventeli",
    "color_picker_color_lavenderblush": "Laventelinhehku",
    "color_picker_color_lawngreen": "Ruohonvihreä",
    "color_picker_color_lemonchiffon": "Sitruunankeltainen",
    "color_picker_color_lightblue": "Vaaleansininen",
    "color_picker_color_lightcoral": "Vaalea koralli",
    "color_picker_color_lightcyan": "Vaalea syaani",
    "color_picker_color_lightgoldenrodyellow": "Vaalea kultapiiskunkeltainen",
    "color_picker_color_lightgray": "Vaaleanharmaa",
    "color_picker_color_lightgreen": "Vaaleanvihreä",
    "color_picker_color_lightpink": "Vaalea pinkki",
    "color_picker_color_lightsalmon": "Vaalea lohenpunainen",
    "color_picker_color_lightseagreen": "Vaalea merenvihreä",
    "color_picker_color_lightskyblue": "Vaalea taivaansininen",
    "color_picker_color_lightslategray": "Vaalea liuskekiviharmaa",
    "color_picker_color_lightsteelblue": "Vaalea teräksensininen",
    "color_picker_color_lightyellow": "Vaaleankeltainen",
    "color_picker_color_limegreen": "Limen vihreä",
    "color_picker_color_linen": "Pellavainen",
    "color_picker_color_magenta": "Magenta",
    "color_picker_color_mediumaquamarine": "Keskiakvamariini",
    "color_picker_color_mediumblue": "Keskisininen",
    "color_picker_color_mediumorchid": "Keskiorkidea",
    "color_picker_color_mediumpurple": "Keskipurppura",
    "color_picker_color_mediumseagreen": "Keskimerenvihreä",
    "color_picker_color_mediumslateblue": "Keskiliuskekivisininen",
    "color_picker_color_mediumspringgreen": "Keskikeväänvihreä",
    "color_picker_color_mediumturquoise": "Keskiturkoosi",
    "color_picker_color_mediumvioletred": "Keskivioletinpunainen",
    "color_picker_color_midnightblue": "Keskiviikonsininen",
    "color_picker_color_mintcream": "Minttukerma",
    "color_picker_color_mistyrose": "Sumunpunainen",
    "color_picker_color_moccasin": "Mokkasiini",
    "color_picker_color_navajowhite": "Navajo-valkoinen",
    "color_picker_color_oldlace": "Vanha pitsi",
    "color_picker_color_olivedrab": "Oliivinharmaa",
    "color_picker_color_orange": "Oranssi",
    "color_picker_color_orangered": "Oranssinpunainen",
    "color_picker_color_orchid": "Orkidea",
    "color_picker_color_palegoldenrod": "Haalea kultapiisku",
    "color_picker_color_palegreen": "Haaleanvihreä",
    "color_picker_color_paleturquoise": "Haalea turkoosi",
    "color_picker_color_palevioletred": "Haalean violetinpunainen",
    "color_picker_color_papayawhip": "Papaijakerma",
    "color_picker_color_peachpuff": "Persikka",
    "color_picker_color_peru": "Perunpunainen",
    "color_picker_color_pink": "Pinkki",
    "color_picker_color_plum": "Luumu",
    "color_picker_color_powderblue": "Puuterinsininen",
    "color_picker_color_rebeccapurple": "Rebekanpurppura",
    "color_picker_color_rosybrown": "Ruusunruskea",
    "color_picker_color_royalblue": "Kuninkaansininen",
    "color_picker_color_saddlebrown": "Satulanruskea",
    "color_picker_color_salmon": "Lohenpunainen",
    "color_picker_color_sandybrown": "Hiekanruskea",
    "color_picker_color_seagreen": "Merenvihreä",
    "color_picker_color_seashell": "Simpukankuori",
    "color_picker_color_sienna": "Siena",
    "color_picker_color_skyblue": "Taivaansininen",
    "color_picker_color_slateblue": "Liuskekivisininen",
    "color_picker_color_slategray": "Liuskekiviharmaa",
    "color_picker_color_snow": "Lumi",
    "color_picker_color_springgreen": "Kevätvihreä",
    "color_picker_color_steelblue": "Teräksensininen",
    "color_picker_color_tan": "Parkkinahka",
    "color_picker_color_thistle": "Ohdake",
    "color_picker_color_tomato": "Tomaatti",
    "color_picker_color_turquoise": "Turkoosi",
    "color_picker_color_violet": "Violetti",
    "color_picker_color_wheat": "Vehnä",
    "color_picker_color_whitesmoke": "Valkoinen savu",
    "color_picker_color_yellowgreen": "Keltavihreä",
}
