# Greek lexemes statusbar.py
lexemes = {
    "statusbar_litter_bin_label": "Κάδος απορριμμάτων",
    "statusbar_litter_bin_accessible_name": "Εμφάνιση περιεχομένου κάδου απορριμμάτων",

    "statusbar_save_progress_label": b'\xf0\x9f\x92\xbe',  # Unicode for save icon
    "statusbar_encryption_symbol_encrypted_label": b'\xf0\x9f\x94\x92',  # Unicode for encrypted icon
    "statusbar_encryption_symbol_unencrypted_label": b'\xf0\x9f\x94\x93',  # Unicode for unencrypted icon

    "statusbar_mode_label_mode_view": "Λειτουργία προβολής",
    "statusbar_mode_label_mode_edit": "Λειτουργία επεξεργασίας",
    "statusbar_mode_label_mode_source": "Λειτουργία πηγής",

    "statusbar_source_label_source_markdown": "Markdown",
    "statusbar_source_label_source_html": "HTML",

    "statusbar_encryption_label": "{encryption} {icon}",
    "statusbar_encryption_label_encryption_plain": "Απλό",
    "statusbar_encryption_label_encryption_encrypted": "Κρυπτογραφημένο",

    "statusbar_cursor_label": "γραμμή: {line} → στήλη: {column}",
    "statusbar_cursor_label_selected": "γραμμή: {line} → στήλη: {column} → επιλ: {selected}",
    "statusbar_cursor_label_with_global": "γραμμή: {line} → στήλη: {column} → θέση: {position}",
    "statusbar_cursor_label_selected_with_global":
        "γραμμή: {line} → στήλη: {column} → θέση: {position} → επιλ: {selected}",
}
