# English lexemes common.py
lexemes = {
    # Common
    "module_ondevice_llm_name": "On Device LLM",

    "module_ondevice_llm_model_exception": "Model not found error: {error_msg}",
    "module_ondevice_llm_task_exception": "Cannot init model generator: {error_msg}",
}
