# Georgian lexemes common.py
lexemes = {
    "module_llama_cpp_name": "მოდული llama.cpp",

    "module_llama_cpp_model_exception": "მოდელი ვერ მოიძებნა შეცდომა: {error_msg}",
    "module_llama_cpp_task_exception": "მოდელის გენერატორის ინიციალიზაცია ვერ ხდება: {error_msg}",
}
