# Italian lexemes main_menu.py
lexemes = {
    "group_file_label": "File",
    "group_edit_label": "Modifica",
    "group_tools_label": "Strumenti",
    "group_help_label": "Aiuto",

    "actions_file_label_new_document": "Nuovo documento",
    "actions_file_accessible_name_new_document": "Nuovo documento",
    "actions_file_label_open": "Apri",
    "actions_file_accessible_name_open": "Apri documento",
    "actions_file_label_save": "Salva",
    "actions_file_accessible_name_save": "Salva documento",
    "actions_file_label_save_as": "Salva come",
    "actions_file_accessible_name_save_as": "Salva come copia del documento",
    "actions_file_label_settings": "Impostazioni",
    "actions_file_accessible_name_settings": "Impostazioni dell'app",
    "actions_file_label_reset_settings": "Reimposta impostazioni",
    "actions_file_accessible_name_reset_settings": "Reimposta impostazioni",
    "actions_file_label_exit": "Esci",
    "actions_file_accessible_name_exit": "Esci dall'applicazione",

    "actions_edit_edit_mode": "Modifica",
    "actions_edit_accessible_name_edit_mode": "Modifica file",
    "actions_edit_source_mode": "Sorgente",
    "actions_edit_accessible_name_source_mode": "Codice sorgente",
    "actions_edit_bold": "Grassetto",
    "actions_edit_accessible_name_bold": "Formato testo grassetto",
    "actions_edit_italic": "Corsivo",
    "actions_edit_accessible_name_italic": "Formato testo corsivo",
    "actions_edit_underline": "Sottolineato",
    "actions_edit_accessible_name_underline": "Formato testo sottolineato",
    "actions_edit_strikethrough": "Barrato",
    "actions_edit_accessible_name_strikethrough": "Formato testo barrato",
    "actions_edit_blockquote": "Citazione",
    "actions_edit_accessible_name_blockquote": "Formato testo citazione",

    "actions_tools_ai_assistant": "Assistente IA",
    "actions_tools_accessible_name_ai_assistant": "Avvia Assistente IA",
    "actions_tools_color_picker": "Selettore Colore",
    "actions_tools_accessible_name_color_picker": "Scegli un colore per il testo",

    "actions_help_label_md_syntax": "Sintassi Markdown",
    "actions_help_accessible_name_md_syntax": "Sintassi Markdown",
    "actions_help_label_check_for_updates": "Controlla aggiornamenti",
    "actions_help_accessible_name_check_for_updates": "Controlla aggiornamenti",
    "actions_help_label_bug_report": "Segnala bug",
    "actions_help_accessible_name_bug_report": "Invia segnalazione di bug",
    "actions_help_label_about": "Informazioni",
    "actions_help_accessible_name_about": "Informazioni",
}
