# English lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "New document",
    "actions_accessible_name_new_document": "New document",
    "actions_label_open": "Open",
    "actions_accessible_name_open": "Open document",
    "actions_label_save": "Save",
    "actions_accessible_name_save": "Save document",
    "actions_label_save_as": "Save as",
    "actions_accessible_name_save_as": "Save as document copy",
    "actions_label_sync": "Sync",
    "actions_accessible_name_sync": "Sync document with an external storage",
    "actions_label_edit": "Edit",
    "actions_accessible_name_edit": "Edit file",
    "actions_label_source": "Source",
    "actions_accessible_name_source": "Source code",
    "actions_label_encrypt": "Encrypt",
    "actions_accessible_name_encrypt": "Encrypt file",
    "actions_label_decrypt": "Decrypt",
    "actions_accessible_name_decrypt": "Decrypt file",
    "actions_label_bold": "Bold",
    "actions_accessible_name_bold": "Bold text format",
    "actions_label_italic": "Italic",
    "actions_accessible_name_italic": "Italic text format",
    "actions_label_underline": "Underline",
    "actions_accessible_name_underline": "Underline text format",
    "actions_label_strikethrough": "Strikethrough",
    "actions_accessible_name_strikethrough": "Strikethrough text format",
    "actions_label_blockquote": "Blockquote",
    "actions_accessible_name_blockquote": "Blockquote text format",
    "actions_label_color_picker": "Color Picker",
    "actions_accessible_name_color_picker": "Choose a text color",
    "actions_label_ai_assistant": "AI Assistant",
    "actions_accessible_name_ai_assistant": "Launch AI Assistant",
    "actions_label_about": "About",
    "actions_accessible_name_about": "About the App",
    "actions_label_exit": "Exit",
    "actions_accessible_name_exit": "Exit the App",
    "actions_label_settings": "Settings",
    "actions_accessible_name_settings": "App settings",

    "search_input_label": "Search",
    "search_input_placeholder_text": "Search text in the document",
    "search_input_accessible_description": "Search input field",
    "search_buttons_label_clear": "Clear search",
    "search_buttons_accessible_name_clear": "Clear search input field",
    "search_buttons_label_prev": "Previous search",
    "search_buttons_accessible_name_prev": "Previous search result",
    "search_buttons_label_next": "Next search",
    "search_buttons_accessible_name_next": "Next search result",
    "search_case_sensitive_accessible_name": "Case sensitive",
    "search_case_sensitive_tooltip": "Case sensitive search",
}
