# Lexica Communia Latine ai_assistant.py
lexemes = {
    # Assistens AI
    "dialog_title": "Postulatio ad AI",
    "dialog_prompt_input_placeholder_text": "Postulatio",
    "dialog_prompt_input_accessible_description": "Postulationem ingredi ad contextum assistenti AI praebendum",
    "dialog_response_output_placeholder_text": "Responsi data",
    "dialog_response_output_accessible_description": "Responsi data in hoc campo apparebunt",
    "dialog_response_output_notice_empty_text": "Praebe textum ad respondendum fere...",

    "dialog_usage_module_label": "MODULUS",
    "dialog_usage_model_label": "EXEMPLAR",
    "dialog_usage_tokens_label": "SIGNA",
    "dialog_usage_tokens_prompt": "promptus: {tokens}",
    "dialog_usage_tokens_answer": "responsio: {tokens}",
    "dialog_usage_tokens_total": "totum: {tokens}",

    "dialog_button_send_request": "Postulationem mittere",
    "dialog_button_stop_request": "Intermitte",
    "dialog_button_save_history": "Conferensiae historia serva",

    "dialog_message_copy_tooltip": "Exemplum textus",
    "dialog_message_copied_tooltip": "Exemplar",

    "dialog_error_loading_model": "Error loading mos proprius",
}
