# Finnish lexemes common.py
lexemes = {
    "module_llama_cpp_name": "Moduuli llama.cpp",

    "module_llama_cpp_model_exception": "Mallia ei löydy virhe: {error_msg}",
    "module_llama_cpp_task_exception": "Malligeneraattoria ei voi alustaa: {error_msg}",
}
