# Hindi lexemes color_picker_dialog.py
lexemes = {
    "color_picker_title": "रंग चुनें",

    "color_picker_color_black": "काला",
    "color_picker_color_silver": "चांदी",
    "color_picker_color_gray": "धूसर",
    "color_picker_color_white": "सफेद",
    "color_picker_color_maroon": "मैरून",
    "color_picker_color_red": "लाल",
    "color_picker_color_purple": "बैंगनी",
    "color_picker_color_fuchsia": "फ्यूशिया",
    "color_picker_color_green": "हरा",
    "color_picker_color_lime": "चूना",
    "color_picker_color_olive": "जैतूनी",
    "color_picker_color_yellow": "पीला",
    "color_picker_color_navy": "नेवी ब्लू",
    "color_picker_color_blue": "नीला",
    "color_picker_color_teal": "टील",
    "color_picker_color_aqua": "ऐक्वा",
    "color_picker_color_aliceblue": "ऐलिस ब्लू",
    "color_picker_color_antiquewhite": "एंटीक सफेद",
    "color_picker_color_aquamarine": "एक्वामरीन",
    "color_picker_color_azure": "आसमानी",
    "color_picker_color_beige": "बेज",
    "color_picker_color_bisque": "बिस्क",
    "color_picker_color_blanchedalmond": "ब्लांच्ड बादाम",
    "color_picker_color_blueviolet": "नीली बैंगनी",
    "color_picker_color_brown": "भूरा",
    "color_picker_color_burlywood": "बर्लीवुड",
    "color_picker_color_cadetblue": "कैडेट ब्लू",
    "color_picker_color_chartreuse": "शार्ट्र्यूज़",
    "color_picker_color_chocolate": "चॉकलेट",
    "color_picker_color_coral": "कोरल",
    "color_picker_color_cornflowerblue": "कॉर्नफ्लावर ब्लू",
    "color_picker_color_cornsilk": "कॉर्नसिल्क",
    "color_picker_color_crimson": "क्रिमसन",
    "color_picker_color_cyan": "सियान",
    "color_picker_color_darkblue": "गहरा नीला",
    "color_picker_color_darkcyan": "गहरा सियान",
    "color_picker_color_darkgoldenrod": "गहरा गोल्डन रॉड",
    "color_picker_color_darkgray": "गहरा धूसर",
    "color_picker_color_darkgreen": "गहरा हरा",
    "color_picker_color_darkkhaki": "गहरा खाकी",
    "color_picker_color_darkmagenta": "गहरा मैजेंटा",
    "color_picker_color_darkolivegreen": "गहरा जैतूनी हरा",
    "color_picker_color_darkorange": "गहरा नारंगी",
    "color_picker_color_darkorchid": "गहरा ऑर्किड",
    "color_picker_color_darkred": "गहरा लाल",
    "color_picker_color_darksalmon": "गहरा साल्मन",
    "color_picker_color_darkseagreen": "गहरा समुद्री हरा",
    "color_picker_color_darkslateblue": "गहरा स्लेट नीला",
    "color_picker_color_darkslategray": "गहरा स्लेट धूसर",
    "color_picker_color_darkturquoise": "गहरा फ़िरोज़ा",
    "color_picker_color_darkviolet": "गहरी बैंगनी",
    "color_picker_color_deeppink": "गहरा गुलाबी",
    "color_picker_color_deepskyblue": "गहरा आसमानी नीला",
    "color_picker_color_dimgray": "मद्धम धूसर",
    "color_picker_color_dodgerblue": "डॉजर ब्लू",
    "color_picker_color_firebrick": "फ़ायर ब्रिक",
    "color_picker_color_floralwhite": "फ़्लोरल सफेद",
    "color_picker_color_forestgreen": "वन हरा",
    "color_picker_color_gainsboro": "गेन्सबोरो",
    "color_picker_color_ghostwhite": "घोस्ट सफेद",
    "color_picker_color_gold": "सोना",
    "color_picker_color_goldenrod": "गोल्डन रॉड",
    "color_picker_color_greenyellow": "हरा पीला",
    "color_picker_color_honeydew": "हनी ड्यू",
    "color_picker_color_hotpink": "हॉट पिंक",
    "color_picker_color_indianred": "इंडियन लाल",
    "color_picker_color_indigo": "इंडिगो",
    "color_picker_color_ivory": "हाथीदांत",
    "color_picker_color_khaki": "खाकी",
    "color_picker_color_lavender": "लैवेंडर",
    "color_picker_color_lavenderblush": "लैवेंडर ब्लश",
    "color_picker_color_lawngreen": "लॉन हरा",
    "color_picker_color_lemonchiffon": "लेमन शिफॉन",
    "color_picker_color_lightblue": "हल्का नीला",
    "color_picker_color_lightcoral": "हल्का कोरल",
    "color_picker_color_lightcyan": "हल्का सियान",
    "color_picker_color_lightgoldenrodyellow": "हल्का गोल्डन रॉड पीला",
    "color_picker_color_lightgray": "हल्का धूसर",
    "color_picker_color_lightgreen": "हल्का हरा",
    "color_picker_color_lightpink": "हल्का गुलाबी",
    "color_picker_color_lightsalmon": "हल्का साल्मन",
    "color_picker_color_lightseagreen": "हल्का समुद्री हरा",
    "color_picker_color_lightskyblue": "हल्का आसमानी नीला",
    "color_picker_color_lightslategray": "हल्का स्लेट धूसर",
    "color_picker_color_lightsteelblue": "हल्का स्टील नीला",
    "color_picker_color_lightyellow": "हल्का पीला",
    "color_picker_color_limegreen": "लाइम हरा",
    "color_picker_color_linen": "लिनेन",
    "color_picker_color_magenta": "मैजेंटा",
    "color_picker_color_mediumaquamarine": "मध्यम एक्वामरीन",
    "color_picker_color_mediumblue": "मध्यम नीला",
    "color_picker_color_mediumorchid": "मध्यम ऑर्किड",
    "color_picker_color_mediumpurple": "मध्यम बैंगनी",
    "color_picker_color_mediumseagreen": "मध्यम समुद्री हरा",
    "color_picker_color_mediumslateblue": "मध्यम स्लेट नीला",
    "color_picker_color_mediumspringgreen": "मध्यम स्प्रिंग हरा",
    "color_picker_color_mediumturquoise": "मध्यम फ़िरोज़ा",
    "color_picker_color_mediumvioletred": "मध्यम वायलेट लाल",
    "color_picker_color_midnightblue": "मिडनाइट नीला",
    "color_picker_color_mintcream": "मिंट क्रीम",
    "color_picker_color_mistyrose": "मिस्टी रोज़",
    "color_picker_color_moccasin": "मोकासिन",
    "color_picker_color_navajowhite": "नवाजो सफेद",
    "color_picker_color_oldlace": "ओल्ड लेस",
    "color_picker_color_olivedrab": "ऑलिव ड्रैब",
    "color_picker_color_orange": "नारंगी",
    "color_picker_color_orangered": "ऑरेंज रेड",
    "color_picker_color_orchid": "ऑर्किड",
    "color_picker_color_palegoldenrod": "फीका गोल्डन रॉड",
    "color_picker_color_palegreen": "फीका हरा",
    "color_picker_color_paleturquoise": "फीका फ़िरोज़ा",
    "color_picker_color_palevioletred": "फीका वायलेट लाल",
    "color_picker_color_papayawhip": "पपाया व्हिप",
    "color_picker_color_peachpuff": "पीच पफ",
    "color_picker_color_peru": "पेरू",
    "color_picker_color_pink": "गुलाबी",
    "color_picker_color_plum": "प्लम",
    "color_picker_color_powderblue": "पाउडर नीला",
    "color_picker_color_rebeccapurple": "रिबेका पर्पल",
    "color_picker_color_rosybrown": "रोज़ी भूरा",
    "color_picker_color_royalblue": "रॉयल नीला",
    "color_picker_color_saddlebrown": "सैडल भूरा",
    "color_picker_color_salmon": "साल्मन",
    "color_picker_color_sandybrown": "सैंडी भूरा",
    "color_picker_color_seagreen": "समुद्री हरा",
    "color_picker_color_seashell": "सी शेल",
    "color_picker_color_sienna": "सिएना",
    "color_picker_color_skyblue": "आसमानी नीला",
    "color_picker_color_slateblue": "स्लेट नीला",
    "color_picker_color_slategray": "स्लेट धूसर",
    "color_picker_color_snow": "स्नो",
    "color_picker_color_springgreen": "स्प्रिंग हरा",
    "color_picker_color_steelblue": "स्टील नीला",
    "color_picker_color_tan": "टैन",
    "color_picker_color_thistle": "थिसल",
    "color_picker_color_tomato": "टमाटर",
    "color_picker_color_turquoise": "फ़िरोज़ा",
    "color_picker_color_violet": "बैंगनी",
    "color_picker_color_wheat": "गेहूँ",
    "color_picker_color_whitesmoke": "सफेद धुआँ",
    "color_picker_color_yellowgreen": "पीला हरा"
}
