# Georgian lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "ახალი დოკუმენტი",
    "actions_accessible_name_new_document": "ახალი დოკუმენტი",
    "actions_label_open": "გახსნა",
    "actions_accessible_name_open": "დოკუმენტის გახსნა",
    "actions_label_save": "შენახვა",
    "actions_accessible_name_save": "დოკუმენტის შენახვა",
    "actions_label_save_as": "შენახვა როგორც",
    "actions_accessible_name_save_as": "დოკუმენტის ასლის შენახვა",
    "actions_label_sync": "სინქრონიზაცია",
    "actions_accessible_name_sync": "დოკუმენტის სინქრონიზაცია გარე მეხსიერებით",
    "actions_label_edit": "რედაქტირება",
    "actions_accessible_name_edit": "ფაილის რედაქტირება",
    "actions_label_source": "წყარო",
    "actions_accessible_name_source": "კოდის წყარო",
    "actions_label_encrypt": "დაშიფვრა",
    "actions_accessible_name_encrypt": "ფაილის დაშიფვრა",
    "actions_label_decrypt": "გაშიფვრა",
    "actions_accessible_name_decrypt": "ფაილის გაშიფვრა",
    "actions_label_bold": "მუქი",
    "actions_accessible_name_bold": "ტექსტის მუქი ფორმატი",
    "actions_label_italic": "კურსივი",
    "actions_accessible_name_italic": "ტექსტის კურსივის ფორმატი",
    "actions_label_underline": "ხაზგასმა",
    "actions_accessible_name_underline": "ტექსტის ხაზგასმის ფორმატი",
    "actions_label_strikethrough": "გადახაზვა",
    "actions_accessible_name_strikethrough": "ტექსტის გადახაზული ფორმატი",
    "actions_label_blockquote": "ბლოკციტატა",
    "actions_accessible_name_blockquote": "ბლოკციტატის ტექსტის ფორმატი",
    "actions_label_color_picker": "ფერის შერჩევა",
    "actions_accessible_name_color_picker": "ტექსტის ფერის არჩევა",
    "actions_label_ai_assistant": "AI ასისტენტი",
    "actions_accessible_name_ai_assistant": "AI ასისტენტის გაშვება",
    "actions_label_about": "შესახებ",
    "actions_accessible_name_about": "აპლიკაციის შესახებ",
    "actions_label_exit": "გასვლა",
    "actions_accessible_name_exit": "აპლიკაციის დატოვება",
    "actions_label_settings": "პარამეტრები",
    "actions_accessible_name_settings": "აპლიკაციის პარამეტრები",

    "search_input_label": "ძიება",
    "search_input_placeholder_text": "ტექსტის ძიება დოკუმენტში",
    "search_input_accessible_description": "ძიების ველი",
    "search_buttons_label_clear": "ძიების გასუფთავება",
    "search_buttons_accessible_name_clear": "ძიების ველის გასუფთავება",
    "search_buttons_label_prev": "წინა ძიება",
    "search_buttons_accessible_name_prev": "წინა ძიების შედეგი",
    "search_buttons_label_next": "შემდეგი ძიება",
    "search_buttons_accessible_name_next": "შემდეგი ძიების შედეგი",
    "search_case_sensitive_accessible_name": "რეგისტრის მნიშვნელობა",
    "search_case_sensitive_tooltip": "რეგისტრის მნიშვნელობით ძიება",
}
