# Spanish lexemes ai_assistant.py
lexemes = {
    # Asistente IA
    "dialog_title": "Solicitud a IA",
    "dialog_prompt_input_placeholder_text": "Solicitud",
    "dialog_prompt_input_accessible_description": "Ingrese la solicitud para dar un contexto al asistente IA",
    "dialog_response_output_placeholder_text": "Datos de respuesta",
    "dialog_response_output_accessible_description": "Los datos de respuesta aparecerán en este campo",
    "dialog_response_output_notice_empty_text":
        "Proporcione una entrada de texto para obtener una respuesta de aproximadamente...",

    "dialog_usage_module_label": "MÓDULO",
    "dialog_usage_model_label": "MODELO",
    "dialog_usage_tokens_label": "TOKENS",
    "dialog_usage_tokens_prompt": "prompt: {tokens}",
    "dialog_usage_tokens_answer": "respuesta: {tokens}",
    "dialog_usage_tokens_total": "total: {tokens}",

    "dialog_button_send_request": "Enviar solicitud",
    "dialog_button_stop_request": "Detener",
    "dialog_button_save_history": "Guardar historial del diálogo",

    "dialog_message_copy_tooltip": "Copiar texto",
    "dialog_message_copied_tooltip": "Copiado",

    "dialog_error_loading_model": "Error al cargar el modelo personalizado",
}
