# Russian lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "Новый документ",
    "actions_accessible_name_new_document": "Новый документ",
    "actions_label_open": "Открыть",
    "actions_accessible_name_open": "Открыть документ",
    "actions_label_save": "Сохранить",
    "actions_accessible_name_save": "Сохранить документ",
    "actions_label_save_as": "Сохранить как",
    "actions_accessible_name_save_as": "Сохранить копию документа",
    "actions_label_sync": "Синхронизировать",
    "actions_accessible_name_sync": "Синхронизировать документ с внешним хранилищем",
    "actions_label_edit": "Редактировать",
    "actions_accessible_name_edit": "Редактировать файл",
    "actions_label_source": "Источник",
    "actions_accessible_name_source": "Исходный код",
    "actions_label_encrypt": "Зашифровать",
    "actions_accessible_name_encrypt": "Зашифровать файл",
    "actions_label_decrypt": "Расшифровать",
    "actions_accessible_name_decrypt": "Расшифровать файл",
    "actions_label_bold": "Жирный",
    "actions_accessible_name_bold": "Жирный формат текста",
    "actions_label_italic": "Курсив",
    "actions_accessible_name_italic": "Курсивный формат текста",
    "actions_label_underline": "Подчеркнутый",
    "actions_accessible_name_underline": "Подчеркнутый формат текста",
    "actions_label_strikethrough": "Зачеркнутый",
    "actions_accessible_name_strikethrough": "Зачеркнутый формат текста",
    "actions_label_blockquote": "Цитата",
    "actions_accessible_name_blockquote": "Формат текста в виде цитаты",
    "actions_label_color_picker": "Выбор цвета",
    "actions_accessible_name_color_picker": "Выберите цвет текста",
    "actions_label_ai_assistant": "ИИ помощник",
    "actions_accessible_name_ai_assistant": "Запустить ИИ помощника",
    "actions_label_about": "О программе",
    "actions_accessible_name_about": "О приложении",
    "actions_label_exit": "Выход",
    "actions_accessible_name_exit": "Выйти из приложения",
    "actions_label_settings": "Настройки",
    "actions_accessible_name_settings": "Настройки приложения",

    "search_input_label": "Поиск",
    "search_input_placeholder_text": "Поиск текста в документе",
    "search_input_accessible_description": "Поле ввода поиска",
    "search_buttons_label_clear": "Очистить поиск",
    "search_buttons_accessible_name_clear": "Очистить поле поиска",
    "search_buttons_label_prev": "Предыдущий поиск",
    "search_buttons_accessible_name_prev": "Предыдущий результат поиска",
    "search_buttons_label_next": "Следующий поиск",
    "search_buttons_accessible_name_next": "Следующий результат поиска",
    "search_case_sensitive_accessible_name": "Учитывать регистр",
    "search_case_sensitive_tooltip": "Поиск с учетом регистра",
}
