# Swedish lexemes main_menu.py
lexemes = {
    "group_file_label": "Fil",
    "group_edit_label": "Redigera",
    "group_tools_label": "Verktyg",
    "group_help_label": "Hjälp",

    "actions_file_label_new_document": "Nytt dokument",
    "actions_file_accessible_name_new_document": "Nytt dokument",
    "actions_file_label_open": "Öppna",
    "actions_file_accessible_name_open": "Öppna dokument",
    "actions_file_label_save": "Spara",
    "actions_file_accessible_name_save": "Spara dokument",
    "actions_file_label_save_as": "Spara som",
    "actions_file_accessible_name_save_as": "Spara dokumentkopior",
    "actions_file_label_settings": "Inställningar",
    "actions_file_accessible_name_settings": "Appinställningar",
    "actions_file_label_reset_settings": "Återställ inställningar",
    "actions_file_accessible_name_reset_settings": "Återställ inställningar",
    "actions_file_label_exit": "Avsluta",
    "actions_file_accessible_name_exit": "Avsluta programmet",

    "actions_edit_edit_mode": "Redigera",
    "actions_edit_accessible_name_edit_mode": "Redigera fil",
    "actions_edit_source_mode": "Källkod",
    "actions_edit_accessible_name_source_mode": "Källkod",
    "actions_edit_bold": "Fet",
    "actions_edit_accessible_name_bold": "Fet textformat",
    "actions_edit_italic": "Kursiv",
    "actions_edit_accessible_name_italic": "Kursiv textformat",
    "actions_edit_underline": "Understrykning",
    "actions_edit_accessible_name_underline": "Understruken textformat",
    "actions_edit_strikethrough": "Genomstrykning",
    "actions_edit_accessible_name_strikethrough": "Genomstruken textformat",
    "actions_edit_blockquote": "Blockcitat",
    "actions_edit_accessible_name_blockquote": "Blockcitat textformat",

    "actions_tools_ai_assistant": "AI-assistent",
    "actions_tools_accessible_name_ai_assistant": "Starta AI-assistent",
    "actions_tools_color_picker": "Färgväljare",
    "actions_tools_accessible_name_color_picker": "Välj textfärg",

    "actions_help_label_md_syntax": "Markdown-syntax",
    "actions_help_accessible_name_md_syntax": "Markdown-syntax",
    "actions_help_label_check_for_updates": "Sök efter uppdateringar",
    "actions_help_accessible_name_check_for_updates": "Sök efter uppdateringar",
    "actions_help_label_bug_report": "Felrapport",
    "actions_help_accessible_name_bug_report": "Skicka felrapport",
    "actions_help_label_about": "Om",
    "actions_help_accessible_name_about": "Om"
}
