# Russian lexemes common.py
lexemes = {
    "module_llama_cpp_name": "Модуль llama.cpp",

    "module_llama_cpp_model_exception": "Ошибка: модель не найдена: {error_msg}",
    "module_llama_cpp_task_exception": "Невозможно инициировать генератор модели: {error_msg}",
}
