/* Tabs */
QTabBar::tab {
    color: lightgray;
}
/* Active tab */
QTabBar::tab:selected {
    color: red;
}
/* Scroll area */
QScrollArea {
    border: none;
    background: transparent;
}
QScrollArea > QWidget > QWidget {
    background: transparent;
}
QComboBox {}
QComboBox::separator {
    height: 1px;
    background: #555555;
}
/*QComboBox::down-arrow { top: 1px; }*/
QLabel {
    color: #eeeeee;
}
QLineEdit {
    color: #eeeeee;
}
/* Group titles */
QLabel.group-header-label {
    color: #cccccc;
}
QCheckBox {
    color: #eeeeee;
}
/* Custom slider (no ticks color supported) */
QSlider::groove:horizontal {
    color: #eeeeee;
    border: 1px solid #999999;
    height: 7px;
    background: qlineargradient(x1:0, y1:0, x2:0, y2:1, stop:0 #bbbbbb, stop:1 #cccccc);
    margin: 2px 0;
}
QSlider::handle:horizontal {
    background: qlineargradient(x1:0, y1:0, x2:1, y2:1, stop:0 #bbbbbb, stop:1 #999999);
    border: 1px solid #5f5f5f;
    width: 17px;
    margin: -2px 0; /* handle is placed by default on the contents rect of the groove. Expand outside the groove */
    border-radius: 3px;
}
/* Request submit button */
QPushButton#settings_dialog_button_close {
    color: white;
    background-color: red;
}
/* Styling for hint tooltips */
QToolTip {
    color: #fefefe;
    background-color: #777777;
    padding: 5px;
}
