# Spanish lexemes common.py
lexemes = {
    # Common
    "module_ondevice_llm_name": "LLM en dispositivo",

    "module_ondevice_llm_model_exception": "Error de modelo no encontrado: {error_msg}",
    "module_ondevice_llm_task_exception": "No se puede iniciar el generador de modelos: {error_msg}",
}
