# Swedish lexemes common.py
lexemes = {
    "module_llama_cpp_name": "Modul llama.cpp",

    "module_llama_cpp_model_exception": "Modell hittades inte fel: {error_msg}",
    "module_llama_cpp_task_exception": "Kan inte initiera modellgenerator: {error_msg}",
}
