/* Tabs */
QTabBar::tab {
    color: black;
}
/* Active tab */
QTabBar::tab:selected {
    color: red;
}
/* Scroll area */
QScrollArea {
    border: none;
    background: transparent;
}
QScrollArea > QWidget > QWidget {
    background: transparent;
}
QComboBox {}
QLabel {
    color: black;
}
QLineEdit {}
/* Group titles */
QLabel.group-header-label {
    color: gray;
}
QCheckBox {
    color: black;
}
/* Custom slider (no ticks color supported) */
QSlider::groove:horizontal {}
QSlider::handle:horizontal {}
/* Request submit button */
QPushButton#settings_dialog_button_close {
    color: white;
    background-color: black;
}
/* Styling for hint tooltips */
QToolTip {
    color: white;
    background-color: red;
    padding: 5px;
}
