# Latin lexemes color_picker_dialog.py
lexemes = {
    "color_picker_title": "Elige colorem",

    "color_picker_color_black": "Niger",
    "color_picker_color_silver": "Argenteus",
    "color_picker_color_gray": "Canus",
    "color_picker_color_white": "Albus",
    "color_picker_color_maroon": "Castaneus",
    "color_picker_color_red": "Ruber",
    "color_picker_color_purple": "Purpureus",
    "color_picker_color_fuchsia": "Fuchsia",
    "color_picker_color_green": "Viridis",
    "color_picker_color_lime": "Lima",
    "color_picker_color_olive": "Olivarius",
    "color_picker_color_yellow": "Flavus",
    "color_picker_color_navy": "Classiarius",
    "color_picker_color_blue": "Caeruleus",
    "color_picker_color_teal": "Caelum",
    "color_picker_color_aqua": "Aqua",
    "color_picker_color_aliceblue": "Caeruleus Alicia",
    "color_picker_color_antiquewhite": "Albus Antiquus",
    "color_picker_color_aquamarine": "Aquamarinus",
    "color_picker_color_azure": "Azurus",
    "color_picker_color_beige": "Beige",
    "color_picker_color_bisque": "Bisque",
    "color_picker_color_blanchedalmond": "Amygdalae Candidae",
    "color_picker_color_blueviolet": "Viola Caerulea",
    "color_picker_color_brown": "Brunneus",
    "color_picker_color_burlywood": "Lignum Robustum",
    "color_picker_color_cadetblue": "Caeruleus Cadet",
    "color_picker_color_chartreuse": "Chartreuse",
    "color_picker_color_chocolate": "Chocolatum",
    "color_picker_color_coral": "Coralium",
    "color_picker_color_cornflowerblue": "Caeruleus Centaurea",
    "color_picker_color_cornsilk": "Sericum Zeae",
    "color_picker_color_crimson": "Crimson",
    "color_picker_color_cyan": "Cyanus",
    "color_picker_color_darkblue": "Caeruleus Obscurus",
    "color_picker_color_darkcyan": "Cyanus Obscurus",
    "color_picker_color_darkgoldenrod": "Virga Aurea Obscura",
    "color_picker_color_darkgray": "Canus Obscurus",
    "color_picker_color_darkgreen": "Viridis Obscurus",
    "color_picker_color_darkkhaki": "Khaki Obscurus",
    "color_picker_color_darkmagenta": "Magenta Obscura",
    "color_picker_color_darkolivegreen": "Viridis Olivarius Obscurus",
    "color_picker_color_darkorange": "Aurantius Obscurus",
    "color_picker_color_darkorchid": "Orchis Obscura",
    "color_picker_color_darkred": "Ruber Obscurus",
    "color_picker_color_darksalmon": "Salmo Obscurus",
    "color_picker_color_darkseagreen": "Viridis Maris Obscurus",
    "color_picker_color_darkslateblue": "Caeruleus Ardesia Obscurus",
    "color_picker_color_darkslategray": "Canus Ardesia Obscurus",
    "color_picker_color_darkturquoise": "Turquoise Obscura",
    "color_picker_color_darkviolet": "Viola Obscura",
    "color_picker_color_deeppink": "Profundus Roseus",
    "color_picker_color_deepskyblue": "Profundus Caeruleus Caeli",
    "color_picker_color_dimgray": "Canus Obscuratus",
    "color_picker_color_dodgerblue": "Caeruleus Dodger",
    "color_picker_color_firebrick": "Later Tegularis",
    "color_picker_color_floralwhite": "Albus Floral",
    "color_picker_color_forestgreen": "Viridis Saltus",
    "color_picker_color_gainsboro": "Gainsboro",
    "color_picker_color_ghostwhite": "Albus Spectrus",
    "color_picker_color_gold": "Aureus",
    "color_picker_color_goldenrod": "Virga Aurea",
    "color_picker_color_greenyellow": "Viridis Flavus",
    "color_picker_color_honeydew": "Mel Roris",
    "color_picker_color_hotpink": "Roseus Calidus",
    "color_picker_color_indianred": "Ruber Indicus",
    "color_picker_color_indigo": "Indicum",
    "color_picker_color_ivory": "Eburneus",
    "color_picker_color_khaki": "Khaki",
    "color_picker_color_lavender": "Lavandula",
    "color_picker_color_lavenderblush": "Lavandula Pudor",
    "color_picker_color_lawngreen": "Viridis Pratum",
    "color_picker_color_lemonchiffon": "Crepis Citri",
    "color_picker_color_lightblue": "Levis Caeruleus",
    "color_picker_color_lightcoral": "Levis Coralium",
    "color_picker_color_lightcyan": "Levis Cyanus",
    "color_picker_color_lightgoldenrodyellow": "Levis Virga Aurea Flava",
    "color_picker_color_lightgray": "Levis Canus",
    "color_picker_color_lightgreen": "Levis Viridis",
    "color_picker_color_lightpink": "Levis Roseus",
    "color_picker_color_lightsalmon": "Levis Salmo",
    "color_picker_color_lightseagreen": "Levis Viridis Maris",
    "color_picker_color_lightskyblue": "Levis Caeruleus Caeli",
    "color_picker_color_lightslategray": "Levis Canus Ardesia",
    "color_picker_color_lightsteelblue": "Levis Caeruleus Chalybs",
    "color_picker_color_lightyellow": "Levis Flavus",
    "color_picker_color_limegreen": "Viridis Citri",
    "color_picker_color_linen": "Linum",
    "color_picker_color_magenta": "Magenta",
    "color_picker_color_mediumaquamarine": "Medium Aquamarina",
    "color_picker_color_mediumblue": "Medium Caeruleus",
    "color_picker_color_mediumorchid": "Medium Orchis",
    "color_picker_color_mediumpurple": "Medium Purpureus",
    "color_picker_color_mediumseagreen": "Medium Viridis Maris",
    "color_picker_color_mediumslateblue": "Medium Caeruleus Ardesia",
    "color_picker_color_mediumspringgreen": "Medium Viridis Ver",
    "color_picker_color_mediumturquoise": "Medium Turquoise",
    "color_picker_color_mediumvioletred": "Medium Viola Ruber",
    "color_picker_color_midnightblue": "Caeruleus Medianoctium",
    "color_picker_color_mintcream": "Crema Menthae",
    "color_picker_color_mistyrose": "Roseus Nebula",
    "color_picker_color_moccasin": "Moccasin",
    "color_picker_color_navajowhite": "Albus Navaho",
    "color_picker_color_oldlace": "Vetus Subucula",
    "color_picker_color_olivedrab": "Olivarius Tristis",
    "color_picker_color_orange": "Aurantiacus",
    "color_picker_color_orangered": "Ruber Aurantiacus",
    "color_picker_color_orchid": "Orchis",
    "color_picker_color_palegoldenrod": "Pallidus Virga Aurea",
    "color_picker_color_palegreen": "Pallidus Viridis",
    "color_picker_color_paleturquoise": "Pallidus Turquoise",
    "color_picker_color_palevioletred": "Pallidus Viola Ruber",
    "color_picker_color_papayawhip": "Papaya Flagellum",
    "color_picker_color_peachpuff": "Peach Puff",
    "color_picker_color_peru": "Peruvia",
    "color_picker_color_pink": "Roseus",
    "color_picker_color_plum": "Prunum",
    "color_picker_color_powderblue": "Pulvis Caeruleus",
    "color_picker_color_rebeccapurple": "Purpureus Rebecca",
    "color_picker_color_rosybrown": "Brunneus Rosaceus",
    "color_picker_color_royalblue": "Regalis Caeruleus",
    "color_picker_color_saddlebrown": "Sella Brunneus",
    "color_picker_color_salmon": "Salmo",
    "color_picker_color_sandybrown": "Arenosus Brunneus",
    "color_picker_color_seagreen": "Viridis Maris",
    "color_picker_color_seashell": "Concha Maris",
    "color_picker_color_sienna": "Terra Sienna",
    "color_picker_color_skyblue": "Caeruleus Caelum",
    "color_picker_color_slateblue": "Caeruleus Ardesia",
    "color_picker_color_slategray": "Canus Ardesia",
    "color_picker_color_snow": "Nix",
    "color_picker_color_springgreen": "Viridis Ver",
    "color_picker_color_steelblue": "Chalybs Caeruleus",
    "color_picker_color_tan": "Subrufus",
    "color_picker_color_thistle": "Carduus",
    "color_picker_color_tomato": "Lycopersicum",
    "color_picker_color_turquoise": "Turquoise",
    "color_picker_color_violet": "Viola",
    "color_picker_color_wheat": "Triticum",
    "color_picker_color_whitesmoke": "Fumus Albus",
    "color_picker_color_yellowgreen": "Viridis Flavus",
}
