# Hindi lexemes toolbar.py
lexemes = {
    "actions_label_new_document": "नया दस्तावेज़",
    "actions_accessible_name_new_document": "नया दस्तावेज़",
    "actions_label_open": "खोलें",
    "actions_accessible_name_open": "दस्तावेज़ खोलें",
    "actions_label_save": "सहेजें",
    "actions_accessible_name_save": "दस्तावेज़ सहेजें",
    "actions_label_save_as": "इस रूप में सहेजें",
    "actions_accessible_name_save_as": "दस्तावेज़ की प्रतिलिपि सहेजें",
    "actions_label_sync": "सिंक",
    "actions_accessible_name_sync": "बाह्य संग्रह के साथ दस्तावेज़ सिंक",
    "actions_label_edit": "संपादित करें",
    "actions_accessible_name_edit": "फ़ाइल संपादित करें",
    "actions_label_source": "स्रोत",
    "actions_accessible_name_source": "स्रोत कोड",
    "actions_label_encrypt": "एन्क्रिप्ट",
    "actions_accessible_name_encrypt": "फ़ाइल को एन्क्रिप्ट करें",
    "actions_label_decrypt": "डिक्रिप्ट",
    "actions_accessible_name_decrypt": "फ़ाइल को डिक्रिप्ट करें",
    "actions_label_bold": "मोटा",
    "actions_accessible_name_bold": "मोटा पाठ प्रारूप",
    "actions_label_italic": "तिरछा",
    "actions_accessible_name_italic": "तिरछा पाठ प्रारूप",
    "actions_label_underline": "रेखांकित",
    "actions_accessible_name_underline": "रेखांकित पाठ प्रारूप",
    "actions_label_strikethrough": "स्ट्राइकथ्रू",
    "actions_accessible_name_strikethrough": "स्ट्राइकथ्रू पाठ प्रारूप",
    "actions_label_blockquote": "ब्लॉक कोट",
    "actions_accessible_name_blockquote": "ब्लॉक कोट पाठ प्रारूप",
    "actions_label_color_picker": "रंग चयनकर्ता",
    "actions_accessible_name_color_picker": "पाठ रंग चुनें",
    "actions_label_ai_assistant": "ए.आई. सहायक",
    "actions_accessible_name_ai_assistant": "ए.आई. सहायक लॉन्च करें",
    "actions_label_about": "ऐप के बारे में",
    "actions_accessible_name_about": "ऐप के बारे में",
    "actions_label_exit": "बाहर निकलें",
    "actions_accessible_name_exit": "ऐप से बाहर निकलें",
    "actions_label_settings": "सेटिंग्स",
    "actions_accessible_name_settings": "ऐप सेटिंग्स",

    "search_input_label": "खोज",
    "search_input_placeholder_text": "दस्तावेज़ में टेक्स्ट खोजें",
    "search_input_accessible_description": "खोज इनपुट फ़ील्ड",
    "search_buttons_label_clear": "खोज साफ़ करें",
    "search_buttons_accessible_name_clear": "खोज इनपुट फ़ील्ड को साफ़ करें",
    "search_buttons_label_prev": "पिछला खोज",
    "search_buttons_accessible_name_prev": "पिछला खोज परिणाम",
    "search_buttons_label_next": "अगली खोज",
    "search_buttons_accessible_name_next": "अगली खोज परिणाम",
    "search_case_sensitive_accessible_name": "मामूली जांच",
    "search_case_sensitive_tooltip": "मामूली जांच खोज"
}
