# English lexemes main_menu.py
lexemes = {
    "group_file_label": "File",
    "group_edit_label": "Edit",
    "group_tools_label": "Tools",
    "group_help_label": "Help",

    "actions_file_label_new_document": "New document",
    "actions_file_accessible_name_new_document": "New document",
    "actions_file_label_open": "Open",
    "actions_file_accessible_name_open": "Open document",
    "actions_file_label_save": "Save",
    "actions_file_accessible_name_save": "Save document",
    "actions_file_label_save_as": "Save as",
    "actions_file_accessible_name_save_as": "Save as document copy",
    "actions_file_label_settings": "Settings",
    "actions_file_accessible_name_settings": "App settings",
    "actions_file_label_reset_settings": "Reset settings",
    "actions_file_accessible_name_reset_settings": "Reset settings",
    "actions_file_label_exit": "Exit",
    "actions_file_accessible_name_exit": "Exit the app",

    "actions_edit_edit_mode": "Edit",
    "actions_edit_accessible_name_edit_mode": "Edit File",
    "actions_edit_source_mode": "Source",
    "actions_edit_accessible_name_source_mode": "Source Code",
    "actions_edit_bold": "Bold",
    "actions_edit_accessible_name_bold": "Bold Text Format",
    "actions_edit_italic": "Italic",
    "actions_edit_accessible_name_italic": "Italic Text Format",
    "actions_edit_underline": "Underline",
    "actions_edit_accessible_name_underline": "Underline Text Format",
    "actions_edit_strikethrough": "Strikethrough",
    "actions_edit_accessible_name_strikethrough": "Strikethrough Text Format",
    "actions_edit_blockquote": "Blockquote",
    "actions_edit_accessible_name_blockquote": "Blockquote Text Format",

    "actions_tools_ai_assistant": "AI Assistant",
    "actions_tools_accessible_name_ai_assistant": "Launch AI Assistant",
    "actions_tools_color_picker": "Color Picker",
    "actions_tools_accessible_name_color_picker": "Choose a Text Color",

    "actions_help_label_md_syntax": "Markdown Syntax",
    "actions_help_accessible_name_md_syntax": "Markdown Syntax",
    "actions_help_label_check_for_updates": "Check for Updates",
    "actions_help_accessible_name_check_for_updates": "Check for Updates",
    "actions_help_label_bug_report":  "Bug Report",
    "actions_help_accessible_name_bug_report": "Submit Bug Report",
    "actions_help_label_about": "About",
    "actions_help_accessible_name_about": "About",
}
