# Swedish lexemes statusbar.py
lexemes = {
    "statusbar_litter_bin_label": "Papperskorg",
    "statusbar_litter_bin_accessible_name": "Visa papperskorgens innehåll",

    "statusbar_save_progress_label": b'\xf0\x9f\x92\xbe',
    "statusbar_encryption_symbol_encrypted_label": b'\xf0\x9f\x94\x92',
    "statusbar_encryption_symbol_unencrypted_label": b'\xf0\x9f\x94\x93',

    "statusbar_mode_label_mode_view": "Visningsläge",
    "statusbar_mode_label_mode_edit": "Redigeringsläge",
    "statusbar_mode_label_mode_source": "Källkodsläge",

    "statusbar_source_label_source_markdown": "Markdown",
    "statusbar_source_label_source_html": "HTML",

    "statusbar_encryption_label": "{encryption} {icon}",
    "statusbar_encryption_label_encryption_plain": "Oskyddad",
    "statusbar_encryption_label_encryption_encrypted": "Krypterad",

    "statusbar_cursor_label": "rad: {line} → kol: {column}",
    "statusbar_cursor_label_selected": "rad: {line} → kol: {column} → val: {selected}",
    "statusbar_cursor_label_with_global": "rad: {line} → kol: {column} → pos: {position}",
    "statusbar_cursor_label_selected_with_global": "rad: {line} → kol: {column} → pos: {position} → val: {selected}"
}
