# German lexemes color_picker_dialog.py
lexemes = {
    "color_picker_title": "Farbe auswählen",

    "color_picker_color_black": "Schwarz",
    "color_picker_color_silver": "Silber",
    "color_picker_color_gray": "Grau",
    "color_picker_color_white": "Weiß",
    "color_picker_color_maroon": "Kastanienbraun",
    "color_picker_color_red": "Rot",
    "color_picker_color_purple": "Lila",
    "color_picker_color_fuchsia": "Fuchsia",
    "color_picker_color_green": "Grün",
    "color_picker_color_lime": "Limettengrün",
    "color_picker_color_olive": "Oliv",
    "color_picker_color_yellow": "Gelb",
    "color_picker_color_navy": "Marineblau",
    "color_picker_color_blue": "Blau",
    "color_picker_color_teal": "Blaugrün",
    "color_picker_color_aqua": "Aqua",
    "color_picker_color_aliceblue": "Aliceblau",
    "color_picker_color_antiquewhite": "Antikweiß",
    "color_picker_color_aquamarine": "Aquamarin",
    "color_picker_color_azure": "Azur",
    "color_picker_color_beige": "Beige",
    "color_picker_color_bisque": "Biskuit",
    "color_picker_color_blanchedalmond": "Mandelweiß",
    "color_picker_color_blueviolet": "Blaulila",
    "color_picker_color_brown": "Braun",
    "color_picker_color_burlywood": "Burlywood",
    "color_picker_color_cadetblue": "Kadettenblau",
    "color_picker_color_chartreuse": "Chartreuse",
    "color_picker_color_chocolate": "Schokolade",
    "color_picker_color_coral": "Koralle",
    "color_picker_color_cornflowerblue": "Kornblumenblau",
    "color_picker_color_cornsilk": "Kornseide",
    "color_picker_color_crimson": "Karmesinrot",
    "color_picker_color_cyan": "Cyan",
    "color_picker_color_darkblue": "Dunkelblau",
    "color_picker_color_darkcyan": "Dunkelcyan",
    "color_picker_color_darkgoldenrod": "Dunkles Goldgelb",
    "color_picker_color_darkgray": "Dunkelgrau",
    "color_picker_color_darkgreen": "Dunkelgrün",
    "color_picker_color_darkkhaki": "Dunkelkhaki",
    "color_picker_color_darkmagenta": "Dunkelmagenta",
    "color_picker_color_darkolivegreen": "Dunkelolivgrün",
    "color_picker_color_darkorange": "Dunkelorange",
    "color_picker_color_darkorchid": "Dunkle Orchidee",
    "color_picker_color_darkred": "Dunkelrot",
    "color_picker_color_darksalmon": "Dunkellachs",
    "color_picker_color_darkseagreen": "Dunkles Seegrün",
    "color_picker_color_darkslateblue": "Dunkelschieferblau",
    "color_picker_color_darkslategray": "Dunkelschiefergrau",
    "color_picker_color_darkturquoise": "Dunkeltürkis",
    "color_picker_color_darkviolet": "Dunkelviolett",
    "color_picker_color_deeppink": "Tiefrosa",
    "color_picker_color_deepskyblue": "Tiefhimmelblau",
    "color_picker_color_dimgray": "Gedämpftes Grau",
    "color_picker_color_dodgerblue": "Dodgerblau",
    "color_picker_color_firebrick": "Ziegelrot",
    "color_picker_color_floralwhite": "Floralweiß",
    "color_picker_color_forestgreen": "Waldgrün",
    "color_picker_color_gainsboro": "Gainsboro",
    "color_picker_color_ghostwhite": "Geisterweiß",
    "color_picker_color_gold": "Gold",
    "color_picker_color_goldenrod": "Goldrute",
    "color_picker_color_greenyellow": "Grüngelb",
    "color_picker_color_honeydew": "Honigtau",
    "color_picker_color_hotpink": "Knallrosa",
    "color_picker_color_indianred": "Indischrot",
    "color_picker_color_indigo": "Indigo",
    "color_picker_color_ivory": "Elfenbein",
    "color_picker_color_khaki": "Khaki",
    "color_picker_color_lavender": "Lavendel",
    "color_picker_color_lavenderblush": "Lavendelrosa",
    "color_picker_color_lawngreen": "Rasengrün",
    "color_picker_color_lemonchiffon": "Zitronenchiffon",
    "color_picker_color_lightblue": "Hellblau",
    "color_picker_color_lightcoral": "Helles Korallenrot",
    "color_picker_color_lightcyan": "Helles Cyan",
    "color_picker_color_lightgoldenrodyellow": "Helles Goldgelb",
    "color_picker_color_lightgray": "Hellgrau",
    "color_picker_color_lightgreen": "Hellgrün",
    "color_picker_color_lightpink": "Hellrosa",
    "color_picker_color_lightsalmon": "Helles Lachsrosa",
    "color_picker_color_lightseagreen": "Helles Seegrün",
    "color_picker_color_lightskyblue": "Helles Himmelblau",
    "color_picker_color_lightslategray": "Helles Schiefergrau",
    "color_picker_color_lightsteelblue": "Helles Stahlblau",
    "color_picker_color_lightyellow": "Hellgelb",
    "color_picker_color_limegreen": "Limettengrün",
    "color_picker_color_linen": "Leinen",
    "color_picker_color_magenta": "Magenta",
    "color_picker_color_mediumaquamarine": "Mittleres Aquamarin",
    "color_picker_color_mediumblue": "Mittelblau",
    "color_picker_color_mediumorchid": "Mittlere Orchidee",
    "color_picker_color_mediumpurple": "Mittleres Purpur",
    "color_picker_color_mediumseagreen": "Mittleres Seegrün",
    "color_picker_color_mediumslateblue": "Mittleres Schieferblau",
    "color_picker_color_mediumspringgreen": "Mittleres Frühlingsgrün",
    "color_picker_color_mediumturquoise": "Mittleres Türkis",
    "color_picker_color_mediumvioletred": "Mittleres Violettrot",
    "color_picker_color_midnightblue": "Mitternachtsblau",
    "color_picker_color_mintcream": "Minzcreme",
    "color_picker_color_mistyrose": "Nebelrose",
    "color_picker_color_moccasin": "Mokassin",
    "color_picker_color_navajowhite": "Navajo-Weiß",
    "color_picker_color_oldlace": "Alte Spitze",
    "color_picker_color_olivedrab": "Olivgrün matt",
    "color_picker_color_orange": "Orange",
    "color_picker_color_orangered": "Orangerot",
    "color_picker_color_orchid": "Orchidee",
    "color_picker_color_palegoldenrod": "Blasses Goldgelb",
    "color_picker_color_palegreen": "Blasses Grün",
    "color_picker_color_paleturquoise": "Blasses Türkis",
    "color_picker_color_palevioletred": "Blasses Violettrot",
    "color_picker_color_papayawhip": "Papayacreme",
    "color_picker_color_peachpuff": "Pfirsich",
    "color_picker_color_peru": "Peru",
    "color_picker_color_pink": "Rosa",
    "color_picker_color_plum": "Pflaume",
    "color_picker_color_powderblue": "Puderblau",
    "color_picker_color_rebeccapurple": "Rebecca-Purpur",
    "color_picker_color_rosybrown": "Rosiges Braun",
    "color_picker_color_royalblue": "Königsblau",
    "color_picker_color_saddlebrown": "Sattelbraun",
    "color_picker_color_salmon": "Lachs",
    "color_picker_color_sandybrown": "Sandbraun",
    "color_picker_color_seagreen": "Meergrün",
    "color_picker_color_seashell": "Muschelweiß",
    "color_picker_color_sienna": "Sienna",
    "color_picker_color_skyblue": "Himmelblau",
    "color_picker_color_slateblue": "Schieferblau",
    "color_picker_color_slategray": "Schiefergrau",
    "color_picker_color_snow": "Schnee",
    "color_picker_color_springgreen": "Frühlingsgrün",
    "color_picker_color_steelblue": "Stahlblau",
    "color_picker_color_tan": "Hellbraun",
    "color_picker_color_thistle": "Distel",
    "color_picker_color_tomato": "Tomatenrot",
    "color_picker_color_turquoise": "Türkis",
    "color_picker_color_violet": "Violett",
    "color_picker_color_wheat": "Weizen",
    "color_picker_color_whitesmoke": "Weißrauch",
    "color_picker_color_yellowgreen": "Gelbgrün",
}
