# Georgian lexemes common.py
lexemes = {
    # Common
    "module_ondevice_llm_name": "მოწყობილობაზე LLM",

    "module_ondevice_llm_model_exception": "მოდელის ვერ მოიძებნა შეცდომა: {error_msg}",
    "module_ondevice_llm_task_exception": "მოდელის გენერატორის ინიციალიზაცია ვერ მოხდა: {error_msg}",
}
