# French lexemes statusbar.py
lexemes = {
    "statusbar_litter_bin_label": "Corbeille",
    "statusbar_litter_bin_accessible_name": "Afficher le contenu de la corbeille",

    "statusbar_save_progress_label": b'\xf0\x9f\x92\xbe',
    "statusbar_encryption_symbol_encrypted_label": b'\xf0\x9f\x94\x92',
    "statusbar_encryption_symbol_unencrypted_label": b'\xf0\x9f\x94\x93',

    "statusbar_mode_label_mode_view": "Mode Vue",
    "statusbar_mode_label_mode_edit": "Mode Édition",
    "statusbar_mode_label_mode_source": "Mode Source",

    "statusbar_source_label_source_markdown": "Markdown",
    "statusbar_source_label_source_html": "HTML",

    "statusbar_encryption_label": "{encryption} {icon}",
    "statusbar_encryption_label_encryption_plain": "Clair",
    "statusbar_encryption_label_encryption_encrypted": "Crypté",

    "statusbar_cursor_label": "ligne : {line} → col : {column}",
    "statusbar_cursor_label_selected": "ligne : {line} → col : {column} → sel : {selected}",
    "statusbar_cursor_label_with_global": "ligne : {line} → col : {column} → pos : {position}",
    "statusbar_cursor_label_selected_with_global":
        "ligne : {line} → col : {column} → pos : {position} → sel : {selected}",
}
