# Chinese lexemes main_menu.py
lexemes = {
    "group_file_label": "文件",
    "group_edit_label": "编辑",
    "group_tools_label": "工具",
    "group_help_label": "帮助",

    "actions_file_label_new_document": "新建文档",
    "actions_file_accessible_name_new_document": "新文档",
    "actions_file_label_open": "打开",
    "actions_file_accessible_name_open": "打开文档",
    "actions_file_label_save": "保存",
    "actions_file_accessible_name_save": "保存文件",
    "actions_file_label_save_as": "另存为",
    "actions_file_accessible_name_save_as": "另存文档副本",
    "actions_file_label_settings": "设置",
    "actions_file_accessible_name_settings": "应用设置",
    "actions_file_label_reset_settings": "重置设置",
    "actions_file_accessible_name_reset_settings": "重置设置",
    "actions_file_label_exit": "退出",
    "actions_file_accessible_name_exit": "退出应用程序",

    "actions_edit_edit_mode": "编辑",
    "actions_edit_accessible_name_edit_mode": "编辑文件",
    "actions_edit_source_mode": "源码",
    "actions_edit_accessible_name_source_mode": "源代码",
    "actions_edit_bold": "加粗",
    "actions_edit_accessible_name_bold": "加粗文字格式",
    "actions_edit_italic": "斜体",
    "actions_edit_accessible_name_italic": "斜体文字格式",
    "actions_edit_underline": "下划线",
    "actions_edit_accessible_name_underline": "下划线文字格式",
    "actions_edit_strikethrough": "删除线",
    "actions_edit_accessible_name_strikethrough": "删除线文字格式",
    "actions_edit_blockquote": "引用",
    "actions_edit_accessible_name_blockquote": "引用文字格式",

    "actions_tools_ai_assistant": "AI 助手",
    "actions_tools_accessible_name_ai_assistant": "启动 AI 助手",
    "actions_tools_color_picker": "颜色选择器",
    "actions_tools_accessible_name_color_picker": "选择文字颜色",

    "actions_help_label_md_syntax": "Markdown 语法",
    "actions_help_accessible_name_md_syntax": "Markdown 语法",
    "actions_help_label_check_for_updates": "检查更新",
    "actions_help_accessible_name_check_for_updates": "检查更新",
    "actions_help_label_bug_report": "错误报告",
    "actions_help_accessible_name_bug_report": "提交错误报告",
    "actions_help_label_about": "关于",
    "actions_help_accessible_name_about": "关于",
}
