# Hindi lexemes statusbar.py
lexemes = {
    "statusbar_litter_bin_label": "कचरा डिब्बा",
    "statusbar_litter_bin_accessible_name": "कचरा डिब्बे की सामग्री दिखाएं",

    "statusbar_save_progress_label": b'\xf0\x9f\x92\xbe',
    "statusbar_encryption_symbol_encrypted_label": b'\xf0\x9f\x94\x92',
    "statusbar_encryption_symbol_unencrypted_label": b'\xf0\x9f\x94\x93',

    "statusbar_mode_label_mode_view": "देखें मोड",
    "statusbar_mode_label_mode_edit": "संपादन मोड",
    "statusbar_mode_label_mode_source": "स्रोत मोड",

    "statusbar_source_label_source_markdown": "मार्कडाउन",
    "statusbar_source_label_source_html": "एचटीएमएल",

    "statusbar_encryption_label": "{encryption} {icon}",
    "statusbar_encryption_label_encryption_plain": "सादा",
    "statusbar_encryption_label_encryption_encrypted": "एन्क्रिप्टेड",

    "statusbar_cursor_label": "पंक्ति: {line} → स्तंभ: {column}",
    "statusbar_cursor_label_selected": "पंक्ति: {line} → स्तंभ: {column} → चयनित: {selected}",
    "statusbar_cursor_label_with_global": "पंक्ति: {line} → स्तंभ: {column} → स्थान: {position}",
    "statusbar_cursor_label_selected_with_global": "पंक्ति: {line} → स्तंभ: {column} → स्थान: {position} → चयनित: {selected}"
}
