# German lexemes common.py
lexemes = {
    # Common
    "module_ondevice_llm_name": "LLM auf dem Gerät",

    "module_ondevice_llm_model_exception": "Modell nicht gefunden Fehler: {error_msg}",
    "module_ondevice_llm_task_exception": "Modellgenerator kann nicht initialisiert werden: {error_msg}",
}
