# Russian lexemes color_picker_dialog.py
lexemes = {
    "color_picker_title": "Выберите цвет",

    "color_picker_color_black": "Черный",
    "color_picker_color_silver": "Серебряный",
    "color_picker_color_gray": "Серый",
    "color_picker_color_white": "Белый",
    "color_picker_color_maroon": "Темно-бордовый",
    "color_picker_color_red": "Красный",
    "color_picker_color_purple": "Пурпурный",
    "color_picker_color_fuchsia": "Фуксия",
    "color_picker_color_green": "Зеленый",
    "color_picker_color_lime": "Лайм",
    "color_picker_color_olive": "Оливковый",
    "color_picker_color_yellow": "Желтый",
    "color_picker_color_navy": "Темно-синий",
    "color_picker_color_blue": "Синий",
    "color_picker_color_teal": "Темно-зеленый",
    "color_picker_color_aqua": "Аква",
    "color_picker_color_aliceblue": "Голубой Алис",
    "color_picker_color_antiquewhite": "Античный белый",
    "color_picker_color_aquamarine": "Аквамарин",
    "color_picker_color_azure": "Лазурный",
    "color_picker_color_beige": "Бежевый",
    "color_picker_color_bisque": "Бисквит",
    "color_picker_color_blanchedalmond": "Миндаль",
    "color_picker_color_blueviolet": "Сине-фиолетовый",
    "color_picker_color_brown": "Коричневый",
    "color_picker_color_burlywood": "Крепкий деревянный",
    "color_picker_color_cadetblue": "Синий кадет",
    "color_picker_color_chartreuse": "Шартрез",
    "color_picker_color_chocolate": "Шоколадный",
    "color_picker_color_coral": "Коралловый",
    "color_picker_color_cornflowerblue": "Васильковый",
    "color_picker_color_cornsilk": "Шелк кукурузы",
    "color_picker_color_crimson": "Малиновый",
    "color_picker_color_cyan": "Циан",
    "color_picker_color_darkblue": "Темно-синий",
    "color_picker_color_darkcyan": "Темный циан",
    "color_picker_color_darkgoldenrod": "Темное золото",
    "color_picker_color_darkgray": "Темно-серый",
    "color_picker_color_darkgreen": "Темно-зеленый",
    "color_picker_color_darkkhaki": "Темный хаки",
    "color_picker_color_darkmagenta": "Темная маджента",
    "color_picker_color_darkolivegreen": "Темный оливково-зеленый",
    "color_picker_color_darkorange": "Темно-оранжевый",
    "color_picker_color_darkorchid": "Темная орхидея",
    "color_picker_color_darkred": "Темно-красный",
    "color_picker_color_darksalmon": "Темный лосось",
    "color_picker_color_darkseagreen": "Темный морской зеленый",
    "color_picker_color_darkslateblue": "Темный графитовый",
    "color_picker_color_darkslategray": "Темный шифер",
    "color_picker_color_darkturquoise": "Темный бирюзовый",
    "color_picker_color_darkviolet": "Темный фиолетовый",
    "color_picker_color_deeppink": "Глубокий розовый",
    "color_picker_color_deepskyblue": "Глубокий небесно-синий",
    "color_picker_color_dimgray": "Тусклый серый",
    "color_picker_color_dodgerblue": "Лазурно-синий",
    "color_picker_color_firebrick": "Кирпичный",
    "color_picker_color_floralwhite": "Цветочно-белый",
    "color_picker_color_forestgreen": "Лесной зеленый",
    "color_picker_color_gainsboro": "Гейнсборо",
    "color_picker_color_ghostwhite": "Призрачно-белый",
    "color_picker_color_gold": "Золотой",
    "color_picker_color_goldenrod": "Золотистый",
    "color_picker_color_greenyellow": "Зелено-желтый",
    "color_picker_color_honeydew": "Медовая роса",
    "color_picker_color_hotpink": "Ярко-розовый",
    "color_picker_color_indianred": "Индийский красный",
    "color_picker_color_indigo": "Индиго",
    "color_picker_color_ivory": "Слоновая кость",
    "color_picker_color_khaki": "Хаки",
    "color_picker_color_lavender": "Лаванда",
    "color_picker_color_lavenderblush": "Лавандовый румянец",
    "color_picker_color_lawngreen": "Газонно-зеленый",
    "color_picker_color_lemonchiffon": "Лимонный шифон",
    "color_picker_color_lightblue": "Светло-синий",
    "color_picker_color_lightcoral": "Светло-коралловый",
    "color_picker_color_lightcyan": "Светло-циан",
    "color_picker_color_lightgoldenrodyellow": "Светло-золотистый",
    "color_picker_color_lightgray": "Светло-серый",
    "color_picker_color_lightgreen": "Светло-зеленый",
    "color_picker_color_lightpink": "Светло-розовый",
    "color_picker_color_lightsalmon": "Светлый лосось",
    "color_picker_color_lightseagreen": "Светло-морской зеленый",
    "color_picker_color_lightskyblue": "Светло-небесно-синий",
    "color_picker_color_lightslategray": "Светло-графитовый",
    "color_picker_color_lightsteelblue": "Светло-стальной",
    "color_picker_color_lightyellow": "Светло-желтый",
    "color_picker_color_limegreen": "Лаймово-зеленый",
    "color_picker_color_linen": "Льняной",
    "color_picker_color_magenta": "Маджента",
    "color_picker_color_mediumaquamarine": "Средний аквамарин",
    "color_picker_color_mediumblue": "Средний синий",
    "color_picker_color_mediumorchid": "Средняя орхидея",
    "color_picker_color_mediumpurple": "Средний пурпурный",
    "color_picker_color_mediumseagreen": "Средний морской зеленый",
    "color_picker_color_mediumslateblue": "Средний графитовый",
    "color_picker_color_mediumspringgreen": "Средний весенне-зеленый",
    "color_picker_color_mediumturquoise": "Средний бирюзовый",
    "color_picker_color_mediumvioletred": "Средний фиолетово-красный",
    "color_picker_color_midnightblue": "Полуночно-синий",
    "color_picker_color_mintcream": "Мятный крем",
    "color_picker_color_mistyrose": "Туманная роза",
    "color_picker_color_moccasin": "Мокасин",
    "color_picker_color_navajowhite": "Навахо-белый",
    "color_picker_color_oldlace": "Старое кружево",
    "color_picker_color_olivedrab": "Тускло-оливковый",
    "color_picker_color_orange": "Оранжевый",
    "color_picker_color_orangered": "Оранжево-красный",
    "color_picker_color_orchid": "Орхидея",
    "color_picker_color_palegoldenrod": "Бледный золотистый",
    "color_picker_color_palegreen": "Бледно-зеленый",
    "color_picker_color_paleturquoise": "Бледный бирюзовый",
    "color_picker_color_palevioletred": "Бледно-фиолетово-красный",
    "color_picker_color_papayawhip": "Папайя",
    "color_picker_color_peachpuff": "Персиковый",
    "color_picker_color_peru": "Перу",
    "color_picker_color_pink": "Розовый",
    "color_picker_color_plum": "Сливовый",
    "color_picker_color_powderblue": "Порошково-синий",
    "color_picker_color_rebeccapurple": "Пурпурный Ребекка",
    "color_picker_color_rosybrown": "Розовато-коричневый",
    "color_picker_color_royalblue": "Королевский синий",
    "color_picker_color_saddlebrown": "Седельный коричневый",
    "color_picker_color_salmon": "Лососевый",
    "color_picker_color_sandybrown": "Песочно-коричневый",
    "color_picker_color_seagreen": "Морской зеленый",
    "color_picker_color_seashell": "Морская ракушка",
    "color_picker_color_sienna": "Сиенна",
    "color_picker_color_skyblue": "Небесно-синий",
    "color_picker_color_slateblue": "Синий ардезия",
    "color_picker_color_slategray": "Серый ардезия",
    "color_picker_color_snow": "Снег",
    "color_picker_color_springgreen": "Весенний зеленый",
    "color_picker_color_steelblue": "Стальной синий",
    "color_picker_color_tan": "Загорелый",
    "color_picker_color_thistle": "Чертополох",
    "color_picker_color_tomato": "Томатный",
    "color_picker_color_turquoise": "Бирюзовый",
    "color_picker_color_violet": "Фиолетовый",
    "color_picker_color_wheat": "Пшеница",
    "color_picker_color_whitesmoke": "Белый дым",
    "color_picker_color_yellowgreen": "Желто-зеленый",
}
