# Russian lexemes main_menu.py
lexemes = {
    "group_file_label": "Файл",
    "group_edit_label": "Редактировать",
    "group_tools_label": "Инструменты",
    "group_help_label": "Помощь",

    "actions_file_label_new_document": "Новый документ",
    "actions_file_accessible_name_new_document": "Новый документ",
    "actions_file_label_open": "Открыть",
    "actions_file_accessible_name_open": "Открыть документ",
    "actions_file_label_save": "Сохранить",
    "actions_file_accessible_name_save": "Сохранить документ",
    "actions_file_label_save_as": "Сохранить как",
    "actions_file_accessible_name_save_as": "Сохранить копию документа",
    "actions_file_label_settings": "Настройки",
    "actions_file_accessible_name_settings": "Настройки приложения",
    "actions_file_label_reset_settings": "Сброс настроек",
    "actions_file_accessible_name_reset_settings": "Сброс настроек",
    "actions_file_label_exit": "Выйти из приложения",
    "actions_file_accessible_name_exit": "Выйти из приложения",

    "actions_edit_edit_mode": "Редактировать",
    "actions_edit_accessible_name_edit_mode": "Редактировать файл",
    "actions_edit_source_mode": "Исходник",
    "actions_edit_accessible_name_source_mode": "Исходный код",
    "actions_edit_bold": "Жирный",
    "actions_edit_accessible_name_bold": "Формат жирного текста",
    "actions_edit_italic": "Курсив",
    "actions_edit_accessible_name_italic": "Формат курсивного текста",
    "actions_edit_underline": "Подчеркнутый",
    "actions_edit_accessible_name_underline": "Формат подчеркнутого текста",
    "actions_edit_strikethrough": "Зачеркнутый",
    "actions_edit_accessible_name_strikethrough": "Формат зачеркнутого текста",
    "actions_edit_blockquote": "Блок цитаты",
    "actions_edit_accessible_name_blockquote": "Формат текста цитаты",

    "actions_tools_ai_assistant": "ИИ Ассистент",
    "actions_tools_accessible_name_ai_assistant": "Запустить ИИ Ассистент",
    "actions_tools_color_picker": "Выбор цвета",
    "actions_tools_accessible_name_color_picker": "Выбрать цвет текста",

    "actions_help_label_md_syntax": "Синтаксис Markdown",
    "actions_help_accessible_name_md_syntax": "Синтаксис Markdown",
    "actions_help_label_check_for_updates": "Проверить обновления",
    "actions_help_accessible_name_check_for_updates": "Проверить обновления",
    "actions_help_label_bug_report": "Сообщить об ошибке",
    "actions_help_accessible_name_bug_report": "Отправить отчет об ошибке",
    "actions_help_label_about": "О программе",
    "actions_help_accessible_name_about": "О программе",
}
