# Hindi lexemes settings_dialog.py
lexemes = {
    "tab_ondevice_llm_config": "डिवाइस पर LLM",

    "module_ondevice_llm_config_label": "डिवाइस पर LLM मॉडल",
    "module_ondevice_llm_config_path_label": "ONNX मॉडल स्थान",
    "module_ondevice_llm_config_path_input_placeholder_text": "मॉडल डायरेक्टरी का पथ",
    "module_ondevice_llm_config_path_input_accessible_description":
        "एक इनपुट फ़ील्ड जिसमें एक सेलेक्टर है जो ONNX फाइलों वाली मॉडल डायरेक्टरी के पथ को निर्दिष्ट करता है।\n"
        "समर्थित मॉडल ONNX प्रारूप में हैं, जो ओपन न्यूरल नेटवर्क एक्सचेंज के लिए है, एक खुला मानक\n"
        "मशीन लर्निंग मॉडलों के लिए।",

    "module_ondevice_llm_config_response_temperature_label": "तापमान: {temperature}",
    "module_ondevice_llm_config_response_temperature_input_accessible_description":
        "मॉडल के उत्तरों की यादृच्छिकता को समायोजित करता है। उच्च मान अधिक विविध आउटपुट उत्पन्न करते हैं,\n"
        "जबकि निम्न मान उत्तरों को अधिक पूर्वानुमानित बनाते हैं।",

    "module_ondevice_llm_config_response_max_tokens_label": "अधिकतम प्रतिक्रिया टोकन",
    "module_ondevice_llm_config_response_max_tokens_input_accessible_description":
        "प्रतिक्रिया में प्राप्त होने वाले टोकनों की अधिकतम संख्या निर्धारित करता है, जैसे शब्द और विराम चिह्न,\n"
        "आउटपुट की लंबाई को नियंत्रित करता है।",

    "module_ondevice_llm_config_prompt_history_size_label": "प्रॉम्प्ट इतिहास का आकार",
    "module_ondevice_llm_config_prompt_history_size_input_accessible_description":
        "प्रणाली द्वारा संदर्भ के लिए बनाए रखी गई प्रॉम्प्ट इतिहास की प्रविष्टियों की संख्या को नियंत्रित करता है।\n"
        "शून्य मूल्य असीमित प्रविष्टियों की अनुमति देता है।"
}
