# Greek lexemes main_menu.py
lexemes = {
    "group_file_label": "Αρχείο",
    "group_edit_label": "Επεξεργασία",
    "group_tools_label": "Εργαλεία",
    "group_help_label": "Βοήθεια",

    "actions_file_label_new_document": "Νέο έγγραφο",
    "actions_file_accessible_name_new_document": "Νέο έγγραφο",
    "actions_file_label_open": "Άνοιγμα",
    "actions_file_accessible_name_open": "Άνοιγμα εγγράφου",
    "actions_file_label_save": "Αποθήκευση",
    "actions_file_accessible_name_save": "Αποθήκευση εγγράφου",
    "actions_file_label_save_as": "Αποθήκευση ως",
    "actions_file_accessible_name_save_as": "Αποθήκευση ως αντίγραφο εγγράφου",
    "actions_file_label_settings": "Ρυθμίσεις",
    "actions_file_accessible_name_settings": "Ρυθμίσεις εφαρμογής",
    "actions_file_label_reset_settings": "Επαναφορά ρυθμίσεων",
    "actions_file_accessible_name_reset_settings": "Επαναφορά ρυθμίσεων",
    "actions_file_label_exit": "Έξοδος",
    "actions_file_accessible_name_exit": "Έξοδος από την εφαρμογή",

    "actions_edit_edit_mode": "Επεξεργασία",
    "actions_edit_accessible_name_edit_mode": "Επεξεργασία αρχείου",
    "actions_edit_source_mode": "Πηγαίος κώδικας",
    "actions_edit_accessible_name_source_mode": "Πηγαίος κώδικας",
    "actions_edit_bold": "Έντονα",
    "actions_edit_accessible_name_bold": "Μορφή έντονου κειμένου",
    "actions_edit_italic": "Πλάγια",
    "actions_edit_accessible_name_italic": "Μορφή πλάγιου κειμένου",
    "actions_edit_underline": "Υπογράμμιση",
    "actions_edit_accessible_name_underline": "Μορφή υπογεγραμμένου κειμένου",
    "actions_edit_strikethrough": "Διαγραμμίσεις",
    "actions_edit_accessible_name_strikethrough": "Μορφή διαγραμμισμένου κειμένου",
    "actions_edit_blockquote": "Παράθεση",
    "actions_edit_accessible_name_blockquote": "Μορφή κειμένου παράθεσης",

    "actions_tools_ai_assistant": "Βοηθός AI",
    "actions_tools_accessible_name_ai_assistant": "Εκκίνηση Βοηθού AI",
    "actions_tools_color_picker": "Επιλογέας χρώματος",
    "actions_tools_accessible_name_color_picker": "Επιλέξτε χρώμα κειμένου",

    "actions_help_label_md_syntax": "Σύνταξη Markdown",
    "actions_help_accessible_name_md_syntax": "Σύνταξη Markdown",
    "actions_help_label_check_for_updates": "Έλεγχος για ενημερώσεις",
    "actions_help_accessible_name_check_for_updates": "Έλεγχος για ενημερώσεις",
    "actions_help_label_bug_report": "Αναφορά σφαλμάτων",
    "actions_help_accessible_name_bug_report": "Υποβολή αναφοράς σφάλματος",
    "actions_help_label_about": "Πληροφορίες",
    "actions_help_accessible_name_about": "Πληροφορίες",
}
