# Chinese lexemes common.py
lexemes = {
    "module_llama_cpp_name": "模块 llama.cpp",

    "module_llama_cpp_model_exception": "未找到模型错误：{error_msg}",
    "module_llama_cpp_task_exception": "无法初始化模型生成器：{error_msg}",
}
