# Korean lexemes main_menu.py
lexemes = {
    "group_file_label": "파일",
    "group_edit_label": "편집",
    "group_tools_label": "도구",
    "group_help_label": "도움말",

    "actions_file_label_new_document": "새 문서",
    "actions_file_accessible_name_new_document": "새 문서",
    "actions_file_label_open": "열기",
    "actions_file_accessible_name_open": "문서 열기",
    "actions_file_label_save": "저장",
    "actions_file_accessible_name_save": "문서 저장",
    "actions_file_label_save_as": "다른 이름으로 저장",
    "actions_file_accessible_name_save_as": "문서 복사본 저장",
    "actions_file_label_settings": "설정",
    "actions_file_accessible_name_settings": "앱 설정",
    "actions_file_label_reset_settings": "설정 재설정",
    "actions_file_accessible_name_reset_settings": "설정 재설정",
    "actions_file_label_exit": "종료",
    "actions_file_accessible_name_exit": "앱 종료",

    "actions_edit_edit_mode": "편집",
    "actions_edit_accessible_name_edit_mode": "파일 편집",
    "actions_edit_source_mode": "소스",
    "actions_edit_accessible_name_source_mode": "소스 코드",
    "actions_edit_bold": "굵게",
    "actions_edit_accessible_name_bold": "굵은 텍스트 형식",
    "actions_edit_italic": "기울임꼴",
    "actions_edit_accessible_name_italic": "기울임꼴 텍스트 형식",
    "actions_edit_underline": "밑줄",
    "actions_edit_accessible_name_underline": "밑줄 텍스트 형식",
    "actions_edit_strikethrough": "취소선",
    "actions_edit_accessible_name_strikethrough": "취소선 텍스트 형식",
    "actions_edit_blockquote": "블록 인용",
    "actions_edit_accessible_name_blockquote": "블록 인용 텍스트 형식",

    "actions_tools_ai_assistant": "AI 보조",
    "actions_tools_accessible_name_ai_assistant": "AI 보조 시작",
    "actions_tools_color_picker": "색상 선택기",
    "actions_tools_accessible_name_color_picker": "텍스트 색상 선택",

    "actions_help_label_md_syntax": "Markdown 문법",
    "actions_help_accessible_name_md_syntax": "Markdown 문법",
    "actions_help_label_check_for_updates": "업데이트 확인",
    "actions_help_accessible_name_check_for_updates": "업데이트 확인",
    "actions_help_label_bug_report": "버그 보고",
    "actions_help_accessible_name_bug_report": "버그 보고서 제출",
    "actions_help_label_about": "정보",
    "actions_help_accessible_name_about": "정보",
}
